@@ -1,21 +1,8 @@
 /*
-  Copyright (c) 2009 Constantin Berzan <exit3219@gmail.com>
-  Copyright (c) 2009 Leo Franchi <lfranchi@kde.org>
+  SPDX-FileCopyrightText: 2009 Constantin Berzan <exit3219@gmail.com>
+  SPDX-FileCopyrightText: 2009 Leo Franchi <lfranchi@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "cryptocomposertest.h"
@@ -351,7 +338,7 @@ void CryptoComposerTest::testBCCEncrypt()
     Composer *composer = new Composer;
     QString data(QStringLiteral("All happy families are alike; each unhappy family is unhappy in its own way."));
     fillComposerData(composer, data);
-    composer->infoPart()->setBcc(QStringList(QLatin1String("bcc@bcc.org")));
+    composer->infoPart()->setBcc(QStringList(QStringLiteral("bcc@bcc.org")));
 
     std::vector<GpgME::Key> keys = MessageComposer::Test::getKeys();
 
@@ -365,7 +352,7 @@ void CryptoComposerTest::testBCCEncrypt()
     std::vector< GpgME::Key > skeys;
     skeys.push_back(keys[2]);
 
-    QList<QPair<QStringList, std::vector<GpgME::Key> > > encKeys;
+    QVector<QPair<QStringList, std::vector<GpgME::Key> > > encKeys;
     encKeys.append(QPair<QStringList, std::vector<GpgME::Key> >(primRecipients, pkeys));
     encKeys.append(QPair<QStringList, std::vector<GpgME::Key> >(secondRecipients, skeys));
 
@@ -543,7 +530,7 @@ void CryptoComposerTest::fillComposerData(Composer *composer, const QString &dat
 {
     composer->globalPart()->setFallbackCharsetEnabled(true);
     composer->infoPart()->setFrom(QStringLiteral("me@me.me"));
-    composer->infoPart()->setTo(QStringList(QLatin1String("you@you.you")));
+    composer->infoPart()->setTo(QStringList(QStringLiteral("you@you.you")));
     composer->textPart()->setWrappedPlainText(data);
 }
 
@@ -556,7 +543,7 @@ void CryptoComposerTest::fillComposerCryptoData(Composer *composer)
     QStringList recipients;
     recipients << QString::fromLocal8Bit("you@you.you");
 
-    QList<QPair<QStringList, std::vector<GpgME::Key> > > encKeys;
+    QVector<QPair<QStringList, std::vector<GpgME::Key> > > encKeys;
     encKeys.append(QPair<QStringList, std::vector<GpgME::Key> >(recipients, keys));
 
     composer->setEncryptionKeys(encKeys);
@@ -576,7 +563,7 @@ void CryptoComposerTest::runSMIMETest(bool sign, bool enc, bool opaque)
     std::vector<GpgME::Key> keys = MessageComposer::Test::getKeys(true);
     QStringList recipients;
     recipients << QString::fromLocal8Bit("you@you.you");
-    QList<QPair<QStringList, std::vector<GpgME::Key> > > encKeys;
+    QVector<QPair<QStringList, std::vector<GpgME::Key> > > encKeys;
     encKeys.append(QPair<QStringList, std::vector<GpgME::Key> >(recipients, keys));
     composer->setEncryptionKeys(encKeys);
     composer->setSigningKeys(keys);
