@@ -1,20 +1,7 @@
 /*
-  Copyright (c) 2009 Constantin Berzan <exit3219@gmail.com>
+  SPDX-FileCopyrightText: 2009 Constantin Berzan <exit3219@gmail.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "maintextjobtest.h"
@@ -54,7 +41,7 @@ void MainTextJobTest::testPlainText()
 {
     Composer *composer = new Composer;
     composer->globalPart()->setGuiEnabled(false);
-    QList<QByteArray> charsets;
+    QVector<QByteArray> charsets;
     charsets << "us-ascii" << "utf-8";
     composer->globalPart()->setCharsets(charsets);
     TextPart *textPart = new TextPart;
@@ -69,6 +56,8 @@ void MainTextJobTest::testPlainText()
     QCOMPARE(result->contentType()->mimeType(), QByteArray("text/plain"));
     QCOMPARE(result->contentType()->charset(), QByteArray("us-ascii"));
     QCOMPARE(QString::fromLatin1(result->body()), data);
+    delete textPart;
+    delete composer;
 }
 
 void MainTextJobTest::testWrappingErrors()
@@ -84,6 +73,8 @@ void MainTextJobTest::testWrappingErrors()
         MainTextJob *mjob = new MainTextJob(textPart, composer);
         QVERIFY(!mjob->exec());   // error: not UseWrapping but given only wrapped text
         QCOMPARE(mjob->error(), int(JobBase::BugError));
+        delete textPart;
+        delete composer;
     }
     {
         Composer *composer = new Composer;
@@ -96,6 +87,8 @@ void MainTextJobTest::testWrappingErrors()
         MainTextJob *mjob = new MainTextJob(textPart, composer);
         QVERIFY(!mjob->exec());   // error: UseWrapping but given only clean text
         QCOMPARE(mjob->error(), int(JobBase::BugError));
+        delete textPart;
+        delete composer;
     }
 }
 
@@ -104,7 +97,7 @@ void MainTextJobTest::testCustomCharset()
     Composer *composer = new Composer;
     composer->globalPart()->setGuiEnabled(false);
     QByteArray charset("iso-8859-2");
-    composer->globalPart()->setCharsets(QList<QByteArray>() << charset);
+    composer->globalPart()->setCharsets(QVector<QByteArray>() << charset);
     TextPart *textPart = new TextPart;
     QString data = QStringLiteral("şi el o să se-nchidă cu o frunză de pelin");
     textPart->setWrappedPlainText(data);
@@ -120,6 +113,8 @@ void MainTextJobTest::testCustomCharset()
     QTextCodec *codec = QTextCodec::codecForName(charset);
     QVERIFY(codec);
     QCOMPARE(codec->toUnicode(outData), data);
+    delete textPart;
+    delete composer;
 }
 
 void MainTextJobTest::testNoCharset()
@@ -135,6 +130,8 @@ void MainTextJobTest::testNoCharset()
     QVERIFY(!mjob->exec());   // Error.
     QCOMPARE(mjob->error(), int(JobBase::BugError));
     qDebug() << mjob->errorString();
+    delete textPart;
+    delete composer;
 }
 
 void MainTextJobTest::testBadCharset()
@@ -142,7 +139,7 @@ void MainTextJobTest::testBadCharset()
     Composer *composer = new Composer;
     composer->globalPart()->setGuiEnabled(false);
     QByteArray charset("us-ascii");   // Cannot handle Romanian chars.
-    composer->globalPart()->setCharsets(QList<QByteArray>() << charset);
+    composer->globalPart()->setCharsets(QVector<QByteArray>() << charset);
     TextPart *textPart = new TextPart;
     QString data = QStringLiteral("el a plâns peste ţară cu lacrima limbii noastre");
     textPart->setWrappedPlainText(data);
@@ -151,6 +148,8 @@ void MainTextJobTest::testBadCharset()
     QVERIFY(!mjob->exec());   // Error.
     QCOMPARE(mjob->error(), int(JobBase::UserError));
     qDebug() << mjob->errorString();
+    delete textPart;
+    delete composer;
 }
 
 void MainTextJobTest::testFallbackCharset()
@@ -170,6 +169,8 @@ void MainTextJobTest::testFallbackCharset()
     QCOMPARE(result->contentType()->mimeType(), QByteArray("text/plain"));
     QCOMPARE(result->contentType()->charset(), QByteArray("us-ascii"));     // Fallback is us-ascii or utf8.
     QCOMPARE(QString::fromLatin1(result->body()), data);
+    delete textPart;
+    delete composer;
 }
 
 void MainTextJobTest::testHtml()
@@ -214,6 +215,7 @@ void MainTextJobTest::testHtml()
             QCOMPARE(QLatin1String(html->body()), editor.toCleanHtml());
         }
     }
+    delete composer;
 }
 
 void MainTextJobTest::testHtmlWithImages()
@@ -309,4 +311,6 @@ void MainTextJobTest::testHtmlWithImages()
             QCOMPARE(cid->identifier(), cid2.toLatin1());
         }
     }
+    delete textPart;
+    delete composer;
 }
