@@ -1,22 +1,9 @@
 /*
-  Copyright (C) 2010 Klaralvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
-  Copyright (c) 2010 Leo Franchi <lfranchi@kde.org>
-  Copyright (C) 2017-2019 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2010 Klaralvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  SPDX-FileCopyrightText: 2010 Leo Franchi <lfranchi@kde.org>
+  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "messagefactoryngtest.h"
@@ -44,7 +31,8 @@
 #include "globalsettings_templateparser.h"
 
 #include <KCharsets>
-
+#include <QRegularExpression>
+#include <QRegularExpressionMatch>
 #include <QDateTime>
 #include <QDir>
 #include <QLocale>
@@ -402,6 +390,7 @@ void MessageFactoryTest::testCreateReplyToAuthorAsync()
                                      "%4")
                  .arg(dateStr).arg(replyTo).arg(reference).arg(replyStr).arg(replyStr.length() - 1);
     QCOMPARE_OR_DIFF(reply.msg->encodedContent(), ba.toLatin1());
+    msg.clear();
 }
 
 void MessageFactoryTest::testCreateReplyAllWithMultiEmailsAsync()
@@ -444,6 +433,7 @@ void MessageFactoryTest::testCreateReplyAllWithMultiEmailsAsync()
                                      "X-KMail-Link-Type: reply\n\n> All happy families are alike; each unhappy family is unhappy in its own way.")
                  .arg(dateStr).arg(replyTo).arg(reference);
     QCOMPARE_OR_DIFF(reply.msg->encodedContent(), ba.toLatin1());
+    msg.clear();
 }
 
 void MessageFactoryTest::testCreateReplyAllAsync()
@@ -466,6 +456,7 @@ void MessageFactoryTest::testCreateReplyAllAsync()
         = QString::fromLatin1(QByteArray(QByteArray("On ") + datetime.toLatin1() + QByteArray(" you wrote:\n> All happy families are alike; each unhappy family is unhappy in its own way.\n\n")));
     QCOMPARE(reply.msg->subject()->asUnicodeString(), QLatin1String("Re: Test Email Subject"));
     QCOMPARE_OR_DIFF(reply.msg->body(), replyStr.toLatin1());
+    msg.clear();
 }
 
 void MessageFactoryTest::testCreateReplyHtmlAsync()
@@ -476,7 +467,8 @@ void MessageFactoryTest::testCreateReplyHtmlAsync()
 
     MessageFactoryNG factory(msg, 0);
     factory.setIdentityManager(mIdentMan);
-    TemplateParser::TemplateParserSettings::self()->setReplyUsingHtml(true);
+    TemplateParser::TemplateParserSettings::self()->setReplyUsingVisualFormat(true);
+    factory.setReplyAsHtml(true);
 
     QSignalSpy spy(&factory, &MessageFactoryNG::createReplyDone);
     factory.setIdentityManager(mIdentMan);
@@ -496,7 +488,9 @@ void MessageFactoryTest::testCreateReplyHtmlAsync()
     QCOMPARE(reply.msg->contents().count(), 2);
     QCOMPARE_OR_DIFF(reply.msg->contents().at(0)->body(), replyStr.toLatin1());
 
-    TemplateParser::TemplateParserSettings::self()->setReplyUsingHtml(false);
+    TemplateParser::TemplateParserSettings::self()->setReplyUsingVisualFormat(false);
+    factory.setReplyAsHtml(false);
+
     factory.createReplyAsync();
     QVERIFY(spy.wait());
     QCOMPARE(spy.count(), 2);
@@ -508,18 +502,20 @@ void MessageFactoryTest::testCreateReplyHtmlAsync()
     QCOMPARE(reply.msg->contentType()->mimeType(), QByteArrayLiteral("text/plain"));
     QCOMPARE(reply.msg->subject()->asUnicodeString(), QLatin1String("Re: reply to please"));
     QCOMPARE(reply.msg->contents().count(), 0);
-    TemplateParser::TemplateParserSettings::self()->setReplyUsingHtml(true);
+    TemplateParser::TemplateParserSettings::self()->setReplyUsingVisualFormat(true);
+    factory.setReplyAsHtml(true);
+    msg.clear();
 }
 
 void MessageFactoryTest::testCreateReplyUTF16Base64Async()
 {
     KMime::Message::Ptr msg = loadMessageFromFile(QStringLiteral("plain_utf16.mbox"));
-
-    TemplateParser::TemplateParserSettings::self()->setReplyUsingHtml(true);
-
     MessageFactoryNG factory(msg, 0);
     factory.setIdentityManager(mIdentMan);
 
+    TemplateParser::TemplateParserSettings::self()->setReplyUsingVisualFormat(true);
+    factory.setReplyAsHtml(true);
+
     QSignalSpy spy(&factory, &MessageFactoryNG::createReplyDone);
     factory.setIdentityManager(mIdentMan);
 
@@ -536,6 +532,7 @@ void MessageFactoryTest::testCreateReplyUTF16Base64Async()
     QCOMPARE(reply.msg->contentType()->mimeType(), QByteArrayLiteral("multipart/alternative"));
     QCOMPARE(reply.msg->subject()->asUnicodeString(), QLatin1String("Re: asking for reply"));
     QCOMPARE_OR_DIFF(reply.msg->contents().at(0)->body(), replyStr.toLatin1());
+    msg.clear();
 }
 
 void MessageFactoryTest::testCreateForwardMultiEmailsAsync()
@@ -579,6 +576,7 @@ void MessageFactoryTest::testCreateForwardMultiEmailsAsync()
 
     QCOMPARE(fw->subject()->asUnicodeString(), QStringLiteral("Fwd: Test Email Subject"));
     QCOMPARE_OR_DIFF(fw->encodedContent(), fwdMsg.toLatin1());
+    msg.clear();
 }
 
 void MessageFactoryTest::testCreateForwardAsync()
@@ -623,6 +621,7 @@ void MessageFactoryTest::testCreateForwardAsync()
 
     QCOMPARE(fw->subject()->asUnicodeString(), QStringLiteral("Fwd: Test Email Subject"));
     QCOMPARE_OR_DIFF(fw->encodedContent(), fwdMsg.toLatin1());
+    msg.clear();
 }
 
 void MessageFactoryTest::testCreateRedirectToAndCCAndBCC()
@@ -639,11 +638,14 @@ void MessageFactoryTest::testCreateRedirectToAndCCAndBCC()
 
     QString datetime = rdir->date()->asUnicodeString();
 
-    QRegExp rx(QLatin1String("Resent-Message-ID: ([^\n]*)"));
-    rx.indexIn(QString::fromLatin1(rdir->head()));
+    const QRegularExpression rx(QLatin1String("Resent-Message-ID: ([^\n]*)"));
+    const QRegularExpressionMatch rxMatch = rx.match(QString::fromLatin1(rdir->head()));
+    QVERIFY(rxMatch.hasMatch());
+
+    const QRegularExpression rxmessageid(QLatin1String("Message-ID: ([^\n]+)"));
+    const QRegularExpressionMatch rxmessageidMatch = rxmessageid.match(QString::fromLatin1(rdir->head()));
+    QVERIFY(rxmessageidMatch.hasMatch());
 
-    QRegExp rxmessageid(QLatin1String("Message-ID: ([^\n]+)"));
-    rxmessageid.indexIn(QString::fromLatin1(rdir->head()));
     QString baseline = QString::fromLatin1("From: me@me.me\n"
                                            "Cc: cc@cc.cc\n"
                                            "Bcc: bcc@bcc.bcc\n"
@@ -665,10 +667,11 @@ void MessageFactoryTest::testCreateRedirectToAndCCAndBCC()
                                            "X-KMail-Redirect-From: me@me.me (by way of another <another@another.com>)\n"
                                            "\n"
                                            "All happy families are alike; each unhappy family is unhappy in its own way.");
-    baseline = baseline.arg(datetime).arg(rxmessageid.cap(1)).arg(rx.cap(1)).arg(datetime).arg(QStringLiteral("another <another@another.com>"));
+    baseline = baseline.arg(datetime).arg(rxmessageidMatch.captured(1)).arg(rxMatch.captured(1)).arg(datetime).arg(QStringLiteral("another <another@another.com>"));
 
     QCOMPARE(rdir->subject()->asUnicodeString(), QStringLiteral("Test Email Subject"));
     QCOMPARE_OR_DIFF(rdir->encodedContent(), baseline.toLatin1());
+    msg.clear();
 }
 
 void MessageFactoryTest::testCreateRedirectToAndCC()
@@ -684,13 +687,14 @@ void MessageFactoryTest::testCreateRedirectToAndCC()
 
     QString datetime = rdir->date()->asUnicodeString();
 
-    QString msgId = MessageCore::StringUtil::generateMessageId(msg->sender()->asUnicodeString(), QString());
+    const QRegularExpression rx(QLatin1String("Resent-Message-ID: ([^\n]*)"));
+    const QRegularExpressionMatch rxMatch = rx.match(QString::fromLatin1(rdir->head()));
+    QVERIFY(rxMatch.hasMatch());
 
-    QRegExp rx(QLatin1String("Resent-Message-ID: ([^\n]*)"));
-    rx.indexIn(QString::fromLatin1(rdir->head()));
+    const QRegularExpression rxmessageid(QLatin1String("Message-ID: ([^\n]+)"));
+    const QRegularExpressionMatch rxmessageidMatch = rxmessageid.match(QString::fromLatin1(rdir->head()));
+    QVERIFY(rxmessageidMatch.hasMatch());
 
-    QRegExp rxmessageid(QLatin1String("Message-ID: ([^\n]+)"));
-    rxmessageid.indexIn(QString::fromLatin1(rdir->head()));
     //qWarning() << "messageid:" << rxmessageid.cap(1) << "(" << rdir->head() << ")";
     QString baseline = QString::fromLatin1("From: me@me.me\n"
                                            "Cc: cc@cc.cc\n"
@@ -712,10 +716,11 @@ void MessageFactoryTest::testCreateRedirectToAndCC()
                                            "X-KMail-Redirect-From: me@me.me (by way of another <another@another.com>)\n"
                                            "\n"
                                            "All happy families are alike; each unhappy family is unhappy in its own way.");
-    baseline = baseline.arg(datetime).arg(rxmessageid.cap(1)).arg(rx.cap(1)).arg(datetime).arg(QStringLiteral("another <another@another.com>"));
+    baseline = baseline.arg(datetime).arg(rxmessageidMatch.captured(1)).arg(rxMatch.captured(1)).arg(datetime).arg(QStringLiteral("another <another@another.com>"));
 
     QCOMPARE(rdir->subject()->asUnicodeString(), QStringLiteral("Test Email Subject"));
     QCOMPARE_OR_DIFF(rdir->encodedContent(), baseline.toLatin1());
+    msg.clear();
 }
 
 void MessageFactoryTest::testCreateRedirect()
@@ -730,11 +735,14 @@ void MessageFactoryTest::testCreateRedirect()
 
     QString datetime = rdir->date()->asUnicodeString();
 
-    QRegExp rx(QLatin1String("Resent-Message-ID: ([^\n]*)"));
-    rx.indexIn(QString::fromLatin1(rdir->head()));
+    const QRegularExpression rx(QLatin1String("Resent-Message-ID: ([^\n]*)"));
+    const QRegularExpressionMatch rxMatch = rx.match(QString::fromLatin1(rdir->head()));
+    QVERIFY(rxMatch.hasMatch());
+
+    const QRegularExpression rxmessageid(QLatin1String("Message-ID: ([^\n]+)"));
+    const QRegularExpressionMatch rxmessageidMatch = rxmessageid.match(QString::fromLatin1(rdir->head()));
+    QVERIFY(rxmessageidMatch.hasMatch());
 
-    QRegExp rxmessageid(QLatin1String("Message-ID: ([^\n]+)"));
-    rxmessageid.indexIn(QString::fromLatin1(rdir->head()));
     QString baseline = QString::fromLatin1("From: me@me.me\n"
                                            "Cc: cc@cc.cc\n"
                                            "Bcc: bcc@bcc.bcc\n"
@@ -754,10 +762,11 @@ void MessageFactoryTest::testCreateRedirect()
                                            "X-KMail-Redirect-From: me@me.me (by way of another <another@another.com>)\n"
                                            "\n"
                                            "All happy families are alike; each unhappy family is unhappy in its own way.");
-    baseline = baseline.arg(datetime).arg(rxmessageid.cap(1)).arg(rx.cap(1)).arg(datetime).arg(QStringLiteral("another <another@another.com>"));
+    baseline = baseline.arg(datetime).arg(rxmessageidMatch.captured(1)).arg(rxMatch.captured(1)).arg(datetime).arg(QStringLiteral("another <another@another.com>"));
 
     QCOMPARE(rdir->subject()->asUnicodeString(), QStringLiteral("Test Email Subject"));
     QCOMPARE_OR_DIFF(rdir->encodedContent(), baseline.toLatin1());
+    msg.clear();
 }
 
 void MessageFactoryTest::testCreateResend()
@@ -771,11 +780,13 @@ void MessageFactoryTest::testCreateResend()
 
     QString datetime = rdir->date()->asUnicodeString();
 
-    QRegExp rx(QLatin1String("Resent-Message-ID: ([^\n]*)"));
-    rx.indexIn(QString::fromLatin1(rdir->head()));
+    const QRegularExpression rx(QLatin1String("Resent-Message-ID: ([^\n]*)"));
+    const QRegularExpressionMatch rxMatch = rx.match(QString::fromLatin1(rdir->head()));
+    QVERIFY(!rxMatch.hasMatch());
 
-    QRegExp rxmessageid(QLatin1String("Message-ID: ([^\n]+)"));
-    rxmessageid.indexIn(QString::fromLatin1(rdir->head()));
+    const QRegularExpression rxmessageid(QLatin1String("Message-ID: ([^\n]+)"));
+    const QRegularExpressionMatch rxmessageidMatch = rxmessageid.match(QString::fromLatin1(rdir->head()));
+    QVERIFY(rxmessageidMatch.hasMatch());
 
     QString baseline = QString::fromLatin1("From: me@me.me\n"
                                            "To: %1\n"
@@ -791,10 +802,11 @@ void MessageFactoryTest::testCreateResend()
                                            "Content-Type: text/plain; charset=\"us-ascii\"\n"
                                            "\n"
                                            "All happy families are alike; each unhappy family is unhappy in its own way.");
-    baseline = baseline.arg(msg->to()->asUnicodeString()).arg(datetime).arg(rxmessageid.cap(1));
+    baseline = baseline.arg(msg->to()->asUnicodeString()).arg(datetime).arg(rxmessageidMatch.captured(1));
 
     QCOMPARE(rdir->subject()->asUnicodeString(), QStringLiteral("Test Email Subject"));
     QCOMPARE_OR_DIFF(rdir->encodedContent(), baseline.toLatin1());
+    msg.clear();
 }
 
 void MessageFactoryTest::testCreateMDN()
@@ -816,6 +828,7 @@ void MessageFactoryTest::testCreateMDN()
 
     QCOMPARE_OR_DIFF(Util::findTypeInMessage(mdn.data(), "multipart", "report")->contents().at(0)->body(),
                      mdnContent.toLatin1());
+    msg.clear();
 }
 
 KMime::Message::Ptr MessageFactoryTest::createPlainTestMessage()
@@ -932,4 +945,5 @@ void MessageFactoryTest::test_multipartAlternative()
     QCOMPARE(reply.msg->contentType()->mimeType(), QByteArrayLiteral("multipart/alternative"));
     QCOMPARE(reply.msg->subject()->asUnicodeString(), QLatin1String("Re: Plain Message Test"));
     QCOMPARE(reply.msg->contents().at(contentAt)->encodedBody().data(), expected.toLatin1().data());
+    origMsg.clear();
 }
