@@ -1,22 +1,9 @@
 /*
-  Copyright (C) 2010 Klaralvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
-  Copyright (c) 2010 Leo Franchi <lfranchi@kde.org>
-  Copyright (C) 2017-2019 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2010 Klaralvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  SPDX-FileCopyrightText: 2010 Leo Franchi <lfranchi@kde.org>
+  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef MESSAGEFACTORYNG_TEST_H
@@ -64,10 +51,10 @@ private Q_SLOTS:
 
     void cleanupTestCase();
 private:
-    KMime::Message::Ptr createPlainTestMessage();
-    KMime::Message::Ptr loadMessageFromFile(const QString &filename);
-    KMime::Message::Ptr createPlainTestMessageWithMultiEmails();
-    KMime::Message::Ptr loadMessage(const QString &filename);
+    Q_REQUIRED_RESULT KMime::Message::Ptr createPlainTestMessage();
+    Q_REQUIRED_RESULT KMime::Message::Ptr loadMessageFromFile(const QString &filename);
+    Q_REQUIRED_RESULT KMime::Message::Ptr createPlainTestMessageWithMultiEmails();
+    Q_REQUIRED_RESULT KMime::Message::Ptr loadMessage(const QString &filename);
     KIdentityManagement::IdentityManager *mIdentMan = nullptr;
 };
 
