@@ -1,20 +1,7 @@
 /*
-  Copyright (C) 2019 Glen Ditchfield <GJDitchfield@acm.org>
+  SPDX-FileCopyrightText: 2019 Glen Ditchfield <GJDitchfield@acm.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "replystrategytest.h"
@@ -104,9 +91,9 @@ ReplyStrategyTest::~ReplyStrategyTest()
 void ReplyStrategyTest::initTestCase()
 {
     QFile::remove(QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation)
-                  + QDir::separator() + QStringLiteral("emailidentities"));
+                  + QStringLiteral("/emailidentities"));
     QFile::remove(QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation)
-                  + QDir::separator() + QStringLiteral("emaildefaults"));
+                  + QStringLiteral("/emaildefaults"));
 
     mIdentityManager = new KIdentityManagement::IdentityManager;
 
@@ -137,7 +124,7 @@ KMime::Message::Ptr ReplyStrategyTest::makeReply(const KMime::Message::Ptr &orig
     QSignalSpy spy {&factory, &MessageFactoryNG::createReplyDone};
     factory.createReplyAsync();
     KMime::Message::Ptr result {nullptr};
-    [&]{
+    [&] {
         QVERIFY(spy.wait());
         QCOMPARE(spy.count(), 1);
         result = spy.at(0).at(0).value<MessageFactoryNG::MessageReply>().msg;
@@ -415,6 +402,7 @@ void ReplyStrategyTest::testReply()
         COMPARE_ADDRESSES(reply->to(), rTo);
         COMPARE_ADDRESSES(reply->cc(), rCc);
     }
+    original.clear();
 }
 
 QTEST_MAIN(ReplyStrategyTest)
