@@ -1,21 +1,8 @@
 /*
-  Copyright (c) 2009 Constantin Berzan <exit3219@gmail.com>
-  Copyright (C) 2017-2019 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009 Constantin Berzan <exit3219@gmail.com>
+  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "utiltest.h"
@@ -40,7 +27,7 @@ void UtilTest::testSelectCharset()
     // Pick a charset that actually works.
     {
         QString text = QStringLiteral("text 123 ăîşţâ");
-        QList<QByteArray> charsets;
+        QVector<QByteArray> charsets;
         charsets << "us-ascii";
         charsets << "iso-8859-1";
         charsets << "iso-8859-2"; // This one works.
@@ -51,7 +38,7 @@ void UtilTest::testSelectCharset()
     // Pick as simple a charset as possible.
     {
         QString text = QStringLiteral("plain English text");
-        QList<QByteArray> charsets;
+        QVector<QByteArray> charsets;
         charsets << "us-ascii"; // This one works.
         charsets << "iso-8859-1";
         charsets << "utf-8";
@@ -62,7 +49,7 @@ void UtilTest::testSelectCharset()
     // Return empty charset if none works.
     {
         QString text = QStringLiteral("text 123 ăîşţâ");
-        QList<QByteArray> charsets;
+        QVector<QByteArray> charsets;
         QByteArray choice = Util::selectCharset(charsets, text);
         QVERIFY(choice.isEmpty());
         charsets << "us-ascii";
