@@ -1,23 +1,11 @@
 /*
  * This file is part of KMail.
- * Copyright (c) 2009 Constantin Berzan <exit3219@gmail.com>
+ * SPDX-FileCopyrightText: 2009 Constantin Berzan <exit3219@gmail.com>
  *
  * Parts based on KMail code by:
  * Various authors.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "attachmentcontrollerbase.h"
@@ -54,7 +42,7 @@
 #include <KMessageBox>
 #include <KMimeTypeTrader>
 #include <QPushButton>
-#include <KRun>
+#include <KIO/ApplicationLauncherJob>
 #include <QTemporaryFile>
 #include <QMimeDatabase>
 #include <KFileItemActions>
@@ -71,6 +59,9 @@
 #include <MessageCore/AttachmentFromUrlUtils>
 #include <settings/messagecomposersettings.h>
 #include <KIO/Job>
+#include <kio_version.h>
+#include <KIO/JobUiDelegate>
+#include <KIO/OpenUrlJob>
 #include <Akonadi/Contact/EmailAddressSelectionDialog>
 #include <Akonadi/Contact/EmailAddressSelectionWidget>
 
@@ -182,8 +173,8 @@ void AttachmentControllerBase::Private::compressJobResult(KJob *job)
         return;
     }
 
-    Q_ASSERT(dynamic_cast<AttachmentCompressJob *>(job));
-    AttachmentCompressJob *ajob = static_cast<AttachmentCompressJob *>(job);
+    AttachmentCompressJob *ajob = dynamic_cast<AttachmentCompressJob *>(job);
+    Q_ASSERT(ajob);
     AttachmentPart::Ptr originalPart = ajob->originalPart();
     AttachmentPart::Ptr compressedPart = ajob->compressedPart();
 
@@ -216,8 +207,8 @@ void AttachmentControllerBase::Private::loadJobResult(KJob *job)
         return;
     }
 
-    Q_ASSERT(dynamic_cast<AttachmentLoadJob *>(job));
-    AttachmentLoadJob *ajob = static_cast<AttachmentLoadJob *>(job);
+    AttachmentLoadJob *ajob = dynamic_cast<AttachmentLoadJob *>(job);
+    Q_ASSERT(ajob);
     AttachmentPart::Ptr part = ajob->attachmentPart();
     q->addAttachment(part);
 }
@@ -241,7 +232,7 @@ void AttachmentControllerBase::Private::viewSelectedAttachments()
 void AttachmentControllerBase::Private::editSelectedAttachment()
 {
     Q_ASSERT(selectedParts.count() == 1);
-    q->editAttachment(selectedParts.first(), MessageViewer::EditorWatcher::NoOpenWithDialog);
+    q->editAttachment(selectedParts.constFirst(), MessageViewer::EditorWatcher::NoOpenWithDialog);
 }
 
 void AttachmentControllerBase::Private::editSelectedAttachmentWith()
@@ -263,19 +254,19 @@ void AttachmentControllerBase::Private::removeSelectedAttachments()
 void AttachmentControllerBase::Private::saveSelectedAttachmentAs()
 {
     Q_ASSERT(selectedParts.count() == 1);
-    q->saveAttachmentAs(selectedParts.first());
+    q->saveAttachmentAs(selectedParts.constFirst());
 }
 
 void AttachmentControllerBase::Private::selectedAttachmentProperties()
 {
     Q_ASSERT(selectedParts.count() == 1);
-    q->attachmentProperties(selectedParts.first());
+    q->attachmentProperties(selectedParts.constFirst());
 }
 
 void AttachmentControllerBase::Private::reloadAttachment()
 {
     Q_ASSERT(selectedParts.count() == 1);
-    AttachmentUpdateJob *ajob = new AttachmentUpdateJob(selectedParts.first(), q);
+    AttachmentUpdateJob *ajob = new AttachmentUpdateJob(selectedParts.constFirst(), q);
     connect(ajob, &AttachmentUpdateJob::result, q, [this](KJob *job) {
         updateJobResult(job);
     });
@@ -288,8 +279,8 @@ void AttachmentControllerBase::Private::updateJobResult(KJob *job)
         KMessageBox::sorry(wParent, job->errorString(), i18n("Failed to reload attachment"));
         return;
     }
-    Q_ASSERT(dynamic_cast<AttachmentUpdateJob *>(job));
-    AttachmentUpdateJob *ajob = static_cast<AttachmentUpdateJob *>(job);
+    AttachmentUpdateJob *ajob = dynamic_cast<AttachmentUpdateJob *>(job);
+    Q_ASSERT(ajob);
     AttachmentPart::Ptr originalPart = ajob->originalPart();
     AttachmentPart::Ptr updatedPart = ajob->updatedPart();
 
@@ -579,6 +570,7 @@ void AttachmentControllerBase::createActions()
     collection->addAction(QStringLiteral("attach_public_key"), d->attachPublicKeyAction);
     collection->addAction(QStringLiteral("attach_my_public_key"), d->attachMyPublicKeyAction);
     collection->addAction(QStringLiteral("attach"), d->addAttachmentFileAction);
+    collection->setDefaultShortcut(d->addAttachmentFileAction, QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_A));
     collection->addAction(QStringLiteral("attach_directory"), d->addAttachmentDirectoryAction);
 
     collection->addAction(QStringLiteral("remove"), d->removeAction);
@@ -654,7 +646,7 @@ void AttachmentControllerBase::showContextMenu()
                 ) {
                 menu.addAction(d->viewContextAction);
             }
-            d->createOpenWithMenu(&menu, d->selectedParts.first());
+            d->createOpenWithMenu(&menu, d->selectedParts.constFirst());
         }
         menu.addAction(d->openContextAction);
     }
@@ -662,9 +654,7 @@ void AttachmentControllerBase::showContextMenu()
         menu.addAction(d->editWithContextAction);
         menu.addAction(d->editContextAction);
     }
-    if (numberOfParts > 0) {
-        menu.addAction(d->removeContextAction);
-    }
+    menu.addSeparator();
     if (numberOfParts == 1) {
         if (!d->selectedParts.first()->url().isEmpty()) {
             menu.addAction(d->reloadAttachmentAction);
@@ -672,15 +662,19 @@ void AttachmentControllerBase::showContextMenu()
         menu.addAction(d->saveAsContextAction);
         menu.addSeparator();
         menu.addAction(d->propertiesContextAction);
+        menu.addSeparator();
     }
 
+    if (numberOfParts > 0) {
+        menu.addAction(d->removeContextAction);
+        menu.addSeparator();
+    }
     const int nbAttachment = d->model->rowCount();
     if (nbAttachment != numberOfParts) {
-        menu.addSeparator();
         menu.addAction(d->selectAllAction);
+        menu.addSeparator();
     }
     if (numberOfParts == 0) {
-        menu.addSeparator();
         menu.addAction(d->addContextAction);
     }
 
@@ -702,31 +696,28 @@ void AttachmentControllerBase::slotOpenWithAction(QAction *act)
 
 void AttachmentControllerBase::openWith(const KService::Ptr &offer)
 {
-    QTemporaryFile *tempFile = dumpAttachmentToTempFile(d->selectedParts.first());
+    QTemporaryFile *tempFile = dumpAttachmentToTempFile(d->selectedParts.constFirst());
     if (!tempFile) {
         KMessageBox::sorry(d->wParent,
                            i18n("KMail was unable to write the attachment to a temporary file."),
                            i18n("Unable to open attachment"));
         return;
     }
-    QList<QUrl> lst;
     QUrl url = QUrl::fromLocalFile(tempFile->fileName());
-    lst.append(url);
     tempFile->setPermissions(QFile::ReadUser);
-    bool result = false;
-    if (offer) {
-        result = KRun::runService(*offer, lst, d->wParent, false);
-    } else {
-        result = KRun::displayOpenWithDialog(lst, d->wParent, false);
-    }
-    if (!result) {
-        delete tempFile;
-        tempFile = nullptr;
-    } else {
-        // The file was opened.  Delete it only when the composer is closed
-        // (and this object is destroyed).
-        tempFile->setParent(this);   // Manages lifetime.
-    }
+    // If offer is null, this will show the "open with" dialog
+    KIO::ApplicationLauncherJob *job = new KIO::ApplicationLauncherJob(offer);
+    job->setUrls({url});
+    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, d->wParent));
+    job->start();
+    connect(job, &KJob::result, this, [tempFile, job]() {
+        if (job->error()) {
+            delete tempFile;
+        }
+    });
+    // Delete the file only when the composer is closed
+    // (and this object is destroyed).
+    tempFile->setParent(this);   // Manages lifetime.
 }
 
 void AttachmentControllerBase::openAttachment(const AttachmentPart::Ptr &part)
@@ -739,28 +730,22 @@ void AttachmentControllerBase::openAttachment(const AttachmentPart::Ptr &part)
         return;
     }
     tempFile->setPermissions(QFile::ReadUser);
-    KRun::RunFlags flags;
-    flags |= KRun::DeleteTemporaryFiles;
-    bool success = KRun::runUrl(QUrl::fromLocalFile(tempFile->fileName()),
-                                QString::fromLatin1(part->mimeType()),
-                                d->wParent,
-                                flags);
-    if (!success) {
-        if (!KMimeTypeTrader::self()->preferredService(QString::fromLatin1(part->mimeType())).data()) {
-            // KRun showed an Open-With dialog, and it was canceled.
-        } else {
-            // KRun failed.
+    KIO::OpenUrlJob *job = new KIO::OpenUrlJob(QUrl::fromLocalFile(tempFile->fileName()), QString::fromLatin1(part->mimeType()));
+    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, d->wParent));
+    job->setDeleteTemporaryFile(true);
+    connect(job, &KIO::OpenUrlJob::result, this, [this, tempFile](KJob *job) {
+        if (job->error() == KIO::ERR_USER_CANCELED) {
             KMessageBox::sorry(d->wParent,
                                i18n("KMail was unable to open the attachment."),
-                               i18n("Unable to open attachment"));
+                               job->errorString());
+            delete tempFile;
+        } else {
+            // The file was opened.  Delete it only when the composer is closed
+            // (and this object is destroyed).
+            tempFile->setParent(this);   // Manages lifetime.
         }
-        delete tempFile;
-        tempFile = nullptr;
-    } else {
-        // The file was opened.  Delete it only when the composer is closed
-        // (and this object is destroyed).
-        tempFile->setParent(this);   // Manages lifetime.
-    }
+    });
+    job->start();
 }
 
 void AttachmentControllerBase::viewAttachment(const AttachmentPart::Ptr &part)
@@ -777,7 +762,7 @@ void AttachmentControllerBase::viewAttachment(const AttachmentPart::Ptr &part)
 void AttachmentControllerBase::Private::slotAttachmentContentCreated(KJob *job)
 {
     if (!job->error()) {
-        const MessageComposer::AttachmentJob *const attachmentJob = dynamic_cast<MessageComposer::AttachmentJob *>(job);
+        const MessageComposer::AttachmentJob *const attachmentJob = qobject_cast<MessageComposer::AttachmentJob *>(job);
         Q_ASSERT(attachmentJob);
         if (attachmentJob) {
             Q_EMIT q->showAttachment(attachmentJob->content(), QByteArray());
@@ -841,7 +826,7 @@ void AttachmentControllerBase::saveAttachmentAs(const AttachmentPart::Ptr &part)
         pname = i18n("unnamed");
     }
 
-    QUrl url = QFileDialog::getSaveFileUrl(d->wParent, i18n("Save Attachment As"), QUrl::fromLocalFile(pname));
+    const QUrl url = QFileDialog::getSaveFileUrl(d->wParent, i18n("Save Attachment As"), QUrl::fromLocalFile(pname));
 
     if (url.isEmpty()) {
         qCDebug(MESSAGECOMPOSER_LOG) << "Save Attachment As dialog canceled.";
@@ -898,18 +883,6 @@ void AttachmentControllerBase::attachDirectory(const QUrl &url)
     }
 }
 
-void AttachmentControllerBase::attachFiles(const QList<QUrl> &urls, const QString &encoding)
-{
-    const int numberOfFiles(urls.count());
-    for (int i = 0; i < numberOfFiles; ++i) {
-        auto url = urls.at(i);
-        QUrlQuery query(url);
-        query.addQueryItem(QStringLiteral("charset"), encoding);
-        url.setQuery(query.toString());
-        addAttachment(url);
-    }
-}
-
 void AttachmentControllerBase::showAttachVcard()
 {
     QPointer<Akonadi::EmailAddressSelectionDialog> dlg = new Akonadi::EmailAddressSelectionDialog(d->wParent);
@@ -959,7 +932,7 @@ void AttachmentControllerBase::showAddAttachmentFileDialog()
             QUrl urlWithEncoding = url;
             MessageCore::StringUtil::setEncodingFile(urlWithEncoding, encoding);
             QMimeDatabase mimeDb;
-            auto mimeType = mimeDb.mimeTypeForUrl(urlWithEncoding);
+            const auto mimeType = mimeDb.mimeTypeForUrl(urlWithEncoding);
             if (mimeType.name() == QLatin1String("inode/directory")) {
                 const int rc = KMessageBox::warningYesNo(d->wParent, i18n("Do you really want to attach this directory \"%1\"?", url.toLocalFile()),
                                                          i18nc("@title:window", "Attach directory"));
