@@ -1,31 +1,21 @@
 /*
-   Copyright (C) 2015-2019 Montel Laurent <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "richtextcomposerng.h"
-#include <kpimtextedit/richtextcomposercontroler.h>
-#include <kpimtextedit/richtextcomposerimages.h>
+#include <KPIMTextEdit/RichTextComposerControler>
+#include <KPIMTextEdit/RichTextComposerImages>
 #include "richtextcomposersignatures.h"
-#include <pimcommon/autocorrection.h>
+#include <PimCommon/AutoCorrection>
 #include <part/textpart.h>
 #include "settings/messagecomposersettings.h"
-#include <grantlee/markupdirector.h>
-#include <grantlee/plaintextmarkupbuilder.h>
+#include <KPIMTextEdit/TextHTMLBuilder>
+#include <KPIMTextEdit/MarkupDirector>
+#include <KPIMTextEdit/PlainTextMarkupBuilder>
+
+#define USE_TEXTHTML_BUILDER 1
 
 using namespace MessageComposer;
 
@@ -39,9 +29,9 @@ public:
     }
 
     void fixHtmlFontSize(QString &cleanHtml);
-    QString toCleanHtml() const;
+    Q_REQUIRED_RESULT QString toCleanHtml() const;
     PimCommon::AutoCorrection *autoCorrection = nullptr;
-    RichTextComposerNg *richtextComposer = nullptr;
+    RichTextComposerNg * const richtextComposer;
     MessageComposer::RichTextComposerSignatures *richTextComposerSignatures = nullptr;
 };
 
@@ -161,14 +151,14 @@ MessageComposer::PluginEditorConvertTextInterface::ConvertTextStatus RichTextCom
 
 void RichTextComposerNg::fillComposerTextPart(MessageComposer::TextPart *textPart)
 {
-    bool wasConverted
+    const bool wasConverted
         = convertPlainText(textPart) == MessageComposer::PluginEditorConvertTextInterface::ConvertTextStatus::Converted;
     if (composerControler()->isFormattingUsed()) {
         if (!wasConverted) {
             if (MessageComposer::MessageComposerSettings::self()->improvePlainTextOfHtmlMessage()) {
-                Grantlee::PlainTextMarkupBuilder *pb = new Grantlee::PlainTextMarkupBuilder();
+                KPIMTextEdit::PlainTextMarkupBuilder *pb = new KPIMTextEdit::PlainTextMarkupBuilder();
 
-                Grantlee::MarkupDirector *pmd = new Grantlee::MarkupDirector(pb);
+                KPIMTextEdit::MarkupDirector *pmd = new KPIMTextEdit::MarkupDirector(pb);
                 pmd->processDocument(document());
                 const QString plainText = pb->getResult();
                 textPart->setCleanPlainText(composerControler()->toCleanPlainText(plainText));
@@ -192,9 +182,23 @@ void RichTextComposerNg::fillComposerTextPart(MessageComposer::TextPart *textPar
     }
     textPart->setWordWrappingEnabled(lineWrapMode() == QTextEdit::FixedColumnWidth);
     if (composerControler()->isFormattingUsed() && !wasConverted) {
+#ifdef USE_TEXTHTML_BUILDER
+        KPIMTextEdit::TextHTMLBuilder *pb = new KPIMTextEdit::TextHTMLBuilder();
+
+        KPIMTextEdit::MarkupDirector *pmd = new KPIMTextEdit::MarkupDirector(pb);
+        pmd->processDocument(document());
+        QString cleanHtml = QStringLiteral("<html>\n<head>\n<meta http-equiv=\"content-type\" content=\"text/html; charset=UTF-8\">\n</head>\n<body>%1</body>\n</html>").arg(pb->getResult());
+        delete pmd;
+        delete pb;
+        d->fixHtmlFontSize(cleanHtml);
+        textPart->setCleanHtml(cleanHtml);
+        //qDebug() << " cleanHtml  grantlee builder" << cleanHtml;
+#else
         QString cleanHtml = d->toCleanHtml();
         d->fixHtmlFontSize(cleanHtml);
         textPart->setCleanHtml(cleanHtml);
+        qDebug() << "cleanHtml  " << cleanHtml;
+#endif
         textPart->setEmbeddedImages(composerControler()->composerImages()->embeddedImages());
     }
 }
@@ -361,7 +365,8 @@ void RichTextComposerNg::insertSignature(const KIdentityManagement::Signature &s
 
         // We added the text of the signature above, now it is time to add the images as well.
         if (signature.isInlinedHtml()) {
-            for (const KIdentityManagement::Signature::EmbeddedImagePtr &image : signature.embeddedImages()) {
+            const QVector<KIdentityManagement::Signature::EmbeddedImagePtr> embeddedImages = signature.embeddedImages();
+            for (const KIdentityManagement::Signature::EmbeddedImagePtr &image : embeddedImages) {
                 composerControler()->composerImages()->loadImage(image->image, image->name, image->name);
             }
         }
