@@ -1,22 +1,9 @@
 /*
-  Copyright (c) 2009 Constantin Berzan <exit3219@gmail.com>
-  Copyright (C) 2009 Klaralvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-  Copyright (c) 2009 Leo Franchi <lfranchi@kde.org>
+  SPDX-FileCopyrightText: 2009 Constantin Berzan <exit3219@gmail.com>
+  SPDX-FileCopyrightText: 2009 Klaralvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
+  SPDX-FileCopyrightText: 2009 Leo Franchi <lfranchi@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "composer.h"
@@ -38,7 +25,7 @@
 #include "settings/messagecomposersettings.h"
 
 #include "messagecomposer_debug.h"
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
 using namespace MessageComposer;
 using MessageCore::AttachmentPart;
@@ -50,26 +37,29 @@ public:
         : JobBasePrivate(qq)
     {
     }
+    ~ComposerPrivate()
+    {
+        //delete skeletonMessage;
+    }
 
     void init();
     void doStart(); // slot
     void composeStep1();
-    void skeletonJobFinished(KJob *job);   // slot
     void composeStep2();
-    QList<ContentJobBase *> createEncryptJobs(ContentJobBase *contentJob, bool sign);
+    Q_REQUIRED_RESULT QList<ContentJobBase *> createEncryptJobs(ContentJobBase *contentJob, bool sign);
     void contentJobFinished(KJob *job);   // slot
     void composeWithLateAttachments(KMime::Message *headers, KMime::Content *content, const AttachmentPart::List &parts, const std::vector<GpgME::Key> &keys, const QStringList &recipients);
     void attachmentsFinished(KJob *job);   // slot
 
     void composeFinalStep(KMime::Content *headers, KMime::Content *content);
 
-    QList<QPair<QStringList, std::vector<GpgME::Key> > > encData;
+    QVector<QPair<QStringList, std::vector<GpgME::Key> > > encData;
     std::vector<GpgME::Key> signers;
     AttachmentPart::List attachmentParts;
     // attachments with different sign/encrypt settings from
     // main message body. added at the end of the process
     AttachmentPart::List lateAttachmentParts;
-    QList<KMime::Message::Ptr> resultMessages;
+    QVector<KMime::Message::Ptr> resultMessages;
 
     Kleo::CryptoMessageFormat format;
 
@@ -114,30 +104,23 @@ void ComposerPrivate::composeStep1()
 
     // Create skeleton message (containing headers only; no content).
     SkeletonMessageJob *skeletonJob = new SkeletonMessageJob(infoPart, globalPart, q);
-    QObject::connect(skeletonJob, &SkeletonMessageJob::finished, q, [this](KJob *job) {
-        skeletonJobFinished(job);
+    QObject::connect(skeletonJob, &SkeletonMessageJob::finished, q, [this, skeletonJob](KJob *job) {
+        if (job->error()) {
+            return; // KCompositeJob takes care of the error.
+        }
+
+        // SkeletonMessageJob is a special job creating a Message instead of a Content.
+        Q_ASSERT(skeletonMessage == nullptr);
+        skeletonMessage = skeletonJob->message();
+        Q_ASSERT(skeletonMessage);
+        skeletonMessage->assemble();
+
+        composeStep2();
     });
     q->addSubjob(skeletonJob);
     skeletonJob->start();
 }
 
-void ComposerPrivate::skeletonJobFinished(KJob *job)
-{
-    if (job->error()) {
-        return; // KCompositeJob takes care of the error.
-    }
-
-    Q_ASSERT(dynamic_cast<SkeletonMessageJob *>(job));
-    SkeletonMessageJob *sjob = static_cast<SkeletonMessageJob *>(job);
-    // SkeletonMessageJob is a special job creating a Message instead of a Content.
-    Q_ASSERT(skeletonMessage == nullptr);
-    skeletonMessage = sjob->message();
-    Q_ASSERT(skeletonMessage);
-    skeletonMessage->assemble();
-
-    composeStep2();
-}
-
 void ComposerPrivate::composeStep2()
 {
     Q_Q(Composer);
@@ -228,11 +211,15 @@ void ComposerPrivate::composeStep2()
         sJob->setCryptoMessageFormat(format);
         sJob->setSigningKeys(signers);
         sJob->appendSubjob(mainJob);
+        if (!encrypt) {
+            sJob->setSkeletonMessage(skeletonMessage);
+        }
         mainJob = sJob;
     }
 
     if (encrypt) {
-        foreach (ContentJobBase *eJob, createEncryptJobs(mainJob, false)) {
+        const auto lstJob = createEncryptJobs(mainJob, false);
+        for (ContentJobBase *eJob : lstJob) {
             QObject::connect(eJob, SIGNAL(finished(KJob*)), q, SLOT(contentJobFinished(KJob*)));
             q->addSubjob(eJob);
             mainJob = eJob;         //start only last EncryptJob
@@ -278,6 +265,7 @@ QList<ContentJobBase *> ComposerPrivate::createEncryptJobs(ContentJobBase *conte
             seJob->setSigningKeys(signers);
             seJob->setEncryptionKeys(recipients.second);
             seJob->setRecipients(recipients.first);
+            seJob->setSkeletonMessage(skeletonMessage);
 
             subJob = seJob;
         } else {
@@ -285,6 +273,7 @@ QList<ContentJobBase *> ComposerPrivate::createEncryptJobs(ContentJobBase *conte
             eJob->setCryptoMessageFormat(format);
             eJob->setEncryptionKeys(recipients.second);
             eJob->setRecipients(recipients.first);
+            eJob->setSkeletonMessage(skeletonMessage);
             subJob = eJob;
         }
         qCDebug(MESSAGECOMPOSER_LOG) << "subJob" << subJob;
@@ -437,7 +426,7 @@ void ComposerPrivate::composeFinalStep(KMime::Content *headers, KMime::Content *
 {
     content->assemble();
 
-    QByteArray allData = headers->head() + content->encodedContent();
+    const QByteArray allData = headers->head() + content->encodedContent();
     KMime::Message::Ptr resultMessage(new KMime::Message);
     resultMessage->setContent(allData);
     resultMessage->parse(); // Not strictly necessary.
@@ -455,12 +444,12 @@ Composer::~Composer()
 {
 }
 
-QList<KMime::Message::Ptr> Composer::resultMessages() const
+QVector<KMime::Message::Ptr> Composer::resultMessages() const
 {
     Q_D(const Composer);
     Q_ASSERT(d->finished);
     Q_ASSERT(!error());
-    QList<KMime::Message::Ptr> results = d->resultMessages;
+    const QVector<KMime::Message::Ptr> results = d->resultMessages;
     return results;
 }
 
@@ -552,7 +541,7 @@ void Composer::setSigningKeys(std::vector<GpgME::Key> &signers)
     d->signers = signers;
 }
 
-void Composer::setEncryptionKeys(const QList<QPair<QStringList, std::vector<GpgME::Key> > > &encData)
+void Composer::setEncryptionKeys(const QVector<QPair<QStringList, std::vector<GpgME::Key> > > &encData)
 {
     Q_D(Composer);
 
