@@ -1,21 +1,8 @@
 /*
-  Copyright (C) 2010 Klaralvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
-  Copyright (c) 2010 Leo Franchi <lfranchi@kde.org>
+  SPDX-FileCopyrightText: 2010 Klaralvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  SPDX-FileCopyrightText: 2010 Leo Franchi <lfranchi@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "composerviewbase.h"
@@ -26,7 +13,7 @@
 #include "composer-ng/richtextcomposerng.h"
 #include <KPIMTextEdit/RichTextComposerImages>
 #include "composer-ng/richtextcomposersignatures.h"
-#include "KPIMTextEdit/RichTextComposerControler"
+#include <KPIMTextEdit/RichTextComposerControler>
 #include "job/emailaddressresolvejob.h"
 #include "composer/keyresolver.h"
 #include "part/globalpart.h"
@@ -37,10 +24,10 @@
 #include "utils/util_p.h"
 #include "imagescaling/imagescalingutils.h"
 
-#include "SendLater/SendLaterInfo"
-#include "SendLater/SendLaterUtil"
+#include "sendlater/sendlaterinfo.h"
+#include "sendlater/sendlatercreatejob.h"
 
-#include <libkdepim/recentaddresses.h>
+#include <PimCommonAkonadi/RecentAddresses>
 #include "helper/messagehelper.h"
 
 #include <MessageComposer/RecipientsEditor>
@@ -57,9 +44,9 @@
 #include <MessageCore/StringUtil>
 #include <MessageCore/NodeHelper>
 
-#include <mailtransport/transportcombobox.h>
-#include <mailtransportakonadi/messagequeuejob.h>
-#include <mailtransport/transportmanager.h>
+#include <MailTransport/TransportComboBox>
+#include <MailTransportAkonadi/MessageQueueJob>
+#include <MailTransport/TransportManager>
 
 #include <Akonadi/KMime/SpecialMailCollections>
 #include <AkonadiCore/itemcreatejob.h>
@@ -100,17 +87,14 @@ ComposerViewBase::ComposerViewBase(QObject *parent, QWidget *parentGui)
     , m_msg(KMime::Message::Ptr(new KMime::Message))
     , m_parentWidget(parentGui)
     , m_cryptoMessageFormat(Kleo::AutoFormat)
-    , m_autoSaveInterval(1 * 1000 * 60) // default of 1 min
+    , m_autoSaveInterval(60000) // default of 1 min
 {
     m_charsets << "utf-8"; // default, so we have a backup in case client code forgot to set.
 
     initAutoSave();
 }
 
-ComposerViewBase::~ComposerViewBase()
-{
-    delete mSendLaterInfo;
-}
+ComposerViewBase::~ComposerViewBase() = default;
 
 bool ComposerViewBase::isComposing() const
 {
@@ -621,7 +605,7 @@ inline bool showKeyApprovalDialog()
 }
 } // nameless namespace
 
-QList< MessageComposer::Composer * > ComposerViewBase::generateCryptoMessages(bool &wasCanceled)
+QVector< MessageComposer::Composer * > ComposerViewBase::generateCryptoMessages(bool &wasCanceled)
 {
     const KIdentityManagement::Identity &id = m_identMan->identityForUoidOrDefault(m_identityCombo->currentIdentity());
 
@@ -655,7 +639,7 @@ QList< MessageComposer::Composer * > ComposerViewBase::generateCryptoMessages(bo
     }
     if (keyResolver->setEncryptToSelfKeys(encryptToSelfKeys) != Kleo::Ok) {
         qCDebug(MESSAGECOMPOSER_LOG) << "Failed to set encryptoToSelf keys!";
-        return QList< MessageComposer::Composer * >();
+        return QVector< MessageComposer::Composer * >();
     }
 
     //Add signingkeys from id to keyResolver
@@ -667,11 +651,12 @@ QList< MessageComposer::Composer * > ComposerViewBase::generateCryptoMessages(bo
     }
     if (keyResolver->setSigningKeys(signKeys) != Kleo::Ok) {
         qCDebug(MESSAGECOMPOSER_LOG) << "Failed to set signing keys!";
-        return QList< MessageComposer::Composer * >();
+        return QVector< MessageComposer::Composer * >();
     }
 
     if (m_attachmentModel) {
-        foreach (const MessageCore::AttachmentPart::Ptr &attachment, m_attachmentModel->attachments()) {
+        const auto attachments = m_attachmentModel->attachments();
+        for (const MessageCore::AttachmentPart::Ptr &attachment : attachments) {
             if (attachment->isSigned()) {
                 signSomething = true;
             } else {
@@ -685,8 +670,8 @@ QList< MessageComposer::Composer * > ComposerViewBase::generateCryptoMessages(bo
         }
     }
 
-    QStringList recipients(mExpandedTo), bcc(mExpandedBcc);
-    recipients.append(mExpandedCc);
+    const QStringList recipients = mExpandedTo + mExpandedCc;
+    const QStringList bcc(mExpandedBcc);
 
     keyResolver->setPrimaryRecipients(recipients);
     keyResolver->setSecondaryRecipients(bcc);
@@ -703,7 +688,7 @@ QList< MessageComposer::Composer * > ComposerViewBase::generateCryptoMessages(bo
             Q_EMIT failed(QString());
         }
         wasCanceled = canceled;
-        return QList< MessageComposer::Composer *>();
+        return QVector< MessageComposer::Composer *>();
     }
 
     canceled = false;
@@ -718,27 +703,27 @@ QList< MessageComposer::Composer * > ComposerViewBase::generateCryptoMessages(bo
         }
 
         wasCanceled = canceled;
-        return QList< MessageComposer::Composer *>();
+        return QVector< MessageComposer::Composer *>();
     }
 
     //No encryption or signing is needed
     if (!signSomething && !encryptSomething) {
-        return QList< MessageComposer::Composer * >() << new MessageComposer::Composer();
+        return QVector< MessageComposer::Composer * >() << new MessageComposer::Composer();
     }
 
     const Kleo::Result kpgpResult = keyResolver->resolveAllKeys(signSomething, encryptSomething);
     if (kpgpResult == Kleo::Canceled) {
         qCDebug(MESSAGECOMPOSER_LOG) << "resolveAllKeys: one key resolution canceled by user";
-        return QList< MessageComposer::Composer *>();
+        return QVector< MessageComposer::Composer *>();
     } else if (kpgpResult != Kleo::Ok) {
         // TODO handle failure
         qCDebug(MESSAGECOMPOSER_LOG) << "resolveAllKeys: failed to resolve keys! oh noes";
         Q_EMIT failed(i18n("Failed to resolve keys. Please report a bug."));
-        return QList< MessageComposer::Composer *>();
+        return QVector< MessageComposer::Composer *>();
     }
     qCDebug(MESSAGECOMPOSER_LOG) << "done resolving keys:";
 
-    QList< MessageComposer::Composer * > composers;
+    QVector< MessageComposer::Composer * > composers;
 
     if (encryptSomething || signSomething) {
         Kleo::CryptoMessageFormat concreteFormat = Kleo::AutoFormat;
@@ -758,7 +743,7 @@ QList< MessageComposer::Composer * > ComposerViewBase::generateCryptoMessages(bo
                 std::vector<Kleo::KeyResolver::SplitInfo> encData = keyResolver->encryptionItems(concreteFormat);
                 std::vector<Kleo::KeyResolver::SplitInfo>::iterator it;
                 std::vector<Kleo::KeyResolver::SplitInfo>::iterator end(encData.end());
-                QList<QPair<QStringList, std::vector<GpgME::Key> > > data;
+                QVector<QPair<QStringList, std::vector<GpgME::Key> > > data;
                 data.reserve(encData.size());
                 for (it = encData.begin(); it != end; ++it) {
                     QPair<QStringList, std::vector<GpgME::Key> > p(it->recipients, it->keys);
@@ -946,14 +931,17 @@ void ComposerViewBase::slotSendComposeResult(KJob *job)
 void ComposerViewBase::saveRecentAddresses(const KMime::Message::Ptr &msg)
 {
     KConfig *config = MessageComposer::MessageComposerSettings::self()->config();
-    foreach (const QByteArray &address, msg->to()->addresses()) {
-        KPIM::RecentAddresses::self(config)->add(QLatin1String(address));
+    const QVector<QByteArray> toAddresses = msg->to()->addresses();
+    for (const QByteArray &address : toAddresses) {
+        PimCommon::RecentAddresses::self(config)->add(QLatin1String(address));
     }
-    foreach (const QByteArray &address, msg->cc()->addresses()) {
-        KPIM::RecentAddresses::self(config)->add(QLatin1String(address));
+    const QVector<QByteArray> ccAddresses = msg->cc()->addresses();
+    for (const QByteArray &address : ccAddresses) {
+        PimCommon::RecentAddresses::self(config)->add(QLatin1String(address));
     }
-    foreach (const QByteArray &address, msg->bcc()->addresses()) {
-        KPIM::RecentAddresses::self(config)->add(QLatin1String(address));
+    const QVector<QByteArray> bccAddresses = msg->bcc()->addresses();
+    for (const QByteArray &address : bccAddresses) {
+        PimCommon::RecentAddresses::self(config)->add(QLatin1String(address));
     }
 }
 
@@ -1186,7 +1174,7 @@ void ComposerViewBase::slotAutoSaveComposeResult(KJob *job)
         // The messages were composed successfully. Only save the first message, there should
         // only be one anyway, since crypto is disabled.
         qCDebug(MESSAGECOMPOSER_LOG) << "NoError.";
-        writeAutoSaveToDisk(composer->resultMessages().first());
+        writeAutoSaveToDisk(composer->resultMessages().constFirst());
         Q_ASSERT(composer->resultMessages().size() == 1);
 
         if (m_autoSaveInterval > 0) {
@@ -1248,6 +1236,7 @@ void ComposerViewBase::writeAutoSaveToDisk(const KMime::Message::Ptr &message)
         m_autoSaveErrorShown = false;
     }
     file.commit();
+    message->clear();
 }
 
 void ComposerViewBase::saveMessage(const KMime::Message::Ptr &message, MessageComposer::MessageSender::SaveIn saveIn)
@@ -1272,19 +1261,17 @@ void ComposerViewBase::saveMessage(const KMime::Message::Ptr &message, MessageCo
     Akonadi::MessageFlags::copyMessageFlags(*message, item);
 
     if (!identity.isNull()) {   // we have a valid identity
-        switch(saveIn) {
-        case MessageComposer::MessageSender::SaveInTemplates: {
+        switch (saveIn) {
+        case MessageComposer::MessageSender::SaveInTemplates:
             if (!identity.templates().isEmpty()) {   // the user has specified a custom templates collection
                 target = Akonadi::Collection(identity.templates().toLongLong());
             }
             break;
-        }
-        case MessageComposer::MessageSender::SaveInDrafts: {
+        case MessageComposer::MessageSender::SaveInDrafts:
             if (!identity.drafts().isEmpty()) {   // the user has specified a custom drafts collection
                 target = Akonadi::Collection(identity.drafts().toLongLong());
             }
             break;
-        }
         case MessageComposer::MessageSender::SaveInOutbox: //We don't define save outbox in identity
             target = Akonadi::SpecialMailCollections::self()->defaultCollection(Akonadi::SpecialMailCollections::Outbox);
             break;
@@ -1326,7 +1313,7 @@ void ComposerViewBase::slotSaveMessage(KJob *job)
 Akonadi::Collection ComposerViewBase::defaultSpecialTarget() const
 {
     Akonadi::Collection target;
-    switch(mSaveIn) {
+    switch (mSaveIn) {
     case MessageComposer::MessageSender::SaveInNone:
         break;
     case MessageComposer::MessageSender::SaveInDrafts:
@@ -1361,10 +1348,7 @@ void ComposerViewBase::slotCreateItemResult(KJob *job)
         const Akonadi::Item item = createJob->item();
         if (item.isValid()) {
             id = item.id();
-            mSendLaterInfo->setItemId(id);
-            SendLater::SendLaterUtil::writeSendLaterInfo(SendLater::SendLaterUtil::defaultConfig(), mSendLaterInfo);
-            delete mSendLaterInfo;
-            mSendLaterInfo = nullptr;
+            addSendLaterItem(item);
         }
     }
 
@@ -1403,25 +1387,25 @@ void ComposerViewBase::addAttachmentPart(KMime::Content *partToAttach)
 {
     MessageCore::AttachmentPart::Ptr part(new MessageCore::AttachmentPart);
     if (partToAttach->contentType()->mimeType() == "multipart/digest"
-        || partToAttach->contentType()->mimeType() == "message/rfc822") {
+        || partToAttach->contentType(false)->mimeType() == "message/rfc822") {
         // if it is a digest or a full message, use the encodedContent() of the attachment,
         // which already has the proper headers
         part->setData(partToAttach->encodedContent());
     } else {
         part->setData(partToAttach->decodedContent());
     }
-    part->setMimeType(partToAttach->contentType()->mimeType());
-    if (partToAttach->contentDescription(false)) {
-        part->setDescription(partToAttach->contentDescription()->asUnicodeString());
+    part->setMimeType(partToAttach->contentType(false)->mimeType());
+    if (auto cd = partToAttach->contentDescription(false)) {
+        part->setDescription(cd->asUnicodeString());
     }
-    if (partToAttach->contentType(false)) {
-        if (partToAttach->contentType()->hasParameter(QStringLiteral("name"))) {
-            part->setName(partToAttach->contentType()->parameter(QStringLiteral("name")));
+    if (auto ct = partToAttach->contentType(false)) {
+        if (ct->hasParameter(QStringLiteral("name"))) {
+            part->setName(ct->parameter(QStringLiteral("name")));
         }
     }
-    if (partToAttach->contentDisposition(false)) {
-        part->setFileName(partToAttach->contentDisposition()->filename());
-        part->setInline(partToAttach->contentDisposition()->disposition() == KMime::Headers::CDinline);
+    if (auto cd = partToAttach->contentDisposition(false)) {
+        part->setFileName(cd->filename());
+        part->setInline(cd->disposition() == KMime::Headers::CDinline);
     }
     if (part->name().isEmpty() && !part->fileName().isEmpty()) {
         part->setName(part->fileName());
@@ -1692,7 +1676,7 @@ void ComposerViewBase::setCryptoOptions(bool sign, bool encrypt, Kleo::CryptoMes
     m_neverEncrypt = neverEncryptDrafts;
 }
 
-void ComposerViewBase::setCharsets(const QList< QByteArray > &charsets)
+void ComposerViewBase::setCharsets(const QVector< QByteArray > &charsets)
 {
     m_charsets = charsets;
 }
@@ -1792,7 +1776,8 @@ ComposerViewBase::MissingAttachment ComposerViewBase::checkForMissingAttachments
 void ComposerViewBase::markAllAttachmentsForSigning(bool sign)
 {
     if (m_attachmentModel) {
-        foreach (MessageCore::AttachmentPart::Ptr attachment, m_attachmentModel->attachments()) {
+        const auto attachments = m_attachmentModel->attachments();
+        for (MessageCore::AttachmentPart::Ptr attachment : attachments) {
             attachment->setSigned(sign);
         }
     }
@@ -1801,7 +1786,8 @@ void ComposerViewBase::markAllAttachmentsForSigning(bool sign)
 void ComposerViewBase::markAllAttachmentsForEncryption(bool encrypt)
 {
     if (m_attachmentModel) {
-        foreach (MessageCore::AttachmentPart::Ptr attachment, m_attachmentModel->attachments()) {
+        const auto attachments = m_attachmentModel->attachments();
+        for (MessageCore::AttachmentPart::Ptr attachment : attachments) {
             attachment->setEncrypted(encrypt);
         }
     }
@@ -2087,15 +2073,14 @@ bool ComposerViewBase::determineWhetherToEncrypt(bool doEncryptCompletely, Kleo:
     return encrypt || doEncryptCompletely;
 }
 
-void ComposerViewBase::setSendLaterInfo(SendLater::SendLaterInfo *info)
+void ComposerViewBase::setSendLaterInfo(SendLaterInfo *info)
 {
-    delete mSendLaterInfo;
-    mSendLaterInfo = info;
+    mSendLaterInfo.reset(info);
 }
 
-SendLater::SendLaterInfo *ComposerViewBase::sendLaterInfo() const
+SendLaterInfo *ComposerViewBase::sendLaterInfo() const
 {
-    return mSendLaterInfo;
+    return mSendLaterInfo.get();
 }
 
 void ComposerViewBase::addFollowupReminder(const QString &messageId)
@@ -2113,6 +2098,14 @@ void ComposerViewBase::addFollowupReminder(const QString &messageId)
     }
 }
 
+void ComposerViewBase::addSendLaterItem(const Akonadi::Item &item)
+{
+    mSendLaterInfo->setItemId(item.id());
+
+    auto job = new MessageComposer::SendLaterCreateJob(*mSendLaterInfo, this);
+    job->start();
+}
+
 bool ComposerViewBase::requestDeleveryConfirmation() const
 {
     return m_requestDeleveryConfirmation;
