@@ -2,43 +2,20 @@
     keyresolver.cpp
 
     This file is part of libkleopatra, the KDE keymanagement library
-    Copyright (c) 2004 Klarälvdalens Datakonsult AB
+    SPDX-FileCopyrightText: 2004 Klarälvdalens Datakonsult AB
 
     Based on kpgp.cpp
     Copyright (C) 2001,2002 the KPGP authors
     See file libkdenetwork/AUTHORS.kpgp for details
 
-    Libkleopatra is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of the
-    License, or (at your option) any later version.
-
-    Libkleopatra is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "composer/keyresolver.h"
 #include "job/savecontactpreferencejob.h"
 
 #ifndef QT_NO_CURSOR
-#include "Libkdepim/KCursorSaver"
+#include <Libkdepim/KCursorSaver>
 #endif
 #include "utils/kleo_util.h"
 
@@ -55,8 +32,7 @@
 #include <Akonadi/Contact/ContactSearchJob>
 #include <KLocalizedString>
 #include "messagecomposer_debug.h"
-#include <qinputdialog.h>
-#include <kmessagebox.h>
+#include <KMessageBox>
 
 #include <QStringList>
 #include <QPointer>
@@ -113,11 +89,6 @@ CopyKeysAndEncryptionPreferences(const Kleo::KeyResolver::Item &oldItem, const K
     return Kleo::KeyResolver::Item(oldItem.address, newItem.keys, newItem.pref, oldItem.signPref, oldItem.format);
 }
 
-static inline bool WithRespectToKeyID(const GpgME::Key &left, const GpgME::Key &right)
-{
-    return qstrcmp(left.keyID(), right.keyID()) == 0;
-}
-
 static bool ValidOpenPGPEncryptionKey(const GpgME::Key &key)
 {
     if (key.protocol() != GpgME::OpenPGP) {
@@ -226,21 +197,11 @@ static inline bool NotValidTrustedOpenPGPEncryptionKey(const GpgME::Key &key)
     return !ValidTrustedOpenPGPEncryptionKey(key);
 }
 
-static inline bool NotValidOpenPGPEncryptionKey(const GpgME::Key &key)
-{
-    return !ValidOpenPGPEncryptionKey(key);
-}
-
 static inline bool NotValidTrustedSMIMEEncryptionKey(const GpgME::Key &key)
 {
     return !ValidTrustedSMIMEEncryptionKey(key);
 }
 
-static inline bool NotValidSMIMEEncryptionKey(const GpgME::Key &key)
-{
-    return !ValidSMIMEEncryptionKey(key);
-}
-
 static inline bool NotValidTrustedEncryptionKey(const GpgME::Key &key)
 {
     return !ValidTrustedEncryptionKey(key);
@@ -251,11 +212,6 @@ static inline bool NotValidEncryptionKey(const GpgME::Key &key)
     return !ValidEncryptionKey(key);
 }
 
-static inline bool NotValidSigningKey(const GpgME::Key &key)
-{
-    return !ValidSigningKey(key);
-}
-
 static inline bool NotValidOpenPGPSigningKey(const GpgME::Key &key)
 {
     return !ValidOpenPGPSigningKey(key);
@@ -317,12 +273,13 @@ static QStringList keysAsStrings(const std::vector<GpgME::Key> &keys)
     strings.reserve(keys.size());
     for (std::vector<GpgME::Key>::const_iterator it = keys.begin(); it != keys.end(); ++it) {
         assert(!(*it).userID(0).isNull());
-        QString keyLabel = QString::fromUtf8((*it).userID(0).email());
+        const auto userID = (*it).userID(0);
+        QString keyLabel = QString::fromUtf8(userID.email());
         if (keyLabel.isEmpty()) {
-            keyLabel = QString::fromUtf8((*it).userID(0).name());
+            keyLabel = QString::fromUtf8(userID.name());
         }
         if (keyLabel.isEmpty()) {
-            keyLabel = QString::fromUtf8((*it).userID(0).id());
+            keyLabel = QString::fromUtf8(userID.id());
         }
         strings.append(keyLabel);
     }
@@ -427,13 +384,6 @@ class Kleo::KeyResolver::SigningPreferenceCounter : public std::unary_function<K
 {
 public:
     SigningPreferenceCounter()
-        : mTotal(0)
-        , mUnknownSigningPreference(0)
-        , mNeverSign(0)
-        , mAlwaysSign(0)
-        , mAlwaysSignIfPossible(0)
-        , mAlwaysAskForSigning(0)
-        , mAskSigningWheneverPossible(0)
     {
     }
 
@@ -448,9 +398,13 @@ public:
     make_int_accessor(Total)
 #undef make_int_accessor
 private:
-    unsigned int mTotal;
-    unsigned int mUnknownSigningPreference, mNeverSign, mAlwaysSign,
-                 mAlwaysSignIfPossible, mAlwaysAskForSigning, mAskSigningWheneverPossible;
+    unsigned int mTotal = 0;
+    unsigned int mUnknownSigningPreference = 0;
+    unsigned int mNeverSign = 0;
+    unsigned int mAlwaysSign = 0;
+    unsigned int mAlwaysSignIfPossible = 0;
+    unsigned int mAlwaysAskForSigning = 0;
+    unsigned int mAskSigningWheneverPossible = 0;
 };
 
 void Kleo::KeyResolver::SigningPreferenceCounter::operator()(const Kleo::KeyResolver::Item &item)
@@ -476,14 +430,6 @@ public:
     EncryptionPreferenceCounter(const Kleo::KeyResolver *kr, EncryptionPreference defaultPreference)
         : _this(kr)
         , mDefaultPreference(defaultPreference)
-        , mTotal(0)
-        , mNoKey(0)
-        , mNeverEncrypt(0)
-        , mUnknownPreference(0)
-        , mAlwaysEncrypt(0)
-        , mAlwaysEncryptIfPossible(0)
-        , mAlwaysAskForEncryption(0)
-        , mAskWheneverPossible(0)
     {
     }
 
@@ -507,10 +453,14 @@ public:
 #undef make_int_accessor
 private:
     EncryptionPreference mDefaultPreference;
-    unsigned int mTotal;
-    unsigned int mNoKey;
-    unsigned int mNeverEncrypt, mUnknownPreference, mAlwaysEncrypt,
-                 mAlwaysEncryptIfPossible, mAlwaysAskForEncryption, mAskWheneverPossible;
+    unsigned int mTotal = 0;
+    unsigned int mNoKey = 0;
+    unsigned int mNeverEncrypt = 0;
+    unsigned int mUnknownPreference = 0;
+    unsigned int mAlwaysEncrypt = 0;
+    unsigned int mAlwaysEncryptIfPossible = 0;
+    unsigned int mAlwaysAskForEncryption = 0;
+    unsigned int mAskWheneverPossible = 0;
 };
 
 void Kleo::KeyResolver::EncryptionPreferenceCounter::operator()(Item &item)
@@ -543,11 +493,6 @@ class FormatPreferenceCounterBase : public std::unary_function<Kleo::KeyResolver
 {
 public:
     FormatPreferenceCounterBase()
-        : mTotal(0)
-        , mInlineOpenPGP(0)
-        , mOpenPGPMIME(0)
-        , mSMIME(0)
-        , mSMIMEOpaque(0)
     {
     }
 
@@ -576,8 +521,11 @@ public:
     }
 
 protected:
-    unsigned int mTotal;
-    unsigned int mInlineOpenPGP, mOpenPGPMIME, mSMIME, mSMIMEOpaque;
+    unsigned int mTotal = 0;
+    unsigned int mInlineOpenPGP = 0;
+    unsigned int mOpenPGPMIME = 0;
+    unsigned int mSMIME = 0;
+    unsigned int mSMIMEOpaque = 0;
 };
 
 class EncryptionFormatPreferenceCounter : public FormatPreferenceCounterBase
@@ -666,9 +614,9 @@ struct Q_DECL_HIDDEN Kleo::KeyResolver::Private {
     ContactPreferencesMap mContactPreferencesMap;
 };
 
-Kleo::KeyResolver::KeyResolver(bool encToSelf, bool showApproval, bool oppEncryption, unsigned int f, int encrWarnThresholdKey, int signWarnThresholdKey, int encrWarnThresholdRootCert,
-                               int signWarnThresholdRootCert, int encrWarnThresholdChainCert, int signWarnThresholdChainCert)
-    : mEncryptToSelf(encToSelf)
+Kleo::KeyResolver::KeyResolver(bool encToSelf, bool showApproval, bool oppEncryption, unsigned int f, int encrWarnThresholdKey, int signWarnThresholdKey, int encrWarnThresholdRootCert, int signWarnThresholdRootCert, int encrWarnThresholdChainCert, int signWarnThresholdChainCert)
+    : d(new Private)
+    , mEncryptToSelf(encToSelf)
     , mShowApprovalDialog(showApproval)
     , mOpportunisticEncyption(oppEncryption)
     , mCryptoMessageFormats(f)
@@ -679,13 +627,11 @@ Kleo::KeyResolver::KeyResolver(bool encToSelf, bool showApproval, bool oppEncryp
     , mEncryptChainCertNearExpiryWarningThreshold(encrWarnThresholdChainCert)
     , mSigningChainCertNearExpiryWarningThreshold(signWarnThresholdChainCert)
 {
-    d = new Private();
 }
 
 Kleo::KeyResolver::~KeyResolver()
 {
     delete d;
-    d = nullptr;
 }
 
 Kleo::Result Kleo::KeyResolver::checkKeyNearExpiry(const GpgME::Key &key, const char *dontAskAgainName, bool mine, bool sign, bool ca, int recur_limit, const GpgME::Key &orig) const
@@ -1002,7 +948,7 @@ Kleo::Result Kleo::KeyResolver::setSigningKeys(const QStringList &fingerprints)
 
     // check for near expiry:
 
-    for (std::vector<GpgME::Key>::const_iterator it = d->mOpenPGPSigningKeys.begin(); it != d->mOpenPGPSigningKeys.end(); ++it) {
+    for (std::vector<GpgME::Key>::const_iterator it = d->mOpenPGPSigningKeys.begin(), total = d->mOpenPGPSigningKeys.end(); it != total; ++it) {
         const Kleo::Result r = checkKeyNearExpiry(*it, "signing key expires soon warning",
                                                   true, true);
         if (r != Kleo::Ok) {
@@ -1010,7 +956,7 @@ Kleo::Result Kleo::KeyResolver::setSigningKeys(const QStringList &fingerprints)
         }
     }
 
-    for (std::vector<GpgME::Key>::const_iterator it = d->mSMIMESigningKeys.begin(); it != d->mSMIMESigningKeys.end(); ++it) {
+    for (std::vector<GpgME::Key>::const_iterator it = d->mSMIMESigningKeys.begin(), total = d->mSMIMESigningKeys.end(); it != total; ++it) {
         const Kleo::Result r = checkKeyNearExpiry(*it, "signing key expires soon warning",
                                                   true, true);
         if (r != Kleo::Ok) {
@@ -1212,7 +1158,7 @@ Kleo::Result Kleo::KeyResolver::resolveEncryptionKeys(bool signingRequested, boo
         qCDebug(MESSAGECOMPOSER_LOG) << "set key data:" << int(it->pref) << int(it->signPref) << int(it->format);
     }
 
-    for (std::vector<Item>::iterator it = d->mSecondaryEncryptionKeys.begin(); it != d->mSecondaryEncryptionKeys.end(); ++it) {
+    for (std::vector<Item>::iterator it = d->mSecondaryEncryptionKeys.begin(), total = d->mSecondaryEncryptionKeys.end(); it != total; ++it) {
         if (!it->needKeys) {
             continue;
         }
@@ -1288,7 +1234,7 @@ Kleo::Result Kleo::KeyResolver::resolveEncryptionKeys(bool signingRequested, boo
 
     for (unsigned int i = 0; i < numConcreteCryptoMessageFormats; ++i) {
         const std::vector<SplitInfo> si_list = encryptionItems(concreteCryptoMessageFormats[i]);
-        for (std::vector<SplitInfo>::const_iterator sit = si_list.begin(); sit != si_list.end(); ++sit) {
+        for (std::vector<SplitInfo>::const_iterator sit = si_list.begin(), total = si_list.end(); sit != total; ++sit) {
             for (std::vector<GpgME::Key>::const_iterator kit = sit->keys.begin(); kit != sit->keys.end(); ++kit) {
                 const Kleo::Result r = checkKeyNearExpiry(*kit, "other encryption key near expiry warning",
                                                           false, false);
@@ -1438,14 +1384,15 @@ Kleo::Result Kleo::KeyResolver::resolveSigningKeysForSigningOnly()
     CryptoMessageFormat commonFormat = AutoFormat;
 
     for (unsigned int i = 0; i < numConcreteCryptoMessageFormats; ++i) {
-        if (!(mCryptoMessageFormats & concreteCryptoMessageFormats[i])) {
+        const auto res = concreteCryptoMessageFormats[i];
+        if (!(mCryptoMessageFormats & res)) {
             continue;    // skip
         }
-        if (signingKeysFor(concreteCryptoMessageFormats[i]).empty()) {
+        if (signingKeysFor(res).empty()) {
             continue;    // skip
         }
-        if (count.numOf(concreteCryptoMessageFormats[i]) == count.numTotal()) {
-            commonFormat = concreteCryptoMessageFormats[i];
+        if (count.numOf(res) == count.numTotal()) {
+            commonFormat = res;
             break;
         }
     }
@@ -1521,7 +1468,7 @@ void Kleo::KeyResolver::collapseAllSplitInfos()
         SplitInfo &si = v.front();
         for (std::vector<SplitInfo>::const_iterator it = v.begin() + 1; it != v.end(); ++it) {
             si.keys.insert(si.keys.end(), it->keys.begin(), it->keys.end());
-            qCopy(it->recipients.begin(), it->recipients.end(), std::back_inserter(si.recipients));
+            std::copy(it->recipients.begin(), it->recipients.end(), std::back_inserter(si.recipients));
         }
         v.resize(1);
     }
@@ -1570,7 +1517,7 @@ void Kleo::KeyResolver::dump() const
                 qCDebug(MESSAGECOMPOSER_LOG) << "  " << kit->shortKeyID();
             }
             qCDebug(MESSAGECOMPOSER_LOG) << "  SplitInfo #" << i << " recipients: "
-                                         << qPrintable(sit->recipients.join(QStringLiteral(", ")));
+                                         << qPrintable(sit->recipients.join(QLatin1String(", ")));
         }
     }
 #endif
@@ -1621,7 +1568,7 @@ Kleo::Result Kleo::KeyResolver::showKeyApprovalDialog(bool &finalySendUnencrypte
     delete dlg;
 
     if (prefsChanged) {
-        for (uint i = 0; i < items.size(); ++i) {
+        for (uint i = 0, total = items.size(); i < total; ++i) {
             ContactPreferences pref = lookupContactPreferences(items[i].address);
             pref.encryptionPreference = items[i].pref;
             pref.pgpKeyFingerprints.clear();
@@ -1751,12 +1698,12 @@ std::vector<GpgME::Key> Kleo::KeyResolver::selectKeys(
 
     QPointer<Kleo::KeySelectionDialog> dlg
         = new Kleo::KeySelectionDialog(
-        i18n("Encryption Key Selection"),
-        msg, KEmailAddress::extractEmailAddress(person), selectedKeys,
-        Kleo::KeySelectionDialog::ValidEncryptionKeys
-        & ~(opgp ? 0 : Kleo::KeySelectionDialog::OpenPGPKeys)
-        & ~(x509 ? 0 : Kleo::KeySelectionDialog::SMIMEKeys),
-        true, true);  // multi-selection and "remember choice" box
+              i18n("Encryption Key Selection"),
+              msg, KEmailAddress::extractEmailAddress(person), selectedKeys,
+              Kleo::KeySelectionDialog::ValidEncryptionKeys
+              & ~(opgp ? 0 : Kleo::KeySelectionDialog::OpenPGPKeys)
+              & ~(x509 ? 0 : Kleo::KeySelectionDialog::SMIMEKeys),
+              true, true); // multi-selection and "remember choice" box
 
     if (dlg->exec() != QDialog::Accepted) {
         delete dlg;
@@ -1784,7 +1731,7 @@ std::vector<GpgME::Key> Kleo::KeyResolver::getEncryptionKeys(const QString &pers
 
     if (!fingerprints.empty()) {
         qCDebug(MESSAGECOMPOSER_LOG) << "Using encryption keys 0x"
-                                     << fingerprints.join(QStringLiteral(", 0x"))
+                                     << fingerprints.join(QLatin1String(", 0x"))
                                      << "for" << person;
         std::vector<GpgME::Key> keys = lookup(fingerprints);
         if (!keys.empty()) {
@@ -1867,7 +1814,7 @@ std::vector<GpgME::Key> Kleo::KeyResolver::lookup(const QStringList &patterns, b
     if (patterns.empty()) {
         return std::vector<GpgME::Key>();
     }
-    qCDebug(MESSAGECOMPOSER_LOG) << "( \"" << patterns.join(QStringLiteral("\", \"")) << "\"," << secret << ")";
+    qCDebug(MESSAGECOMPOSER_LOG) << "( \"" << patterns.join(QLatin1String("\", \"")) << "\"," << secret << ")";
     std::vector<GpgME::Key> result;
     if (mCryptoMessageFormats & (InlineOpenPGPFormat | OpenPGPMIMEFormat)) {
         if (const QGpgME::Protocol *p = QGpgME::openpgp()) {
@@ -1940,6 +1887,7 @@ void Kleo::KeyResolver::addKeys(const std::vector<Item> &items)
 
 Kleo::KeyResolver::ContactPreferences Kleo::KeyResolver::lookupContactPreferences(const QString &address) const
 {
+#ifdef HAVE_A_FIX_FOR_LOCK
     const Private::ContactPreferencesMap::iterator it
         = d->mContactPreferencesMap.find(address);
     if (it != d->mContactPreferencesMap.end()) {
@@ -1961,12 +1909,24 @@ Kleo::KeyResolver::ContactPreferences Kleo::KeyResolver::lookupContactPreference
         pref.signingPreference = Kleo::stringToSigningPreference(signPref);
         QString cryptoFormats = addr.custom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("CRYPTOPROTOPREF"));
         pref.cryptoMessageFormat = Kleo::stringToCryptoMessageFormat(cryptoFormats);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         pref.pgpKeyFingerprints = addr.custom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("OPENPGPFP")).split(QLatin1Char(','), QString::SkipEmptyParts);
+#else
+        pref.pgpKeyFingerprints = addr.custom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("OPENPGPFP")).split(QLatin1Char(','), Qt::SkipEmptyParts);
+#endif
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         pref.smimeCertFingerprints = addr.custom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("SMIMEFP")).split(QLatin1Char(','), QString::SkipEmptyParts);
+#else
+        pref.smimeCertFingerprints = addr.custom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("SMIMEFP")).split(QLatin1Char(','), Qt::SkipEmptyParts);
+#endif
     }
     // insert into map and grab resulting iterator
     d->mContactPreferencesMap.insert(std::make_pair(address, pref));
     return pref;
+#else
+    Q_UNUSED(address)
+    return ContactPreferences();
+#endif
 }
 
 void Kleo::KeyResolver::saveContactPreference(const QString &email, const ContactPreferences &pref) const
