@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2014-2019 Montel Laurent <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef MESSAGECOMPOSER_FOLLOWUPREMINDERCREATEJOB_H
@@ -24,9 +11,12 @@
 #include <QDate>
 #include <AkonadiCore/Item>
 #include <AkonadiCore/Collection>
-#include "FollowupReminder/FollowUpReminderInfo"
 #include <KJob>
+
 #include "messagecomposer_export.h"
+
+#include <memory>
+
 namespace MessageComposer {
 class FollowupReminderCreateJobPrivate;
 /**
@@ -56,9 +46,11 @@ public:
 
 private Q_SLOTS:
     void slotCreateNewTodo(KJob *job);
+
 private:
     void writeFollowupReminderInfo();
-    FollowupReminderCreateJobPrivate *const d;
+
+    std::unique_ptr<FollowupReminderCreateJobPrivate> const d;
 };
 }
 
