@@ -1,24 +1,11 @@
 /*
-   Copyright (c) 2017 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MESSAGEFACTORYFORWARDJOB_H
-#define MESSAGEFACTORYFORWARDJOB_H
+#ifndef MESSAGECOMPOSER_MESSAGEFACTORYFORWARDJOB_H
+#define MESSAGECOMPOSER_MESSAGEFACTORYFORWARDJOB_H
 
 #include <QObject>
 #include <KMime/Message>
@@ -55,11 +42,11 @@ private:
 
     QString mSelection;
     QString mTemplate;
-    KMime::Message::Ptr mMsg;
-    KMime::Message::Ptr mOrigMsg;
+    KMime::Message::Ptr mMsg = nullptr;
+    KMime::Message::Ptr mOrigMsg = nullptr;
     Akonadi::Collection mCollection;
     KIdentityManagement::IdentityManager *mIdentityManager = nullptr;
 };
 }
 
-#endif // MESSAGEFACTORYFORWARDJOB_H
+#endif
