@@ -1,21 +1,9 @@
 /*
-  Copyright (C) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
-  Copyright (c) 2010 Leo Franchi <lfranchi@kde.org>
-  Copyright (C) 2017-2019 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+  SPDX-FileCopyrightText: 2010 Leo Franchi <lfranchi@kde.org>
+  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "messagefactoryng.h"
@@ -40,9 +28,9 @@
 #include "helper/messagehelper.h"
 #include <KLocalizedString>
 #include "messagecomposer_debug.h"
-#include <kcharsets.h>
-#include <QTextCodec>
 #include <KCharsets>
+#include <QRegularExpression>
+#include <QTextCodec>
 
 using namespace MessageComposer;
 
@@ -75,14 +63,12 @@ static KMime::Types::Mailbox::List stripMyAddressesFromAddressList(const KMime::
 
 MessageFactoryNG::MessageFactoryNG(const KMime::Message::Ptr &origMsg, Akonadi::Item::Id id, const Akonadi::Collection &col, QObject *parent)
     : QObject(parent)
-    , m_identityManager(nullptr)
-    , m_origMsg(origMsg)
-    , m_folderId(0)
-    , m_parentFolderId(0)
-    , m_collection(col)
-    , m_replyStrategy(MessageComposer::ReplySmart)
-    , m_quote(true)
-    , m_id(id)
+    , mOrigMsg(origMsg)
+    , mFolderId(0)
+    , mParentFolderId(0)
+    , mCollection(col)
+    , mReplyStrategy(MessageComposer::ReplySmart)
+    , mId(id)
 {
 }
 
@@ -93,8 +79,7 @@ MessageFactoryNG::~MessageFactoryNG()
 // Return the addresses to use when replying to the author of msg.
 // See <https://cr.yp.to/proto/replyto.html>.
 static KMime::Types::Mailbox::List authorMailboxes(
-    const KMime::Message::Ptr &msg,
-    KMime::Types::Mailbox::List mailingLists)
+    const KMime::Message::Ptr &msg, const KMime::Types::Mailbox::List &mailingLists)
 {
     if (auto mrt = msg->headerByType("Mail-Reply-To")) {
         return KMime::Types::Mailbox::listFrom7BitString(mrt->as7BitString(false));
@@ -116,14 +101,14 @@ void MessageFactoryNG::slotCreateReplyDone(const KMime::Message::Ptr &msg, bool
 {
     applyCharset(msg);
 
-    MessageComposer::Util::addLinkInformation(msg, m_id, Akonadi::MessageStatus::statusReplied());
-    if (m_parentFolderId > 0) {
+    MessageComposer::Util::addLinkInformation(msg, mId, Akonadi::MessageStatus::statusReplied());
+    if (mParentFolderId > 0) {
         KMime::Headers::Generic *header = new KMime::Headers::Generic("X-KMail-Fcc");
-        header->fromUnicodeString(QString::number(m_parentFolderId), "utf-8");
+        header->fromUnicodeString(QString::number(mParentFolderId), "utf-8");
         msg->setHeader(header);
     }
 
-    if (auto hrd = m_origMsg->headerByType("X-KMail-EncryptActionEnabled")) {
+    if (auto hrd = mOrigMsg->headerByType("X-KMail-EncryptActionEnabled")) {
         if (hrd->as7BitString(false).contains("true")) {
             auto header = new KMime::Headers::Generic("X-KMail-EncryptActionEnabled");
             header->fromUnicodeString(QStringLiteral("true"), "utf-8");
@@ -146,42 +131,43 @@ void MessageFactoryNG::createReplyAsync()
     KMime::Types::Mailbox::List toList;
     KMime::Types::Mailbox::List replyToList;
 
-    const uint originalIdentity = identityUoid(m_origMsg);
-    MessageHelper::initFromMessage(msg, m_origMsg, m_identityManager, originalIdentity);
-    replyToList = m_origMsg->replyTo()->mailboxes();
+    const uint originalIdentity = identityUoid(mOrigMsg);
+    MessageHelper::initFromMessage(msg, mOrigMsg, mIdentityManager, originalIdentity);
+    replyToList = mOrigMsg->replyTo()->mailboxes();
 
     msg->contentType()->setCharset("utf-8");
 
-    if (auto hdr = m_origMsg->headerByType("List-Post")) {
-        const QString hdrListPost = hdr->asUnicodeString();
-        if (hdrListPost.contains(QLatin1String("mailto:"), Qt::CaseInsensitive)) {
-            QRegExp rx(QStringLiteral("<mailto:([^@>]+)@([^>]+)>"), Qt::CaseInsensitive);
-            if (rx.indexIn(hdrListPost, 0) != -1) {   // matched
-                KMime::Types::Mailbox mailbox;
-                mailbox.fromUnicodeString(rx.cap(1) + QLatin1Char('@') + rx.cap(2));
-                m_mailingListAddresses << mailbox;
-            }
+    if (auto hdr = mOrigMsg->headerByType("List-Post")) {
+        static const QRegularExpression rx {
+            QStringLiteral("<\\s*mailto\\s*:([^@>]+@[^>]+)>"),
+            QRegularExpression::CaseInsensitiveOption
+        };
+        const auto match = rx.match(hdr->asUnicodeString());
+        if (match.hasMatch()) {
+            KMime::Types::Mailbox mailbox;
+            mailbox.fromUnicodeString(match.captured(1));
+            mMailingListAddresses << mailbox;
         }
     }
 
-    switch (m_replyStrategy) {
+    switch (mReplyStrategy) {
     case MessageComposer::ReplySmart:
     {
-        if (auto hdr = m_origMsg->headerByType("Mail-Followup-To")) {
+        if (auto hdr = mOrigMsg->headerByType("Mail-Followup-To")) {
             toList << KMime::Types::Mailbox::listFrom7BitString(hdr->as7BitString(false));
-        } else if (!m_mailingListAddresses.isEmpty()) {
+        } else if (!mMailingListAddresses.isEmpty()) {
             if (replyToList.isEmpty()) {
-                toList = (KMime::Types::Mailbox::List() << m_mailingListAddresses.at(0));
+                toList = (KMime::Types::Mailbox::List() << mMailingListAddresses.at(0));
             } else {
                 toList = replyToList;
             }
         } else {
             // Doesn't seem to be a mailing list.
-            auto originalFromList = m_origMsg->from()->mailboxes();
-            auto originalToList = m_origMsg->to()->mailboxes();
+            auto originalFromList = mOrigMsg->from()->mailboxes();
+            auto originalToList = mOrigMsg->to()->mailboxes();
 
-            if (m_identityManager->thatIsMe(KMime::Types::Mailbox::listToUnicodeString(originalFromList))
-                && !m_identityManager->thatIsMe(KMime::Types::Mailbox::listToUnicodeString(originalToList))
+            if (mIdentityManager->thatIsMe(KMime::Types::Mailbox::listToUnicodeString(originalFromList))
+                && !mIdentityManager->thatIsMe(KMime::Types::Mailbox::listToUnicodeString(originalToList))
                 ) {
                 // Sender seems to be one of our own identities and recipient is not,
                 // so we assume that this is a reply to a "sent" mail where the user
@@ -189,7 +175,7 @@ void MessageFactoryNG::createReplyAsync()
                 toList = originalToList;
             } else {
                 // "Normal" case:  reply to sender.
-                toList = authorMailboxes(m_origMsg, m_mailingListAddresses);
+                toList = authorMailboxes(mOrigMsg, mMailingListAddresses);
             }
 
             replyAll = false;
@@ -197,7 +183,7 @@ void MessageFactoryNG::createReplyAsync()
         // strip all my addresses from the list of recipients
         const KMime::Types::Mailbox::List recipients = toList;
 
-        toList = stripMyAddressesFromAddressList(recipients, m_identityManager);
+        toList = stripMyAddressesFromAddressList(recipients, mIdentityManager);
 
         // ... unless the list contains only my addresses (reply to self)
         if (toList.isEmpty() && !recipients.isEmpty()) {
@@ -207,12 +193,12 @@ void MessageFactoryNG::createReplyAsync()
     }
     case MessageComposer::ReplyList:
     {
-        if (auto hdr = m_origMsg->headerByType("Mail-Followup-To")) {
+        if (auto hdr = mOrigMsg->headerByType("Mail-Followup-To")) {
             KMime::Types::Mailbox mailbox;
             mailbox.from7BitString(hdr->as7BitString(false));
             toList << mailbox;
-        } else if (!m_mailingListAddresses.isEmpty()) {
-            toList << m_mailingListAddresses[ 0 ];
+        } else if (!mMailingListAddresses.isEmpty()) {
+            toList << mMailingListAddresses[ 0 ];
         } else if (!replyToList.isEmpty()) {
             // assume a Reply-To header mangling mailing list
             toList = replyToList;
@@ -221,36 +207,36 @@ void MessageFactoryNG::createReplyAsync()
         // strip all my addresses from the list of recipients
         const KMime::Types::Mailbox::List recipients = toList;
 
-        toList = stripMyAddressesFromAddressList(recipients, m_identityManager);
+        toList = stripMyAddressesFromAddressList(recipients, mIdentityManager);
         break;
     }
     case MessageComposer::ReplyAll:
-        if (auto hdr = m_origMsg->headerByType("Mail-Followup-To")) {
+        if (auto hdr = mOrigMsg->headerByType("Mail-Followup-To")) {
             toList = KMime::Types::Mailbox::listFrom7BitString(hdr->as7BitString(false));
         } else {
-            auto ccList = stripMyAddressesFromAddressList(m_origMsg->cc()->mailboxes(), m_identityManager);
+            auto ccList = stripMyAddressesFromAddressList(mOrigMsg->cc()->mailboxes(), mIdentityManager);
 
-            if (!m_mailingListAddresses.isEmpty()) {
-                toList = stripMyAddressesFromAddressList(m_origMsg->to()->mailboxes(), m_identityManager);
+            if (!mMailingListAddresses.isEmpty()) {
+                toList = stripMyAddressesFromAddressList(mOrigMsg->to()->mailboxes(), mIdentityManager);
                 bool addMailingList = true;
-                for (const KMime::Types::Mailbox &m : m_mailingListAddresses) {
+                for (const KMime::Types::Mailbox &m : qAsConst(mMailingListAddresses)) {
                     if (toList.contains(m)) {
                         addMailingList = false;
                         break;
                     }
                 }
                 if (addMailingList) {
-                    toList += m_mailingListAddresses.front();
+                    toList += mMailingListAddresses.front();
                 }
 
-                ccList += authorMailboxes(m_origMsg, m_mailingListAddresses);
+                ccList += authorMailboxes(mOrigMsg, mMailingListAddresses);
             } else {
                 // Doesn't seem to be a mailing list.
-                auto originalFromList = m_origMsg->from()->mailboxes();
-                auto originalToList = m_origMsg->to()->mailboxes();
+                auto originalFromList = mOrigMsg->from()->mailboxes();
+                auto originalToList = mOrigMsg->to()->mailboxes();
 
-                if (m_identityManager->thatIsMe(KMime::Types::Mailbox::listToUnicodeString(originalFromList))
-                    && !m_identityManager->thatIsMe(KMime::Types::Mailbox::listToUnicodeString(originalToList))
+                if (mIdentityManager->thatIsMe(KMime::Types::Mailbox::listToUnicodeString(originalFromList))
+                    && !mIdentityManager->thatIsMe(KMime::Types::Mailbox::listToUnicodeString(originalToList))
                     ) {
                     // Sender seems to be one of our own identities and recipient is not,
                     // so we assume that this is a reply to a "sent" mail where the user
@@ -258,18 +244,18 @@ void MessageFactoryNG::createReplyAsync()
                     toList = originalToList;
                 } else {
                     // "Normal" case:  reply to sender.
-                    toList = stripMyAddressesFromAddressList(m_origMsg->to()->mailboxes(), m_identityManager);
-                    toList += authorMailboxes(m_origMsg, m_mailingListAddresses);
+                    toList = stripMyAddressesFromAddressList(mOrigMsg->to()->mailboxes(), mIdentityManager);
+                    toList += authorMailboxes(mOrigMsg, mMailingListAddresses);
                 }
             }
 
-            for (const KMime::Types::Mailbox &mailbox : ccList) {
+            for (const KMime::Types::Mailbox &mailbox : qAsConst(ccList)) {
                 msg->cc()->addAddress(mailbox);
             }
         }
         break;
     case MessageComposer::ReplyAuthor:
-        toList = authorMailboxes(m_origMsg, m_mailingListAddresses);
+        toList = authorMailboxes(mOrigMsg, mMailingListAddresses);
         replyAll = false;
         break;
     case MessageComposer::ReplyNone:
@@ -283,26 +269,27 @@ void MessageFactoryNG::createReplyAsync()
         msg->to()->addAddress(mailbox);
     }
 
-    refStr = getRefStr(m_origMsg);
+    refStr = getRefStr(mOrigMsg);
     if (!refStr.isEmpty()) {
         msg->references()->fromUnicodeString(QString::fromLocal8Bit(refStr), "utf-8");
     }
     //In-Reply-To = original msg-id
-    msg->inReplyTo()->from7BitString(m_origMsg->messageID()->as7BitString(false));
+    msg->inReplyTo()->from7BitString(mOrigMsg->messageID()->as7BitString(false));
 
-    msg->subject()->fromUnicodeString(MessageCore::StringUtil::replySubject(m_origMsg.data()), "utf-8");
+    msg->subject()->fromUnicodeString(MessageCore::StringUtil::replySubject(mOrigMsg.data()), "utf-8");
 
     // If the reply shouldn't be blank, apply the template to the message
-    if (m_quote) {
+    if (mQuote) {
         MessageFactoryReplyJob *job = new MessageFactoryReplyJob;
         connect(job, &MessageFactoryReplyJob::replyDone, this, &MessageFactoryNG::slotCreateReplyDone);
         job->setMsg(msg);
         job->setReplyAll(replyAll);
-        job->setIdentityManager(m_identityManager);
-        job->setSelection(m_selection);
-        job->setTemplate(m_template);
-        job->setOrigMsg(m_origMsg);
-        job->setCollection(m_collection);
+        job->setIdentityManager(mIdentityManager);
+        job->setSelection(mSelection);
+        job->setTemplate(mTemplate);
+        job->setOrigMsg(mOrigMsg);
+        job->setCollection(mCollection);
+        job->setReplyAsHtml(mReplyAsHtml);
         job->start();
     } else {
         slotCreateReplyDone(msg, replyAll);
@@ -313,7 +300,7 @@ void MessageFactoryNG::slotCreateForwardDone(const KMime::Message::Ptr &msg)
 {
     applyCharset(msg);
 
-    MessageComposer::Util::addLinkInformation(msg, m_id, Akonadi::MessageStatus::statusForwarded());
+    MessageComposer::Util::addLinkInformation(msg, mId, Akonadi::MessageStatus::statusForwarded());
     msg->assemble();
     Q_EMIT createForwardDone(msg);
 }
@@ -324,16 +311,16 @@ void MessageFactoryNG::createForwardAsync()
 
     // This is a non-multipart, non-text mail (e.g. text/calendar). Construct
     // a multipart/mixed mail and add the original body as an attachment.
-    if (!m_origMsg->contentType()->isMultipart()
-        && (!m_origMsg->contentType()->isText()
-            || (m_origMsg->contentType()->isText() && m_origMsg->contentType()->subType() != "html"
-                && m_origMsg->contentType()->subType() != "plain"))) {
-        const uint originalIdentity = identityUoid(m_origMsg);
-        MessageHelper::initFromMessage(msg, m_origMsg, m_identityManager, originalIdentity);
+    if (!mOrigMsg->contentType()->isMultipart()
+        && (!mOrigMsg->contentType(false)->isText()
+            || (mOrigMsg->contentType(false)->isText() && mOrigMsg->contentType(false)->subType() != "html"
+                && mOrigMsg->contentType(false)->subType() != "plain"))) {
+        const uint originalIdentity = identityUoid(mOrigMsg);
+        MessageHelper::initFromMessage(msg, mOrigMsg, mIdentityManager, originalIdentity);
         msg->removeHeader<KMime::Headers::ContentType>();
         msg->removeHeader<KMime::Headers::ContentTransferEncoding>();
 
-        msg->contentType()->setMimeType("multipart/mixed");
+        msg->contentType(true)->setMimeType("multipart/mixed");
 
         //TODO: Andras: somebody should check if this is correct. :)
         // empty text part
@@ -343,10 +330,10 @@ void MessageFactoryNG::createForwardAsync()
 
         // the old contents of the mail
         KMime::Content *secondPart = new KMime::Content;
-        secondPart->contentType()->setMimeType(m_origMsg->contentType()->mimeType());
-        secondPart->setBody(m_origMsg->body());
+        secondPart->contentType()->setMimeType(mOrigMsg->contentType()->mimeType());
+        secondPart->setBody(mOrigMsg->body());
         // use the headers of the original mail
-        secondPart->setHead(m_origMsg->head());
+        secondPart->setHead(mOrigMsg->head());
         msg->addContent(secondPart);
         msg->assemble();
     }
@@ -355,11 +342,11 @@ void MessageFactoryNG::createForwardAsync()
     // replacing the body text in TemplateParser::addProcessedBodyToMessage()
     else {
         //TODO Check if this is ok
-        msg->setHead(m_origMsg->head());
-        msg->setBody(m_origMsg->body());
-        QString oldContentType = msg->contentType()->asUnicodeString();
-        const uint originalIdentity = identityUoid(m_origMsg);
-        MessageHelper::initFromMessage(msg, m_origMsg, m_identityManager, originalIdentity);
+        msg->setHead(mOrigMsg->head());
+        msg->setBody(mOrigMsg->body());
+        const QString oldContentType = msg->contentType()->asUnicodeString();
+        const uint originalIdentity = identityUoid(mOrigMsg);
+        MessageHelper::initFromMessage(msg, mOrigMsg, mIdentityManager, originalIdentity);
 
         // restore the content type, MessageHelper::initFromMessage() sets the contents type to
         // text/plain, via initHeader(), for unclear reasons
@@ -367,34 +354,34 @@ void MessageFactoryNG::createForwardAsync()
         msg->assemble();
     }
 
-    msg->subject()->fromUnicodeString(MessageCore::StringUtil::forwardSubject(m_origMsg.data()), "utf-8");
+    msg->subject()->fromUnicodeString(MessageCore::StringUtil::forwardSubject(mOrigMsg.data()), "utf-8");
     MessageFactoryForwardJob *job = new MessageFactoryForwardJob;
     connect(job, &MessageFactoryForwardJob::forwardDone, this, &MessageFactoryNG::slotCreateForwardDone);
-    job->setIdentityManager(m_identityManager);
+    job->setIdentityManager(mIdentityManager);
     job->setMsg(msg);
-    job->setSelection(m_selection);
-    job->setTemplate(m_template);
-    job->setOrigMsg(m_origMsg);
-    job->setCollection(m_collection);
+    job->setSelection(mSelection);
+    job->setTemplate(mTemplate);
+    job->setOrigMsg(mOrigMsg);
+    job->setCollection(mCollection);
     job->start();
 }
 
-QPair< KMime::Message::Ptr, QList< KMime::Content * > > MessageFactoryNG::createAttachedForward(const Akonadi::Item::List &items)
+QPair< KMime::Message::Ptr, QVector< KMime::Content * > > MessageFactoryNG::createAttachedForward(const Akonadi::Item::List &items)
 {
     // create forwarded message with original message as attachment
     // remove headers that shouldn't be forwarded
     KMime::Message::Ptr msg(new KMime::Message);
-    QList< KMime::Content * > attachments;
+    QVector< KMime::Content * > attachments;
 
     const int numberOfItems(items.count());
     if (numberOfItems >= 2) {
         // don't respect X-KMail-Identity headers because they might differ for
         // the selected mails
-        MessageHelper::initHeader(msg, m_identityManager, 0);
+        MessageHelper::initHeader(msg, mIdentityManager, 0);
     } else if (numberOfItems == 1) {
         KMime::Message::Ptr firstMsg = MessageComposer::Util::message(items.first());
         const uint originalIdentity = identityUoid(firstMsg);
-        MessageHelper::initFromMessage(msg, firstMsg, m_identityManager, originalIdentity);
+        MessageHelper::initFromMessage(msg, firstMsg, mIdentityManager, originalIdentity);
         msg->subject()->fromUnicodeString(MessageCore::StringUtil::forwardSubject(firstMsg.data()), "utf-8");
     }
 
@@ -403,8 +390,8 @@ QPair< KMime::Message::Ptr, QList< KMime::Content * > > MessageFactoryNG::create
     KPIM::KCursorSaver busy(KPIM::KBusyPtr::busy());
 #endif
     if (numberOfItems == 0) {
-        attachments << createForwardAttachmentMessage(m_origMsg);
-        MessageComposer::Util::addLinkInformation(msg, m_id, Akonadi::MessageStatus::statusForwarded());
+        attachments << createForwardAttachmentMessage(mOrigMsg);
+        MessageComposer::Util::addLinkInformation(msg, mId, Akonadi::MessageStatus::statusForwarded());
     } else {
         // iterate through all the messages to be forwarded
         attachments.reserve(items.count());
@@ -417,7 +404,7 @@ QPair< KMime::Message::Ptr, QList< KMime::Content * > > MessageFactoryNG::create
     applyCharset(msg);
 
     //msg->assemble();
-    return QPair< KMime::Message::Ptr, QList< KMime::Content * > >(msg, QList< KMime::Content * >() << attachments);
+    return QPair< KMime::Message::Ptr, QVector< KMime::Content * > >(msg, QVector< KMime::Content * >() << attachments);
 }
 
 KMime::Content *MessageFactoryNG::createForwardAttachmentMessage(const KMime::Message::Ptr &fwdMsg)
@@ -430,9 +417,12 @@ KMime::Content *MessageFactoryNG::createForwardAttachmentMessage(const KMime::Me
     KMime::Content *msgPart = new KMime::Content(fwdMsg.data());
     msgPart->contentType()->setMimeType("message/rfc822");
 
-    msgPart->contentDisposition()->setParameter(QStringLiteral("filename"), i18n("forwarded message"));
-    msgPart->contentDisposition()->setDisposition(KMime::Headers::CDinline);
-    msgPart->contentDescription()->fromUnicodeString(fwdMsg->from()->asUnicodeString() + QLatin1String(": ") + fwdMsg->subject()->asUnicodeString(), "utf-8");
+    auto cd = msgPart->contentDisposition(); //create
+    cd->setParameter(QStringLiteral("filename"), i18n("forwarded message"));
+    cd->setDisposition(KMime::Headers::CDinline);
+    const QString subject = fwdMsg->subject()->asUnicodeString();
+    msgPart->contentType()->setParameter(QStringLiteral("name"), subject);
+    cd->fromUnicodeString(fwdMsg->from()->asUnicodeString() + QLatin1String(": ") + subject, "utf-8");
     msgPart->setBody(fwdMsg->encodedContent());
     msgPart->assemble();
 
@@ -440,13 +430,23 @@ KMime::Content *MessageFactoryNG::createForwardAttachmentMessage(const KMime::Me
     return msgPart;
 }
 
+bool MessageFactoryNG::replyAsHtml() const
+{
+    return mReplyAsHtml;
+}
+
+void MessageFactoryNG::setReplyAsHtml(bool replyAsHtml)
+{
+    mReplyAsHtml = replyAsHtml;
+}
+
 KMime::Message::Ptr MessageFactoryNG::createResend()
 {
     KMime::Message::Ptr msg(new KMime::Message);
-    msg->setContent(m_origMsg->encodedContent());
+    msg->setContent(mOrigMsg->encodedContent());
     msg->parse();
     msg->removeHeader<KMime::Headers::MessageID>();
-    uint originalIdentity = identityUoid(m_origMsg);
+    uint originalIdentity = identityUoid(mOrigMsg);
 
     // Set the identity from above
     KMime::Headers::Generic *header = new KMime::Headers::Generic("X-KMail-Identity");
@@ -454,19 +454,19 @@ KMime::Message::Ptr MessageFactoryNG::createResend()
     msg->setHeader(header);
 
     // Restore the original bcc field as this is overwritten in applyIdentity
-    msg->bcc(m_origMsg->bcc());
+    msg->bcc(mOrigMsg->bcc());
     return msg;
 }
 
 KMime::Message::Ptr MessageFactoryNG::createRedirect(const QString &toStr, const QString &ccStr, const QString &bccStr, int transportId, const QString &fcc, int identity)
 {
-    if (!m_origMsg) {
+    if (!mOrigMsg) {
         return KMime::Message::Ptr();
     }
 
     // copy the message 1:1
     KMime::Message::Ptr msg(new KMime::Message);
-    msg->setContent(m_origMsg->encodedContent());
+    msg->setContent(mOrigMsg->encodedContent());
     msg->parse();
 
     uint id = identity;
@@ -479,11 +479,11 @@ KMime::Message::Ptr MessageFactoryNG::createRedirect(const QString &toStr, const
         }
     }
     const KIdentityManagement::Identity &ident
-        = m_identityManager->identityForUoidOrDefault(id);
+        = mIdentityManager->identityForUoidOrDefault(id);
 
     // X-KMail-Redirect-From: content
     const QString strByWayOf = QString::fromLocal8Bit("%1 (by way of %2 <%3>)")
-                               .arg(m_origMsg->from()->asUnicodeString(), ident.fullName(), ident.primaryEmailAddress());
+                               .arg(mOrigMsg->from()->asUnicodeString(), ident.fullName(), ident.primaryEmailAddress());
 
     // Resent-From: content
     const QString strFrom = QString::fromLocal8Bit("%1 <%2>")
@@ -522,7 +522,7 @@ KMime::Message::Ptr MessageFactoryNG::createRedirect(const QString &toStr, const
 
     if (msg->to(false)) {
         KMime::Headers::To *headerT = new KMime::Headers::To;
-        headerT->fromUnicodeString(m_origMsg->to()->asUnicodeString(), "utf-8");
+        headerT->fromUnicodeString(mOrigMsg->to()->asUnicodeString(), "utf-8");
         msg->setHeader(headerT);
     }
 
@@ -569,14 +569,14 @@ KMime::Message::Ptr MessageFactoryNG::createRedirect(const QString &toStr, const
 
     msg->assemble();
 
-    MessageComposer::Util::addLinkInformation(msg, m_id, Akonadi::MessageStatus::statusForwarded());
+    MessageComposer::Util::addLinkInformation(msg, mId, Akonadi::MessageStatus::statusForwarded());
     return msg;
 }
 
 KMime::Message::Ptr MessageFactoryNG::createDeliveryReceipt()
 {
     QString receiptTo;
-    if (auto hrd = m_origMsg->headerByType("Disposition-Notification-To")) {
+    if (auto hrd = mOrigMsg->headerByType("Disposition-Notification-To")) {
         receiptTo = hrd->asUnicodeString();
     }
     if (receiptTo.trimmed().isEmpty()) {
@@ -585,14 +585,14 @@ KMime::Message::Ptr MessageFactoryNG::createDeliveryReceipt()
     receiptTo.remove(QChar::fromLatin1('\n'));
 
     KMime::Message::Ptr receipt(new KMime::Message);
-    const uint originalIdentity = identityUoid(m_origMsg);
-    MessageHelper::initFromMessage(receipt, m_origMsg, m_identityManager, originalIdentity);
+    const uint originalIdentity = identityUoid(mOrigMsg);
+    MessageHelper::initFromMessage(receipt, mOrigMsg, mIdentityManager, originalIdentity);
     receipt->to()->fromUnicodeString(receiptTo, QStringLiteral("utf-8").toLatin1());
-    receipt->subject()->fromUnicodeString(i18n("Receipt: ") + m_origMsg->subject()->asUnicodeString(), "utf-8");
+    receipt->subject()->fromUnicodeString(i18n("Receipt: ") + mOrigMsg->subject()->asUnicodeString(), "utf-8");
 
     QString str = QStringLiteral("Your message was successfully delivered.");
     str += QLatin1String("\n\n---------- Message header follows ----------\n");
-    str += QString::fromLatin1(m_origMsg->head());
+    str += QString::fromLatin1(mOrigMsg->head());
     str += QLatin1String("--------------------------------------------\n");
     // Conversion to toLatin1 is correct here as Mail headers should contain
     // ascii only
@@ -607,7 +607,7 @@ KMime::Message::Ptr MessageFactoryNG::createMDN(KMime::MDN::ActionMode a, KMime:
 {
     // extract where to send to:
     QString receiptTo;
-    if (auto hrd = m_origMsg->headerByType("Disposition-Notification-To")) {
+    if (auto hrd = mOrigMsg->headerByType("Disposition-Notification-To")) {
         receiptTo = hrd->asUnicodeString();
     }
     if (receiptTo.trimmed().isEmpty()) {
@@ -618,63 +618,65 @@ KMime::Message::Ptr MessageFactoryNG::createMDN(KMime::MDN::ActionMode a, KMime:
     QString special; // fill in case of error, warning or failure
 
     // extract where to send from:
-    QString finalRecipient = m_identityManager->identityForUoidOrDefault(identityUoid(m_origMsg)).fullEmailAddr();
+    QString finalRecipient = mIdentityManager->identityForUoidOrDefault(identityUoid(mOrigMsg)).fullEmailAddr();
 
     //
     // Generate message:
     //
 
     KMime::Message::Ptr receipt(new KMime::Message());
-    const uint originalIdentity = identityUoid(m_origMsg);
-    MessageHelper::initFromMessage(receipt, m_origMsg, m_identityManager, originalIdentity);
-    receipt->contentType()->from7BitString("multipart/report");
-    receipt->contentType()->setBoundary(KMime::multiPartBoundary());
-    receipt->contentType()->setCharset("us-ascii");
+    const uint originalIdentity = identityUoid(mOrigMsg);
+    MessageHelper::initFromMessage(receipt, mOrigMsg, mIdentityManager, originalIdentity);
+    auto contentType = receipt->contentType(true); //create it
+    contentType->from7BitString("multipart/report");
+    contentType->setBoundary(KMime::multiPartBoundary());
+    contentType->setCharset("us-ascii");
     receipt->removeHeader<KMime::Headers::ContentTransferEncoding>();
     // Modify the ContentType directly (replaces setAutomaticFields(true))
-    receipt->contentType()->setParameter(QStringLiteral("report-type"), QStringLiteral("disposition-notification"));
+    contentType->setParameter(QStringLiteral("report-type"), QStringLiteral("disposition-notification"));
 
-    QString description = replaceHeadersInString(m_origMsg, KMime::MDN::descriptionFor(d, m));
+    const QString description = replaceHeadersInString(mOrigMsg, KMime::MDN::descriptionFor(d, m));
 
     // text/plain part:
-    KMime::Content *firstMsgPart = new KMime::Content(m_origMsg.data());
-    firstMsgPart->contentType()->setMimeType("text/plain");
-    firstMsgPart->contentType()->setCharset("utf-8");
-    firstMsgPart->contentTransferEncoding()->setEncoding(KMime::Headers::CE7Bit);
+    KMime::Content *firstMsgPart = new KMime::Content(mOrigMsg.data());
+    auto firstMsgPartContentType = firstMsgPart->contentType(); //create it
+    firstMsgPartContentType->setMimeType("text/plain");
+    firstMsgPartContentType->setCharset("utf-8");
+    firstMsgPart->contentTransferEncoding(true)->setEncoding(KMime::Headers::CE7Bit);
     firstMsgPart->setBody(description.toUtf8());
     receipt->addContent(firstMsgPart);
 
     // message/disposition-notification part:
-    KMime::Content *secondMsgPart = new KMime::Content(m_origMsg.data());
+    KMime::Content *secondMsgPart = new KMime::Content(mOrigMsg.data());
     secondMsgPart->contentType()->setMimeType("message/disposition-notification");
 
     secondMsgPart->contentTransferEncoding()->setEncoding(KMime::Headers::CE7Bit);
     QByteArray originalRecipient = "";
-    if (auto hrd = m_origMsg->headerByType("Original-Recipient")) {
+    if (auto hrd = mOrigMsg->headerByType("Original-Recipient")) {
         originalRecipient = hrd->as7BitString(false);
     }
     secondMsgPart->setBody(KMime::MDN::dispositionNotificationBodyContent(
                                finalRecipient,
                                originalRecipient,
-                               m_origMsg->messageID()->as7BitString(false), /* Message-ID */
+                               mOrigMsg->messageID()->as7BitString(false), /* Message-ID */
                                d, a, s, m, special));
     receipt->addContent(secondMsgPart);
 
-    if (mdnQuoteOriginal < 0 || mdnQuoteOriginal > 2) {
+    if ((mdnQuoteOriginal < 0) || (mdnQuoteOriginal > 2)) {
         mdnQuoteOriginal = 0;
     }
     /* 0=> Nothing, 1=>Full Message, 2=>HeadersOnly*/
 
-    KMime::Content *thirdMsgPart = new KMime::Content(m_origMsg.data());
+    KMime::Content *thirdMsgPart = new KMime::Content(mOrigMsg.data());
     switch (mdnQuoteOriginal) {
     case 1:
         thirdMsgPart->contentType()->setMimeType("message/rfc822");
-        thirdMsgPart->setBody(MessageCore::StringUtil::asSendableString(m_origMsg));
+        thirdMsgPart->setBody(MessageCore::StringUtil::asSendableString(mOrigMsg));
         receipt->addContent(thirdMsgPart);
         break;
     case 2:
         thirdMsgPart->contentType()->setMimeType("text/rfc822-headers");
-        thirdMsgPart->setBody(MessageCore::StringUtil::headerAsSendableString(m_origMsg));
+        thirdMsgPart->setBody(MessageCore::StringUtil::headerAsSendableString(mOrigMsg));
         receipt->addContent(thirdMsgPart);
         break;
     case 0:
@@ -687,10 +689,10 @@ KMime::Message::Ptr MessageFactoryNG::createMDN(KMime::MDN::ActionMode a, KMime:
     //Laurent: We don't translate subject ?
     receipt->subject()->from7BitString("Message Disposition Notification");
     KMime::Headers::InReplyTo *header = new KMime::Headers::InReplyTo;
-    header->fromUnicodeString(m_origMsg->messageID()->asUnicodeString(), "utf-8");
+    header->fromUnicodeString(mOrigMsg->messageID()->asUnicodeString(), "utf-8");
     receipt->setHeader(header);
 
-    receipt->references()->from7BitString(getRefStr(m_origMsg));
+    receipt->references()->from7BitString(getRefStr(mOrigMsg));
 
     receipt->assemble();
 
@@ -705,7 +707,7 @@ QPair< KMime::Message::Ptr, KMime::Content * > MessageFactoryNG::createForwardDi
     KMime::Message::Ptr msg(new KMime::Message);
     KMime::Content *digest = new KMime::Content(msg.data());
 
-    QString mainPartText = i18n("\nThis is a MIME digest forward. The content of the"
+    const QString mainPartText = i18n("\nThis is a MIME digest forward. The content of the"
                                 " message is contained in the attachment(s).\n\n\n");
 
     digest->contentType()->setMimeType("multipart/digest");
@@ -740,8 +742,8 @@ QPair< KMime::Message::Ptr, KMime::Content * > MessageFactoryNG::createForwardDi
     }
     digest->assemble();
 
-    id = m_folderId;
-    MessageHelper::initHeader(msg, m_identityManager, id);
+    id = mFolderId;
+    MessageHelper::initHeader(msg, mIdentityManager, id);
 
     //   qCDebug(MESSAGECOMPOSER_LOG) << "digest:" << digest->contents().size() << digest->encodedContent();
 
@@ -750,42 +752,42 @@ QPair< KMime::Message::Ptr, KMime::Content * > MessageFactoryNG::createForwardDi
 
 void MessageFactoryNG::setIdentityManager(KIdentityManagement::IdentityManager *ident)
 {
-    m_identityManager = ident;
+    mIdentityManager = ident;
 }
 
 void MessageFactoryNG::setReplyStrategy(MessageComposer::ReplyStrategy replyStrategy)
 {
-    m_replyStrategy = replyStrategy;
+    mReplyStrategy = replyStrategy;
 }
 
 void MessageFactoryNG::setSelection(const QString &selection)
 {
-    m_selection = selection;
+    mSelection = selection;
 }
 
 void MessageFactoryNG::setQuote(bool quote)
 {
-    m_quote = quote;
+    mQuote = quote;
 }
 
 void MessageFactoryNG::setTemplate(const QString &templ)
 {
-    m_template = templ;
+    mTemplate = templ;
 }
 
 void MessageFactoryNG::setMailingListAddresses(const KMime::Types::Mailbox::List &listAddresses)
 {
-    m_mailingListAddresses << listAddresses;
+    mMailingListAddresses << listAddresses;
 }
 
 void MessageFactoryNG::setFolderIdentity(Akonadi::Collection::Id folderIdentityId)
 {
-    m_folderId = folderIdentityId;
+    mFolderId = folderIdentityId;
 }
 
 void MessageFactoryNG::putRepliesInSameFolder(Akonadi::Collection::Id parentColId)
 {
-    m_parentFolderId = parentColId;
+    mParentFolderId = parentColId;
 }
 
 bool MessageFactoryNG::MDNRequested(const KMime::Message::Ptr &msg)
@@ -902,11 +904,11 @@ uint MessageFactoryNG::identityUoid(const KMime::Message::Ptr &msg)
     uint id = idString.toUInt(&ok);
 
     if (!ok || id == 0) {
-        id = m_identityManager->identityForAddress(msg->to()->asUnicodeString() + QLatin1String(", ") + msg->cc()->asUnicodeString()).uoid();
+        id = mIdentityManager->identityForAddress(msg->to()->asUnicodeString() + QLatin1String(", ") + msg->cc()->asUnicodeString()).uoid();
     }
 
-    if (id == 0 && m_folderId > 0) {
-        id = m_folderId;
+    if (id == 0 && mFolderId > 0) {
+        id = mFolderId;
     }
     return id;
 }
@@ -914,30 +916,28 @@ uint MessageFactoryNG::identityUoid(const KMime::Message::Ptr &msg)
 QString MessageFactoryNG::replaceHeadersInString(const KMime::Message::Ptr &msg, const QString &s)
 {
     QString result = s;
-    QRegExp rx(QStringLiteral("\\$\\{([a-z0-9-]+)\\}"), Qt::CaseInsensitive);
-    Q_ASSERT(rx.isValid());
-
-    QRegExp rxDate(QStringLiteral("\\$\\{date\\}"));
-    Q_ASSERT(rxDate.isValid());
+    static QRegularExpression rx {
+        QStringLiteral("\\$\\{([a-z0-9-]+)\\}"),
+        QRegularExpression::CaseInsensitiveOption
+    };
 
     const QString sDate = KMime::DateFormatter::formatDate(
         KMime::DateFormatter::Localized, msg->date()->dateTime().toSecsSinceEpoch());
     qCDebug(MESSAGECOMPOSER_LOG) << "creating mdn date:" << msg->date()->dateTime().toSecsSinceEpoch() << sDate;
 
-    int idx = 0;
-    if ((idx = rxDate.indexIn(result, idx)) != -1) {
-        result.replace(idx, rxDate.matchedLength(), sDate);
-    }
+    result.replace(QStringLiteral("${date}"), sDate);
 
-    idx = 0;
-    while ((idx = rx.indexIn(result, idx)) != -1) {
-        const QByteArray ba = rx.cap(1).toLatin1();
-        QString replacement;
-        if (auto hrd = msg->headerByType(ba.constData())) {
-            replacement = hrd->asUnicodeString();
+    int idx = 0;
+    for (auto match = rx.match(result); match.hasMatch(); match = rx.match(result, idx)) {
+        idx = match.capturedStart(1);
+        const QByteArray ba = match.captured(1).toLatin1();
+        if (auto hdr = msg->headerByType(ba.constData())) {
+            const auto replacement = hdr->asUnicodeString();
+            result.replace(idx, match.capturedLength(1), replacement);
+            idx += replacement.length();
+        } else {
+            result.remove(idx, match.capturedLength(1));
         }
-        result.replace(idx, rx.matchedLength(), replacement);
-        idx += replacement.length();
     }
     return result;
 }
@@ -954,7 +954,7 @@ void MessageFactoryNG::applyCharset(const KMime::Message::Ptr msg)
         const QString body = bodyCodec->toUnicode(msg->body());
 
         // then apply the encoding of the original message
-        msg->contentType()->setCharset(m_origMsg->contentType()->charset());
+        msg->contentType()->setCharset(mOrigMsg->contentType()->charset());
 
         QTextCodec *codec = KCharsets::charsets()->codecForName(QString::fromLatin1(msg->contentType()->charset()));
         if (!codec) {
@@ -962,7 +962,7 @@ void MessageFactoryNG::applyCharset(const KMime::Message::Ptr msg)
         } else if (!codec->canEncode(body)) {     // charset can't encode body, fall back to preferred
             const QStringList charsets = MessageComposer::MessageComposerSettings::preferredCharsets();
 
-            QList<QByteArray> chars;
+            QVector<QByteArray> chars;
             chars.reserve(charsets.count());
             for (const QString &charset : charsets) {
                 chars << charset.toLatin1();
