@@ -1,26 +1,13 @@
 /*
-   Copyright (C) 2012-2019 Montel Laurent <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "imagescalingwidget.h"
 #include "ui_imagescalingwidget.h"
 #include "settings/messagecomposersettings.h"
-
+#include <Libkdepim/LineEditCatchReturnKey>
 #include <KLocalizedString>
 #include <KMessageBox>
 
@@ -28,6 +15,7 @@
 #include <QComboBox>
 #include <QImageWriter>
 #include <QWhatsThis>
+#include <QVector>
 
 using namespace MessageComposer;
 class MessageComposer::ImageScalingWidgetPrivate
@@ -60,6 +48,11 @@ ImageScalingWidget::ImageScalingWidget(QWidget *parent)
     initComboBox(d->ui->CBMinimumHeight);
 
     initWriteImageFormat();
+    new KPIM::LineEditCatchReturnKey(d->ui->pattern, this);
+    new KPIM::LineEditCatchReturnKey(d->ui->renameResizedImagePattern, this);
+    new KPIM::LineEditCatchReturnKey(d->ui->resizeEmailsPattern, this);
+    new KPIM::LineEditCatchReturnKey(d->ui->doNotResizePattern, this);
+
     connect(d->ui->enabledAutoResize, &QCheckBox::clicked, this, &ImageScalingWidget::changed);
     connect(d->ui->KeepImageRatio, &QCheckBox::clicked, this, &ImageScalingWidget::changed);
     connect(d->ui->AskBeforeResizing, &QCheckBox::clicked, this, &ImageScalingWidget::changed);
@@ -71,18 +64,18 @@ ImageScalingWidget::ImageScalingWidget(QWidget *parent)
     connect(d->ui->customMinimumHeight, qOverload<int>(&QSpinBox::valueChanged), this, &ImageScalingWidget::changed);
     connect(d->ui->skipImageSizeLower, &QCheckBox::clicked, this, &ImageScalingWidget::changed);
     connect(d->ui->imageSize, qOverload<int>(&QSpinBox::valueChanged), this, &ImageScalingWidget::changed);
-    connect(d->ui->pattern, &KLineEdit::textChanged, this, &ImageScalingWidget::changed);
+    connect(d->ui->pattern, &QLineEdit::textChanged, this, &ImageScalingWidget::changed);
     connect(d->ui->CBMaximumWidth, qOverload<int>(&QComboBox::currentIndexChanged), this, &ImageScalingWidget::slotComboboxChanged);
     connect(d->ui->CBMaximumHeight, qOverload<int>(&QComboBox::currentIndexChanged), this, &ImageScalingWidget::slotComboboxChanged);
     connect(d->ui->CBMinimumWidth, qOverload<int>(&QComboBox::currentIndexChanged), this, &ImageScalingWidget::slotComboboxChanged);
     connect(d->ui->CBMinimumHeight, qOverload<int>(&QComboBox::currentIndexChanged), this, &ImageScalingWidget::slotComboboxChanged);
     connect(d->ui->WriteToImageFormat, qOverload<int>(&QComboBox::activated), this, &ImageScalingWidget::changed);
     connect(d->ui->renameResizedImage, &QCheckBox::clicked, this, &ImageScalingWidget::changed);
-    connect(d->ui->renameResizedImage, &QCheckBox::clicked, d->ui->renameResizedImagePattern, &KLineEdit::setEnabled);
-    connect(d->ui->renameResizedImagePattern, &KLineEdit::textChanged, this, &ImageScalingWidget::changed);
+    connect(d->ui->renameResizedImage, &QCheckBox::clicked, d->ui->renameResizedImagePattern, &QLineEdit::setEnabled);
+    connect(d->ui->renameResizedImagePattern, &QLineEdit::textChanged, this, &ImageScalingWidget::changed);
 
-    connect(d->ui->resizeEmailsPattern, &KLineEdit::textChanged, this, &ImageScalingWidget::changed);
-    connect(d->ui->doNotResizePattern, &KLineEdit::textChanged, this, &ImageScalingWidget::changed);
+    connect(d->ui->resizeEmailsPattern, &QLineEdit::textChanged, this, &ImageScalingWidget::changed);
+    connect(d->ui->doNotResizePattern, &QLineEdit::textChanged, this, &ImageScalingWidget::changed);
     connect(d->ui->resizeImageWithFormatsType, &MessageComposer::ImageScalingSelectFormat::textChanged, this, &ImageScalingWidget::changed);
     connect(d->ui->resizeImageWithFormats, &QCheckBox::clicked, this, &ImageScalingWidget::changed);
     connect(d->ui->resizeImageWithFormats, &QCheckBox::clicked, d->ui->resizeImageWithFormatsType, &MessageComposer::ImageScalingSelectFormat::setEnabled);
@@ -90,13 +83,21 @@ ImageScalingWidget::ImageScalingWidget(QWidget *parent)
 
     d->ui->pattern->setEnabled(false);
     d->mSourceFilenameFilterGroup = new QButtonGroup(d->ui->filterSourceGroupBox);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(d->mSourceFilenameFilterGroup, qOverload<int>(&QButtonGroup::buttonClicked), this, &ImageScalingWidget::slotSourceFilterClicked);
+#else
+    connect(d->mSourceFilenameFilterGroup, qOverload<QAbstractButton *>(&QButtonGroup::buttonClicked), this, &ImageScalingWidget::slotSourceFilterAbstractButtonClicked);
+#endif
     d->mSourceFilenameFilterGroup->addButton(d->ui->notFilterFilename, MessageComposer::MessageComposerSettings::EnumFilterSourceType::NoFilter);
     d->mSourceFilenameFilterGroup->addButton(d->ui->includeFilesWithPattern, MessageComposer::MessageComposerSettings::EnumFilterSourceType::IncludeFilesWithPattern);
     d->mSourceFilenameFilterGroup->addButton(d->ui->excludeFilesWithPattern, MessageComposer::MessageComposerSettings::EnumFilterSourceType::ExcludeFilesWithPattern);
 
     d->mRecipientFilterGroup = new QButtonGroup(d->ui->tab_4);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(d->mRecipientFilterGroup, qOverload<int>(&QButtonGroup::buttonClicked), this, &ImageScalingWidget::slotRecipientFilterClicked);
+#else
+    connect(d->mRecipientFilterGroup, qOverload<QAbstractButton *>(&QButtonGroup::buttonClicked), this, &ImageScalingWidget::slotRecipientFilterAbstractClicked);
+#endif
     d->ui->doNotResizePattern->setEnabled(false);
     d->ui->resizeEmailsPattern->setEnabled(false);
     d->mRecipientFilterGroup->addButton(d->ui->doNotFilterRecipients, MessageComposer::MessageComposerSettings::EnumFilterRecipientType::NoFilter);
@@ -133,6 +134,14 @@ void ImageScalingWidget::slotHelpLinkClicked(const QString &)
     QWhatsThis::showText(QCursor::pos(), help);
 }
 
+void ImageScalingWidget::slotSourceFilterAbstractButtonClicked(QAbstractButton *button)
+{
+    if (button) {
+        const int buttonId = d->mRecipientFilterGroup->id(button);
+        slotSourceFilterClicked(buttonId);
+    }
+}
+
 void ImageScalingWidget::slotSourceFilterClicked(int button)
 {
     d->ui->pattern->setEnabled(button != 0);
@@ -148,6 +157,14 @@ void ImageScalingWidget::slotRecipientFilterClicked(int button)
     Q_EMIT changed();
 }
 
+void ImageScalingWidget::slotRecipientFilterAbstractClicked(QAbstractButton *button)
+{
+    if (button) {
+        const int buttonId = d->mRecipientFilterGroup->id(button);
+        slotRecipientFilterClicked(buttonId);
+    }
+}
+
 void ImageScalingWidget::slotComboboxChanged(int index)
 {
     QComboBox *combo = qobject_cast< QComboBox * >(sender());
@@ -168,7 +185,7 @@ void ImageScalingWidget::slotComboboxChanged(int index)
 
 void ImageScalingWidget::initComboBox(QComboBox *combo)
 {
-    const QList<int> size = { 240, 320, 512, 640, 800, 1024, 1600, 2048 };
+    const QVector<int> size = { 240, 320, 512, 640, 800, 1024, 1600, 2048 };
     for (int val : size) {
         combo->addItem(QString::number(val), val);
     }
