@@ -1,29 +1,16 @@
 /*
  * This file is part of KMail.
  *
- * Copyright (c) 2010 KDAB
+ * SPDX-FileCopyrightText: 2010 KDAB
+ * SPDX-FileContributor: Tobias Koenig <tokoe@kde.org>
  *
- * Author: Tobias Koenig <tokoe@kde.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef ALIASESEXPANDJOB_P_H
-#define ALIASESEXPANDJOB_P_H
+#ifndef DISTRIBUTIONLISTEXPANDJOB_H
+#define DISTRIBUTIONLISTEXPANDJOB_H
 
-#include <kjob.h>
+#include <KJob>
 #include <QStringList>
 namespace MessageComposer {
 /**
@@ -69,7 +56,7 @@ private Q_SLOTS:
 private:
     QString mListName;
     QStringList mEmailAddresses;
-    bool mIsEmpty;
+    bool mIsEmpty = false;
 };
 }
 #endif
