@@ -1,26 +1,14 @@
 /*
-  Copyright (C) 2009 Klaralvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-  Copyright (c) 2009 Leo Franchi <lfranchi@kde.org>
+  SPDX-FileCopyrightText: 2009 Klaralvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
+  SPDX-FileCopyrightText: 2009 Leo Franchi <lfranchi@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "job/encryptjob.h"
 
 #include "contentjobbase_p.h"
+#include "job/protectedheaders.h"
 #include "utils/util_p.h"
 
 #include <Libkleo/Enum>
@@ -30,9 +18,6 @@
 
 #include "messagecomposer_debug.h"
 
-#include <kmime/kmime_message.h>
-#include <kmime/kmime_content.h>
-
 #include <gpgme++/global.h>
 #include <gpgme++/signingresult.h>
 #include <gpgme++/encryptionresult.h>
@@ -48,10 +33,14 @@ public:
     {
     }
 
-    KMime::Content *content = nullptr;
+    QStringList recipients;
     std::vector<GpgME::Key> keys;
     Kleo::CryptoMessageFormat format;
-    QStringList recipients;
+    KMime::Content *content = nullptr;
+    KMime::Message *skeletonMessage = nullptr;
+
+    bool protectedHeaders = true;
+    bool protectedHeadersObvoscate = false;
 
     // copied from messagecomposer.cpp
     bool binaryHint(Kleo::CryptoMessageFormat f)
@@ -122,6 +111,27 @@ void EncryptJob::setRecipients(const QStringList &recipients)
     d->recipients = recipients;
 }
 
+void EncryptJob::setSkeletonMessage(KMime::Message *skeletonMessage)
+{
+    Q_D(EncryptJob);
+
+    d->skeletonMessage = skeletonMessage;
+}
+
+void EncryptJob::setProtectedHeaders(bool protectedHeaders)
+{
+    Q_D(EncryptJob);
+
+    d->protectedHeaders = protectedHeaders;
+}
+
+void EncryptJob::setProtectedHeadersObvoscate(bool protectedHeadersObvoscate)
+{
+    Q_D(EncryptJob);
+
+    d->protectedHeadersObvoscate = protectedHeadersObvoscate;
+}
+
 QStringList EncryptJob::recipients() const
 {
     Q_D(const EncryptJob);
@@ -136,7 +146,7 @@ std::vector<GpgME::Key> EncryptJob::encryptionKeys() const
     return d->keys;
 }
 
-void EncryptJob::process()
+void EncryptJob::doStart()
 {
     Q_D(EncryptJob);
     Q_ASSERT(d->resultContent == nullptr);   // Not processed before.
@@ -149,11 +159,57 @@ void EncryptJob::process()
     // if setContent hasn't been called, we assume that a subjob was added
     // and we want to use that
     if (!d->content || !d->content->hasContent()) {
-        Q_ASSERT(d->subjobContents.size() == 1);
-        d->content = d->subjobContents.first();
+        if (d->subjobContents.size() == 1) {
+            d->content = d->subjobContents.constFirst();
+        }
     }
 
-    //d->resultContent = new KMime::Content;
+    if (d->protectedHeaders && d->skeletonMessage && d->format & Kleo::OpenPGPMIMEFormat) {
+        ProtectedHeadersJob *pJob = new ProtectedHeadersJob;
+        pJob->setContent(d->content);
+        pJob->setSkeletonMessage(d->skeletonMessage);
+        pJob->setObvoscate(d->protectedHeadersObvoscate);
+        QObject::connect(pJob, &ProtectedHeadersJob::finished, this, [d, pJob](KJob *job) {
+            if (job->error()) {
+                return;
+            }
+            d->content = pJob->content();
+        });
+        appendSubjob(pJob);
+    }
+
+    ContentJobBase::doStart();
+}
+
+void EncryptJob::slotResult(KJob *job)
+{
+    //Q_D(EncryptJob);
+    if (error()) {
+        ContentJobBase::slotResult(job);
+        return;
+    }
+    if (subjobs().size() == 2) {
+        auto pjob = static_cast<ProtectedHeadersJob *>(subjobs().last());
+        if (pjob) {
+            auto cjob = qobject_cast<ContentJobBase *>(job);
+            Q_ASSERT(cjob);
+            pjob->setContent(cjob->content());
+        }
+    }
+
+    ContentJobBase::slotResult(job);
+}
+
+void EncryptJob::process()
+{
+    Q_D(EncryptJob);
+
+    // if setContent hasn't been called, we assume that a subjob was added
+    // and we want to use that
+    if (!d->content || !d->content->hasContent()) {
+        Q_ASSERT(d->subjobContents.size() == 1);
+        d->content = d->subjobContents.constFirst();
+    }
 
     const QGpgME::Protocol *proto = nullptr;
     if (d->format & Kleo::AnyOpenPGP) {
@@ -167,11 +223,7 @@ void EncryptJob::process()
 
     Q_ASSERT(proto);
 
-    qCDebug(MESSAGECOMPOSER_LOG) << "got backend, starting job";
-    QGpgME::EncryptJob *seJob = proto->encryptJob(!d->binaryHint(d->format), d->format == Kleo::InlineOpenPGPFormat);
-
     // for now just do the main recipients
-    QByteArray encryptedBody;
     QByteArray content;
     d->content->assemble();
     if (d->format & Kleo::InlineOpenPGPFormat) {
@@ -180,22 +232,19 @@ void EncryptJob::process()
         content = d->content->encodedContent();
     }
 
-    // FIXME: Make async!
-    const GpgME::EncryptionResult res = seJob->exec(d->keys,
-                                                    content,
-                                                    true, // 'alwaysTrust' provided keys
-                                                    encryptedBody);
+    qCDebug(MESSAGECOMPOSER_LOG) << "got backend, starting job";
+    QGpgME::EncryptJob *eJob = proto->encryptJob(!d->binaryHint(d->format), d->format == Kleo::InlineOpenPGPFormat);
 
-    // exec'ed jobs don't delete themselves
-    seJob->deleteLater();
+    QObject::connect(eJob, &QGpgME::EncryptJob::result, this, [this, d](const GpgME::EncryptionResult &result, const QByteArray &cipherText, const QString &auditLogAsHtml, const GpgME::Error &auditLogError) {
+        if (result.error()) {
+            setError(result.error().code());
+            setErrorText(QString::fromLocal8Bit(result.error().asString()));
+            emitResult();
+            return;
+        }
+        d->resultContent = MessageComposer::Util::composeHeadersAndBody(d->content, cipherText, d->format, false);
 
-    if (res.error()) {
-        setError(res.error().code());
-        setErrorText(QString::fromLocal8Bit(res.error().asString()));
         emitResult();
-        return;
-    }
-    d->resultContent = MessageComposer::Util::composeHeadersAndBody(d->content, encryptedBody, d->format, false);
-
-    emitResult();
+    });
+    eJob->start(d->keys, content, true);
 }
