@@ -1,20 +1,7 @@
 /*
-  Copyright (c) 2009 Constantin Berzan <exit3219@gmail.com>
+  SPDX-FileCopyrightText: 2009 Constantin Berzan <exit3219@gmail.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "job/maintextjob.h"
@@ -90,7 +77,7 @@ bool MainTextJobPrivate::chooseCharsetAndEncode()
 {
     Q_Q(MainTextJob);
 
-    const QList<QByteArray> charsets = q->globalPart()->charsets(true);
+    const QVector<QByteArray> charsets = q->globalPart()->charsets(true);
     if (charsets.isEmpty()) {
         q->setError(JobBase::BugError);
         q->setErrorText(i18n("No charsets were available for encoding. Please check your configuration and make sure it contains at least one charset for sending."));
@@ -272,7 +259,8 @@ void MainTextJob::doStart()
             MultipartJob *multipartJob = new MultipartJob;
             multipartJob->setMultipartSubtype("related");
             multipartJob->appendSubjob(alternativeJob);
-            foreach (const QSharedPointer<KPIMTextEdit::EmbeddedImage> &image, d->textPart->embeddedImages()) {
+            const auto embeddedImages = d->textPart->embeddedImages();
+            for (const QSharedPointer<KPIMTextEdit::EmbeddedImage> &image : embeddedImages) {
                 multipartJob->appendSubjob(d->createImageJob(image));
             }
             appendSubjob(multipartJob);
@@ -286,6 +274,6 @@ void MainTextJob::process()
     Q_D(MainTextJob);
     // The content has been created by our subjob.
     Q_ASSERT(d->subjobContents.count() == 1);
-    d->resultContent = d->subjobContents.first();
+    d->resultContent = d->subjobContents.constFirst();
     emitResult();
 }
