@@ -1,31 +1,20 @@
 /*
-  Copyright (C) 2009 Klaralvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-  Copyright (c) 2009 Leo Franchi <lfranchi@kde.org>
+  SPDX-FileCopyrightText: 2009 Klaralvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
+  SPDX-FileCopyrightText: 2009 Leo Franchi <lfranchi@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "job/signjob.h"
 
 #include "contentjobbase_p.h"
+#include "job/protectedheaders.h"
 #include "utils/util_p.h"
 
 #include <Libkleo/Enum>
 #include <QGpgME/Protocol>
 #include <QGpgME/SignJob>
+#include <QVector>
 
 #include "messagecomposer_debug.h"
 #include <kmime/kmime_headers.h>
@@ -48,11 +37,14 @@ public:
     }
 
     KMime::Content *content = nullptr;
+    KMime::Message *skeletonMessage = nullptr;
     std::vector<GpgME::Key> signers;
     Kleo::CryptoMessageFormat format;
 
+    bool protectedHeaders = true;
+
     // copied from messagecomposer.cpp
-    bool binaryHint(Kleo::CryptoMessageFormat f)
+    Q_REQUIRED_RESULT bool binaryHint(Kleo::CryptoMessageFormat f)
     {
         switch (f) {
         case Kleo::SMIMEFormat:
@@ -65,7 +57,7 @@ public:
         }
     }
 
-    GpgME::SignatureMode signingMode(Kleo::CryptoMessageFormat f)
+    Q_REQUIRED_RESULT GpgME::SignatureMode signingMode(Kleo::CryptoMessageFormat f)
     {
         switch (f) {
         case Kleo::SMIMEOpaqueFormat:
@@ -110,13 +102,27 @@ void SignJob::setCryptoMessageFormat(Kleo::CryptoMessageFormat format)
     d->format = format;
 }
 
-void SignJob::setSigningKeys(std::vector<GpgME::Key> &signers)
+void SignJob::setSigningKeys(const std::vector<GpgME::Key> &signers)
 {
     Q_D(SignJob);
 
     d->signers = signers;
 }
 
+void SignJob::setSkeletonMessage(KMime::Message *skeletonMessage)
+{
+    Q_D(SignJob);
+
+    d->skeletonMessage = skeletonMessage;
+}
+
+void SignJob::setProtectedHeaders(bool protectedHeaders)
+{
+    Q_D(SignJob);
+
+    d->protectedHeaders = protectedHeaders;
+}
+
 KMime::Content *SignJob::origContent()
 {
     Q_D(SignJob);
@@ -124,6 +130,46 @@ KMime::Content *SignJob::origContent()
     return d->content;
 }
 
+void SignJob::doStart()
+{
+    Q_D(SignJob);
+    Q_ASSERT(d->resultContent == nullptr);   // Not processed before.
+
+    if (d->protectedHeaders && d->skeletonMessage && d->format & Kleo::OpenPGPMIMEFormat) {
+        ProtectedHeadersJob *pJob = new ProtectedHeadersJob;
+        pJob->setContent(d->content);
+        pJob->setSkeletonMessage(d->skeletonMessage);
+        pJob->setObvoscate(false);
+        QObject::connect(pJob, &ProtectedHeadersJob::finished, this, [d, pJob](KJob *job) {
+            if (job->error()) {
+                return;
+            }
+            d->content = pJob->content();
+        });
+        appendSubjob(pJob);
+    }
+
+    ContentJobBase::doStart();
+}
+
+void SignJob::slotResult(KJob *job)
+{
+    if (error()) {
+        ContentJobBase::slotResult(job);
+        return;
+    }
+    if (subjobs().size() == 2) {
+        auto pjob = static_cast<ProtectedHeadersJob *>(subjobs().last());
+        if (pjob) {
+            auto cjob = qobject_cast<ContentJobBase *>(job);
+            Q_ASSERT(cjob);
+            pjob->setContent(cjob->content());
+        }
+    }
+
+    ContentJobBase::slotResult(job);
+}
+
 void SignJob::process()
 {
     Q_D(SignJob);
@@ -133,7 +179,7 @@ void SignJob::process()
     // and we want to use that
     if (!d->content) {
         Q_ASSERT(d->subjobContents.size() == 1);
-        d->content = d->subjobContents.first();
+        d->content = d->subjobContents.constFirst();
     }
 
     //d->resultContent = new KMime::Content;
@@ -170,9 +216,10 @@ void SignJob::process()
             && !d->content->contentType(false)) {
             QByteArray body = d->content->encodedBody();
             bool changed = false;
-            QList<QByteArray> search;
-            QList<QByteArray> replacements;
-
+            QVector<QByteArray> search;
+            search.reserve(3);
+            QVector<QByteArray> replacements;
+            replacements.reserve(3);
             search << "From "
                    << "from "
                    << "-";
