@@ -1,25 +1,12 @@
 /*
-    Copyright (C) 2010 Casey Link <unnamedrambler@gmail.com>
-    Copyright (C) 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+    SPDX-FileCopyrightText: 2010 Casey Link <unnamedrambler@gmail.com>
+    SPDX-FileCopyrightText: 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
     Refactored from earlier code by:
-    Copyright (c) 2010 Volker Krause <vkrause@kde.org>
-    Copyright (c) 2004 Cornelius Schumacher <schumacher@kde.org>
+    SPDX-FileCopyrightText: 2010 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2004 Cornelius Schumacher <schumacher@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "recipientseditor.h"
@@ -29,7 +16,7 @@
 #include "recipientseditorsidewidget.h"
 
 #include "settings/messagecomposersettings.h"
-#include <MessageComposer/DistributionListDialog>
+#include "distributionlistdialog.h"
 
 #include "messagecomposer_debug.h"
 
@@ -103,7 +90,7 @@ RecipientsEditor::RecipientsEditor(RecipientLineFactory *lineFactory, QWidget *p
     connect(this, &RecipientsEditor::lineAdded, this, &RecipientsEditor::slotLineAdded);
     connect(this, &RecipientsEditor::lineDeleted, this, &RecipientsEditor::slotLineDeleted);
 
-    addData(); // one defaut line
+    addData(); // one default line
 }
 
 RecipientsEditor::~RecipientsEditor()
@@ -141,7 +128,7 @@ void RecipientsEditor::setRecipientString(const QVector< KMime::Types::Mailbox >
 
 Recipient::List RecipientsEditor::recipients() const
 {
-    const QList<MultiplyingLineData::Ptr> dataList = allData();
+    const QVector<MultiplyingLineData::Ptr> dataList = allData();
     Recipient::List recList;
     for (const MultiplyingLineData::Ptr &datum : dataList) {
         Recipient::Ptr rec = qSharedPointerDynamicCast<Recipient>(datum);
@@ -160,13 +147,13 @@ Recipient::Ptr RecipientsEditor::activeRecipient() const
 
 QString RecipientsEditor::recipientString(Recipient::Type type) const
 {
-    return recipientStringList(type).join(QStringLiteral(", "));
+    return recipientStringList(type).join(QLatin1String(", "));
 }
 
 QStringList RecipientsEditor::recipientStringList(Recipient::Type type) const
 {
     QStringList selectedRecipients;
-    foreach (const Recipient::Ptr &r, recipients()) {
+    for (const Recipient::Ptr &r : recipients()) {
         if (r->type() == type) {
             selectedRecipients << r->email();
         }
@@ -181,7 +168,7 @@ void RecipientsEditor::removeRecipient(const QString &recipient, Recipient::Type
     MultiplyingLine *line = nullptr;
     while (it.hasNext()) {
         line = it.next();
-        RecipientLineNG *rec = qobject_cast< RecipientLineNG * >(line);
+        RecipientLineNG *rec = qobject_cast<RecipientLineNG *>(line);
         if (rec) {
             if ((rec->recipient()->email() == recipient)
                 && (rec->recipientType() == type)) {
@@ -212,7 +199,7 @@ void MessageComposer::RecipientsEditor::setRecentAddressConfig(KConfig *config)
     if (config) {
         MultiplyingLine *line;
         foreach (line, lines()) {
-            RecipientLineNG *rec = qobject_cast< RecipientLineNG * >(line);
+            RecipientLineNG *rec = qobject_cast<RecipientLineNG *>(line);
             if (rec) {
                 rec->setRecentAddressConfig(config);
             }
@@ -248,16 +235,20 @@ void RecipientsEditor::slotLineAdded(MultiplyingLine *line)
 
     if (count > 0) {
         if (count == 1) {
-            RecipientLineNG *last_rec = qobject_cast< RecipientLineNG * >(lines().first());
-            if (last_rec && last_rec->recipientType() == Recipient::Bcc) {
+            RecipientLineNG *last_rec = qobject_cast<RecipientLineNG *>(lines().constFirst());
+            if (last_rec && (last_rec->recipientType() == Recipient::Bcc || last_rec->recipientType() == Recipient::ReplyTo)) {
                 rec->setRecipientType(Recipient::To);
             } else {
                 rec->setRecipientType(Recipient::Cc);
             }
         } else {
-            RecipientLineNG *last_rec = qobject_cast< RecipientLineNG * >(lines().at(lines().count() - 2));
+            RecipientLineNG *last_rec = qobject_cast<RecipientLineNG *>(lines().at(lines().count() - 2));
             if (last_rec) {
-                rec->setRecipientType(last_rec->recipientType());
+                if (last_rec->recipientType() == Recipient::ReplyTo) {
+                    rec->setRecipientType(Recipient::To);
+                } else {
+                    rec->setRecipientType(last_rec->recipientType());
+                }
             }
         }
         line->fixTabOrder(lines().constLast()->tabOut());
@@ -269,9 +260,9 @@ void RecipientsEditor::slotLineDeleted(int pos)
 {
     bool atLeastOneToLine = false;
     int firstCC = -1;
-    for (int i = pos; i < lines().count(); ++i) {
+    for (int i = pos, total = lines().count(); i < total; ++i) {
         MultiplyingLine *line = lines().at(i);
-        RecipientLineNG *rec = qobject_cast< RecipientLineNG * >(line);
+        RecipientLineNG *rec = qobject_cast<RecipientLineNG *>(line);
         if (rec) {
             if (rec->recipientType() == Recipient::To) {
                 atLeastOneToLine = true;
@@ -282,7 +273,7 @@ void RecipientsEditor::slotLineDeleted(int pos)
     }
 
     if (!atLeastOneToLine && (firstCC >= 0)) {
-        RecipientLineNG *firstCCLine = qobject_cast< RecipientLineNG * >(lines().at(firstCC));
+        RecipientLineNG *firstCCLine = qobject_cast<RecipientLineNG *>(lines().at(firstCC));
         if (firstCCLine) {
             firstCCLine->setRecipientType(Recipient::To);
         }
@@ -322,7 +313,7 @@ void RecipientsEditor::slotCalculateTotal()
     int empty = 0;
     MultiplyingLine *line = nullptr;
     foreach (line, lines()) {
-        RecipientLineNG *rec = qobject_cast< RecipientLineNG * >(line);
+        RecipientLineNG *rec = qobject_cast<RecipientLineNG *>(line);
         if (rec) {
             if (rec->isEmpty()) {
                 ++empty;
@@ -333,32 +324,37 @@ void RecipientsEditor::slotCalculateTotal()
                     d->mSkipTotal = true;
                     Recipient::Ptr recipient = rec->recipient();
                     const auto split = KEmailAddress::splitAddressList(recipient->email());
+                    bool maximumElementFound = false;
                     for (int i = 1 /* sic! */; i < split.count(); ++i) {
-                        addRecipient(split[i], rec->recipientType());
+                        maximumElementFound = addRecipient(split[i], rec->recipientType());
+                        if (maximumElementFound) {
+                            break;
+                        }
                     }
                     recipient->setEmail(split[0]);
                     rec->setData(recipient);
                     setFocusBottom(); // focus next empty entry
                     d->mSkipTotal = false;
+                    if (maximumElementFound) {
+                        return;
+                    }
                 }
             }
         }
     }
-
     // We always want at least one empty line
     if (empty == 0) {
         addData();
     }
     int count = 0;
     foreach (line, lines()) {
-        RecipientLineNG *rec = qobject_cast< RecipientLineNG * >(line);
+        RecipientLineNG *rec = qobject_cast<RecipientLineNG *>(line);
         if (rec) {
             if (!rec->isEmpty()) {
                 count++;
             }
         }
     }
-
     // update the side widget
     d->mSideWidget->setTotal(count, lines().count());
 }
@@ -366,5 +362,5 @@ void RecipientsEditor::slotCalculateTotal()
 RecipientLineNG *RecipientsEditor::activeLine() const
 {
     MultiplyingLine *line = MultiplyingLineEditor::activeLine();
-    return qobject_cast< RecipientLineNG * >(line);
+    return qobject_cast<RecipientLineNG *>(line);
 }
