@@ -1,24 +1,11 @@
 /*
-  Copyright (c) 2009 Constantin Berzan <exit3219@gmail.com>
-  Copyright (C) 2009 Klaralvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-  Copyright (c) 2009 Leo Franchi <lfranchi@kde.org>
+  SPDX-FileCopyrightText: 2009 Constantin Berzan <exit3219@gmail.com>
+  SPDX-FileCopyrightText: 2009 Klaralvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
+  SPDX-FileCopyrightText: 2009 Leo Franchi <lfranchi@kde.org>
 
   Parts based on KMail code by:
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "utils/util.h"
@@ -39,11 +26,11 @@
 
 #include <kmime/kmime_content.h>
 #include <kmime/kmime_headers.h>
-#include <mailtransportakonadi/messagequeuejob.h>
+#include <MailTransportAkonadi/MessageQueueJob>
 #include <AkonadiCore/agentinstance.h>
 #include <AkonadiCore/agentinstancecreatejob.h>
 #include <AkonadiCore/agentmanager.h>
-#include <MessageComposer/MessageHelper>
+#include <MessageCore/StringUtil>
 
 KMime::Content *setBodyAndCTE(QByteArray &encodedBody, KMime::Headers::ContentType *contentType, KMime::Content *ret)
 {
@@ -89,8 +76,9 @@ KMime::Content *MessageComposer::Util::composeHeadersAndBody(KMime::Content *ori
 
             if (sign) {                           // sign PGPMime, sign SMIME
                 if (format & Kleo::AnySMIME) {      // sign SMIME
-                    code->contentTransferEncoding()->setEncoding(KMime::Headers::CEbase64);
-                    code->contentTransferEncoding()->needToEncode();
+                    auto ct = code->contentTransferEncoding(); //create
+                    ct->setEncoding(KMime::Headers::CEbase64);
+                    ct->needToEncode();
                     code->setBody(encodedBody);
                 } else {                            // sign PGPMmime
                     setBodyAndCTE(encodedBody, orig->contentType(), code);
@@ -114,8 +102,9 @@ KMime::Content *MessageComposer::Util::composeHeadersAndBody(KMime::Content *ori
             }
         } else {                                //enc SMIME, sign/enc SMIMEOpaque
             result->contentTransferEncoding()->setEncoding(KMime::Headers::CEbase64);
-            result->contentDisposition()->setDisposition(KMime::Headers::CDattachment);
-            result->contentDisposition()->setFilename(QStringLiteral("smime.p7m"));
+            auto ct = result->contentDisposition(); //Create
+            ct->setDisposition(KMime::Headers::CDattachment);
+            ct->setFilename(QStringLiteral("smime.p7m"));
 
             result->assemble();
             //qCDebug(MESSAGECOMPOSER_LOG) << "processed header:" << result->head();
@@ -138,60 +127,69 @@ void MessageComposer::Util::makeToplevelContentType(KMime::Content *content, Kle
     switch (format) {
     default:
     case Kleo::InlineOpenPGPFormat:
-    case Kleo::OpenPGPMIMEFormat:
+    case Kleo::OpenPGPMIMEFormat: {
+        auto ct = content->contentType(); //Create
         if (sign) {
-            content->contentType()->setMimeType(QByteArrayLiteral("multipart/signed"));
-            content->contentType()->setParameter(QStringLiteral("protocol"), QString::fromAscii("application/pgp-signature"));
-            content->contentType()->setParameter(QStringLiteral("micalg"), QString::fromAscii(QByteArray(QByteArrayLiteral("pgp-") + hashAlgo)).toLower());
+            ct->setMimeType(QByteArrayLiteral("multipart/signed"));
+            ct->setParameter(QStringLiteral("protocol"), QStringLiteral("application/pgp-signature"));
+            ct->setParameter(QStringLiteral("micalg"), QString::fromLatin1(QByteArray(QByteArrayLiteral("pgp-") + hashAlgo)).toLower());
         } else {
-            content->contentType()->setMimeType(QByteArrayLiteral("multipart/encrypted"));
-            content->contentType()->setParameter(QStringLiteral("protocol"), QString::fromAscii("application/pgp-encrypted"));
+            ct->setMimeType(QByteArrayLiteral("multipart/encrypted"));
+            ct->setParameter(QStringLiteral("protocol"), QStringLiteral("application/pgp-encrypted"));
         }
+    }
         return;
-    case Kleo::SMIMEFormat:
+    case Kleo::SMIMEFormat: {
         if (sign) {
+            auto ct = content->contentType(); //Create
             qCDebug(MESSAGECOMPOSER_LOG) << "setting headers for SMIME";
-            content->contentType()->setMimeType(QByteArrayLiteral("multipart/signed"));
-            content->contentType()->setParameter(QStringLiteral("protocol"), QString::fromAscii("application/pkcs7-signature"));
-            content->contentType()->setParameter(QStringLiteral("micalg"), QString::fromAscii(hashAlgo).toLower());
+            ct->setMimeType(QByteArrayLiteral("multipart/signed"));
+            ct->setParameter(QStringLiteral("protocol"), QStringLiteral("application/pkcs7-signature"));
+            ct->setParameter(QStringLiteral("micalg"), QString::fromLatin1(hashAlgo).toLower());
             return;
         }
         // fall through (for encryption, there's no difference between
         // SMIME and SMIMEOpaque, since there is no mp/encrypted for
         // S/MIME)
+    }
         Q_FALLTHROUGH();
     case Kleo::SMIMEOpaqueFormat:
 
         qCDebug(MESSAGECOMPOSER_LOG) << "setting headers for SMIME/opaque";
-        content->contentType()->setMimeType(QByteArrayLiteral("application/pkcs7-mime"));
+        auto ct = content->contentType(); //Create
+        ct->setMimeType(QByteArrayLiteral("application/pkcs7-mime"));
 
         if (sign) {
-            content->contentType()->setParameter(QStringLiteral("smime-type"), QString::fromAscii("signed-data"));
+            ct->setParameter(QStringLiteral("smime-type"), QStringLiteral("signed-data"));
         } else {
-            content->contentType()->setParameter(QStringLiteral("smime-type"), QString::fromAscii("enveloped-data"));
+            ct->setParameter(QStringLiteral("smime-type"), QStringLiteral("enveloped-data"));
         }
-        content->contentType()->setParameter(QStringLiteral("name"), QString::fromAscii("smime.p7m"));
+        ct->setParameter(QStringLiteral("name"), QStringLiteral("smime.p7m"));
     }
 }
 
 void MessageComposer::Util::setNestedContentType(KMime::Content *content, Kleo::CryptoMessageFormat format, bool sign)
 {
     switch (format) {
-    case Kleo::OpenPGPMIMEFormat:
+    case Kleo::OpenPGPMIMEFormat: {
+        auto ct = content->contentType(); //Create
         if (sign) {
-            content->contentType()->setMimeType(QByteArrayLiteral("application/pgp-signature"));
-            content->contentType()->setParameter(QStringLiteral("name"), QString::fromAscii("signature.asc"));
+            ct->setMimeType(QByteArrayLiteral("application/pgp-signature"));
+            ct->setParameter(QStringLiteral("name"), QStringLiteral("signature.asc"));
             content->contentDescription()->from7BitString("This is a digitally signed message part.");
         } else {
-            content->contentType()->setMimeType(QByteArrayLiteral("application/octet-stream"));
+            ct->setMimeType(QByteArrayLiteral("application/octet-stream"));
         }
+    }
         return;
-    case Kleo::SMIMEFormat:
+    case Kleo::SMIMEFormat: {
         if (sign) {
-            content->contentType()->setMimeType(QByteArrayLiteral("application/pkcs7-signature"));
-            content->contentType()->setParameter(QStringLiteral("name"), QString::fromAscii("smime.p7s"));
+            auto ct = content->contentType(); //Create
+            ct->setMimeType(QByteArrayLiteral("application/pkcs7-signature"));
+            ct->setParameter(QStringLiteral("name"), QStringLiteral("smime.p7s"));
             return;
         }
+    }
         Q_FALLTHROUGH();
     // fall through:
     default:
@@ -203,12 +201,13 @@ void MessageComposer::Util::setNestedContentType(KMime::Content *content, Kleo::
 
 void MessageComposer::Util::setNestedContentDisposition(KMime::Content *content, Kleo::CryptoMessageFormat format, bool sign)
 {
+    auto ct = content->contentDisposition();
     if (!sign && format & Kleo::OpenPGPMIMEFormat) {
-        content->contentDisposition()->setDisposition(KMime::Headers::CDinline);
-        content->contentDisposition()->setFilename(QStringLiteral("msg.asc"));
+        ct->setDisposition(KMime::Headers::CDinline);
+        ct->setFilename(QStringLiteral("msg.asc"));
     } else if (sign && format & Kleo::SMIMEFormat) {
-        content->contentDisposition()->setDisposition(KMime::Headers::CDattachment);
-        content->contentDisposition()->setFilename(QStringLiteral("smime.p7s"));
+        ct->setDisposition(KMime::Headers::CDattachment);
+        ct->setFilename(QStringLiteral("smime.p7s"));
     }
 }
 
@@ -226,7 +225,7 @@ bool MessageComposer::Util::makeMultiMime(Kleo::CryptoMessageFormat format, bool
     }
 }
 
-QByteArray MessageComposer::Util::selectCharset(const QList<QByteArray> &charsets, const QString &text)
+QByteArray MessageComposer::Util::selectCharset(const QVector<QByteArray> &charsets, const QString &text)
 {
     for (const QByteArray &name : charsets) {
         // We use KCharsets::codecForName() instead of QTextCodec::codecForName() here, because
@@ -268,8 +267,8 @@ QString MessageComposer::Util::cleanedUpHeaderString(const QString &s)
 
 void MessageComposer::Util::addSendReplyForwardAction(const KMime::Message::Ptr &message, MailTransport::MessageQueueJob *qjob)
 {
-    QList<Akonadi::Item::Id> originalMessageId;
-    QList<Akonadi::MessageStatus> linkStatus;
+    QVector<Akonadi::Item::Id> originalMessageId;
+    QVector<Akonadi::MessageStatus> linkStatus;
     if (MessageComposer::Util::getLinkInformation(message, originalMessageId, linkStatus)) {
         for (Akonadi::Item::Id id : qAsConst(originalMessageId)) {
             if (linkStatus.first() == Akonadi::MessageStatus::statusReplied()) {
@@ -377,7 +376,7 @@ void MessageComposer::Util::addLinkInformation(const KMime::Message::Ptr &msg, A
     msg->setHeader(header);
 }
 
-bool MessageComposer::Util::getLinkInformation(const KMime::Message::Ptr &msg, QList<Akonadi::Item::Id> &id, QList<Akonadi::MessageStatus> &status)
+bool MessageComposer::Util::getLinkInformation(const KMime::Message::Ptr &msg, QVector<Akonadi::Item::Id> &id, QVector<Akonadi::MessageStatus> &status)
 {
     auto hrdLinkMsg = msg->headerByType("X-KMail-Link-Message");
     auto hrdLinkType = msg->headerByType("X-KMail-Link-Type");
@@ -385,8 +384,16 @@ bool MessageComposer::Util::getLinkInformation(const KMime::Message::Ptr &msg, Q
         return false;
     }
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     const QStringList messages = hrdLinkMsg->asUnicodeString().split(QLatin1Char(','), QString::SkipEmptyParts);
+#else
+    const QStringList messages = hrdLinkMsg->asUnicodeString().split(QLatin1Char(','), Qt::SkipEmptyParts);
+#endif
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     const QStringList types = hrdLinkType->asUnicodeString().split(QLatin1Char(','), QString::SkipEmptyParts);
+#else
+    const QStringList types = hrdLinkType->asUnicodeString().split(QLatin1Char(','), Qt::SkipEmptyParts);
+#endif
 
     if (messages.isEmpty() || types.isEmpty()) {
         return false;
@@ -430,12 +437,12 @@ bool MessageComposer::Util::hasMissingAttachments(const QStringList &attachmentK
     QStringList attachWordsList = attachmentKeywords;
 
     QRegularExpression rx(QLatin1String("\\b")
-                          +attachWordsList.join(QStringLiteral("\\b|\\b"))
+                          +attachWordsList.join(QLatin1String("\\b|\\b"))
                           +QLatin1String("\\b"), QRegularExpression::CaseInsensitiveOption);
 
     // check whether the subject contains one of the attachment key words
     // unless the message is a reply or a forwarded message
-    bool gotMatch = (MessageHelper::stripOffPrefixes(subj) == subj) && (rx.match(subj).hasMatch());
+    bool gotMatch = (MessageCore::StringUtil::stripOffPrefixes(subj) == subj) && (rx.match(subj).hasMatch());
 
     if (!gotMatch) {
         // check whether the non-quoted text contains one of the attachment key
