@@ -1,20 +1,6 @@
-/* Copyright 2009 Thomas McGuire <mcguire@kde.org>
+/* SPDX-FileCopyrightText: 2009 Thomas McGuire <mcguire@kde.org>
 
-   This library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU Library General Public License as published
-   by the Free Software Foundation; either version 2 of the License or
-   ( at your option ) version 3 or, at the discretion of KDE e.V.
-   ( which shall act as a proxy as in section 14 of the GPLv3 ), any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 #include "stringutiltest.h"
 
@@ -373,7 +359,11 @@ void StringUtilTest::test_parseMailtoUrl()
     QCOMPARE(list.count(), numberElement);
     if (numberOfTo > 0) {
         QCOMPARE(!list.at(0).second.isEmpty(), toIsNotEmpty);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         QCOMPARE(list.at(0).second.split(QLatin1String(", "), QString::SkipEmptyParts).count(), numberOfTo);
+#else
+        QCOMPARE(list.at(0).second.split(QLatin1String(", "), Qt::SkipEmptyParts).count(), numberOfTo);
+#endif
     }
 }
 
@@ -381,7 +371,7 @@ void StringUtilTest::test_parseMailtoUrlExtra()
 {
     const QByteArray ba("mailto:someone@example.com?subject=This%20is%20the%20subject&cc=someone_else@example.com&body=This%20is%20the%20body");
     QUrl url = QUrl(QUrl::fromPercentEncoding(ba));
-    QList<QPair<QString, QString> > data = StringUtil::parseMailtoUrl(url);
+    QVector<QPair<QString, QString> > data = StringUtil::parseMailtoUrl(url);
     QCOMPARE(data.size(), 4);
     for (int i = 0; i < 4; ++i) {
         if (data.at(i).first == QLatin1String("to")) {
@@ -396,11 +386,37 @@ void StringUtilTest::test_parseMailtoUrlExtra()
     }
 }
 
+void StringUtilTest::test_parseMailToWithUtf8Encoded()
+{
+    const QByteArray ba("mailto:=?utf-8?B?TWnFgm9zeg==?= Vo %3Craco.cki@foo.com%3E");
+    QUrl url = QUrl(QUrl::fromPercentEncoding(ba));
+    QVector<QPair<QString, QString> > data = StringUtil::parseMailtoUrl(url);
+    QCOMPARE(data.size(), 1);
+    for (int i = 0; i < 1; ++i) {
+        if (data.at(i).first == QLatin1String("to")) {
+            QCOMPARE(data.at(i).second, QString::fromUtf8("Mi\u0142osz Vo <raco.cki@foo.com>"));
+        }
+    }
+}
+
+void StringUtilTest::test_parseMailToWithUtf8QuotedEncoded()
+{
+    const QByteArray ba("mailto:=?utf-8?q?foo_Cen_=3Cbla=2Ecete=40kde=2Ecom=3E=2C_Kile_Debut_=3Ckile=2Edebut=40foo=2Ecom?=");
+    QUrl url = QUrl(QUrl::fromPercentEncoding(ba));
+    QVector<QPair<QString, QString> > data = StringUtil::parseMailtoUrl(url);
+    QCOMPARE(data.size(), 1);
+    for (int i = 0; i < 1; ++i) {
+        if (data.at(i).first == QLatin1String("to")) {
+            QCOMPARE(data.at(i).second, QString::fromUtf8("foo Cen <bla.cete@kde.com>, Kile Debut <kile.debut@foo.com"));
+        }
+    }
+}
+
 void StringUtilTest::test_parseMailToBug366981()
 {
     const QString ba(QStringLiteral("mailto:test@test.com?subject=test&body=line1%0D%0Aline2"));
     QUrl urlDecoded(QUrl::fromPercentEncoding(ba.toUtf8()));
-    QList<QPair<QString, QString> > data = StringUtil::parseMailtoUrl(urlDecoded);
+    QVector<QPair<QString, QString> > data = StringUtil::parseMailtoUrl(urlDecoded);
     QCOMPARE(data.size(), 3);
     for (int i = 0; i < 3; ++i) {
         if (data.at(i).first == QLatin1String("to")) {
@@ -420,17 +436,17 @@ void StringUtilTest::test_parseDuplicateQueryItems()
 {
     const QString ba(QStringLiteral("mailto:test@test.com?subject=test&body=line1%0D%0Aline2&cc=someone_else@example.com&cc=someone_else2@example.com"));
     QUrl urlDecoded(QUrl::fromPercentEncoding(ba.toUtf8()));
-    QList<QPair<QString, QString> > values = StringUtil::parseMailtoUrl(urlDecoded);
+    QVector<QPair<QString, QString> > values = StringUtil::parseMailtoUrl(urlDecoded);
     QCOMPARE(values.size(), 5);
     int valueCC = 0;
     for (int i = 0; i < values.size(); ++i) {
-        if (values.at(i).first == QLatin1Literal("to")) {
+        if (values.at(i).first == QLatin1String("to")) {
             QCOMPARE(values.at(i).second, QLatin1String("test@test.com"));
-        } else if (values.at(i).first == QLatin1Literal("subject")) {
+        } else if (values.at(i).first == QLatin1String("subject")) {
             QCOMPARE(values.at(i).second, QLatin1String("test"));
-        } else if (values.at(i).first == QLatin1Literal("body")) {
+        } else if (values.at(i).first == QLatin1String("body")) {
             QCOMPARE(values.at(i).second, QLatin1String("line1\r\nline2"));
-        } else if (values.at(i).first == QLatin1Literal("cc")) {
+        } else if (values.at(i).first == QLatin1String("cc")) {
             const QString ccVal = values.at(i).second;
             valueCC++;
             if ((ccVal != QLatin1String("someone_else@example.com")) && (ccVal != QLatin1String("someone_else2@example.com"))) {
@@ -446,7 +462,7 @@ void StringUtilTest::test_parseMAilToBug402378()
     const QString ba(QStringLiteral(
                          "mailto:?body=infotbm.com https://www.infotbm.com/fr/routes/id=-0.624162|44.849958&type=address/datetime=20181226T143038&id=stop_area:TBT:SA:HTLEV&time_type=arrival&type=stop_area/0&subject=Votre itineraire avec TBM"));
     QUrl urlDecoded(QUrl::fromPercentEncoding(ba.toUtf8()));
-    QList<QPair<QString, QString> > data = StringUtil::parseMailtoUrl(urlDecoded);
+    QVector<QPair<QString, QString> > data = StringUtil::parseMailtoUrl(urlDecoded);
     QCOMPARE(data.size(), 6);
     QCOMPARE(data.at(0).first, QLatin1String("body"));
     QCOMPARE(data.at(0).second, QLatin1String(
@@ -463,12 +479,42 @@ void StringUtilTest::test_parseMAilToBug402378()
     QCOMPARE(data.at(5).second, QLatin1String("Votre itineraire avec TBM"));
 }
 
+void StringUtilTest::test_parseMailToBug406208()
+{
+    {
+        QString ba(QStringLiteral(
+                       "mailto:?body=http%3A%2F%2Fwww.lecourrierdelarchitecte.com%2Farticle_8428&subject=Le%20Courrier%20l'effet%20%23metoo%20%3F"));
+        QUrl urlDecoded(QUrl::fromPercentEncoding(ba.toUtf8()));
+        //qDebug() << " urlDecoded" << urlDecoded.authority(QUrl::FullyDecoded);
+        QVector<QPair<QString, QString> > data = StringUtil::parseMailtoUrl(urlDecoded);
+        QCOMPARE(data.size(), 2);
+        QCOMPARE(data.at(0).first, QLatin1String("body"));
+        QCOMPARE(data.at(0).second, QLatin1String(
+                     "http://www.lecourrierdelarchitecte.com/article_8428"));
+        QCOMPARE(data.at(1).first, QLatin1String("subject"));
+        QCOMPARE(data.at(1).second, QLatin1String("Le Courrier l'effet #metoo ?"));
+    }
+    {
+        QString ba(QStringLiteral(
+                       "mailto:?body=http%3A%2F%2Fwww.lecourrierdelarchitecte.com%2Farticle_8428%20%23%23bla&subject=Le%20Courrier%20l'effet%20%23metoo%20%3F"));
+        QUrl urlDecoded(QUrl::fromPercentEncoding(ba.toUtf8()));
+        //qDebug() << " urlDecoded" << urlDecoded.authority(QUrl::FullyDecoded);
+        QVector<QPair<QString, QString> > data = StringUtil::parseMailtoUrl(urlDecoded);
+        QCOMPARE(data.size(), 2);
+        QCOMPARE(data.at(0).first, QLatin1String("body"));
+        QCOMPARE(data.at(0).second, QLatin1String(
+                     "http://www.lecourrierdelarchitecte.com/article_8428 ##bla"));
+        QCOMPARE(data.at(1).first, QLatin1String("subject"));
+        QCOMPARE(data.at(1).second, QLatin1String("Le Courrier l'effet #metoo ?"));
+    }
+}
+
 void StringUtilTest::test_parseMailToBug832795()
 {
     const QString ba(QStringLiteral(
                          "mailto:832795@bugs.debian.org?In-Reply-To=%3C146974194340.26747.4814466130640572267.reportbug%40portux.lan.naturalnet.de%3E&subject=Re%3A%20kmail%3A%20unescaping%20mailto%3A%20links%20broken&body=On%20Thu%2C%2028%20Jul%202016References=%3C146974194340.26747.4814466130640572267.reportbug%40portux.lan.naturalnet.de%3Ebody=On%20Thu%2C%2028%20Jul%202016%2023%3A39%3A03%20%2B0200%20Dominik%20George%20%3Cnik%40naturalnet.de%3E%20wrote%3A%0A%3E%20Package%3A%20kmail%0A%3E%20Version%3A%204%3A16.04.3-1%0A"));
     QUrl urlDecoded(QUrl::fromPercentEncoding(ba.toUtf8()));
-    QList<QPair<QString, QString> > data = StringUtil::parseMailtoUrl(urlDecoded);
+    QVector<QPair<QString, QString> > data = StringUtil::parseMailtoUrl(urlDecoded);
     QCOMPARE(data.size(), 4);
     QCOMPARE(data.at(0).first, QLatin1String("to"));
     QCOMPARE(data.at(0).second, QLatin1String("832795@bugs.debian.org"));
@@ -479,7 +525,69 @@ void StringUtilTest::test_parseMailToBug832795()
     QCOMPARE(data.at(3).first, QLatin1String("body"));
     QCOMPARE(data.at(3).second, QLatin1String(
                  "On Thu, 28 Jul 2016References=<146974194340.26747.4814466130640572267.reportbug@portux.lan.naturalnet.de>body=On Thu, 28 Jul 2016 23:39:03 +0200 Dominik George <nik@naturalnet.de> wrote:\n> Package: kmail\n> Version: 4:16.04.3-1\n"));
+}
 
+void StringUtilTest::test_crashXdgemail()
+{
+    const QString ba(QStringLiteral("mailto:foo@kde.org?to=bar@kde.org&to=baz@kde.org"));
+    QUrl urlDecoded(QUrl::fromPercentEncoding(ba.toUtf8()));
+    QVector<QPair<QString, QString> > values = StringUtil::parseMailtoUrl(urlDecoded);
+    QCOMPARE(values.size(), 1);
+    QCOMPARE(values.at(0).first, QLatin1String("to"));
+    QCOMPARE(values.at(0).second, QLatin1String("foo@kde.org, bar@kde.org, baz@kde.org"));
+}
+
+void StringUtilTest::test_xdgemail()
+{
+    {
+        const QString ba(QStringLiteral("mailto:foo@kde.org?to=bar@kde.org&to=baz@kde.org&cc=bli@kde.org"));
+        QUrl urlDecoded(QUrl::fromPercentEncoding(ba.toUtf8()));
+        QVector<QPair<QString, QString> > values = StringUtil::parseMailtoUrl(urlDecoded);
+        QCOMPARE(values.size(), 2);
+        QCOMPARE(values.at(0).first, QLatin1String("to"));
+        QCOMPARE(values.at(0).second, QLatin1String("foo@kde.org, bar@kde.org, baz@kde.org"));
+        QCOMPARE(values.at(1).first, QLatin1String("cc"));
+        QCOMPARE(values.at(1).second, QLatin1String("bli@kde.org"));
+    }
+    {
+        const QString ba(QStringLiteral("mailto:foo@kde.org?to=bar@kde.org&to=baz@kde.org&cc=ss@kde.org&bcc=ccs@kde.org"));
+        QUrl urlDecoded(QUrl::fromPercentEncoding(ba.toUtf8()));
+        QVector<QPair<QString, QString> > values = StringUtil::parseMailtoUrl(urlDecoded);
+        QCOMPARE(values.size(), 3);
+        QCOMPARE(values.at(0).first, QLatin1String("to"));
+        QCOMPARE(values.at(0).second, QLatin1String("foo@kde.org, bar@kde.org, baz@kde.org"));
+        QCOMPARE(values.at(1).first, QLatin1String("cc"));
+        QCOMPARE(values.at(1).second, QLatin1String("ss@kde.org"));
+        QCOMPARE(values.at(2).first, QLatin1String("bcc"));
+        QCOMPARE(values.at(2).second, QLatin1String("ccs@kde.org"));
+    }
+    {
+        const QString ba(QStringLiteral("mailto:foo@kde.org?to=bar@kde.org&to=baz@kde.org&cc=ss@kde.org&bcc=ccs@kde.org&to=ff@kde.org"));
+        QUrl urlDecoded(QUrl::fromPercentEncoding(ba.toUtf8()));
+        QVector<QPair<QString, QString> > values = StringUtil::parseMailtoUrl(urlDecoded);
+        QCOMPARE(values.size(), 3);
+        QCOMPARE(values.at(0).first, QLatin1String("cc"));
+        QCOMPARE(values.at(0).second, QLatin1String("ss@kde.org"));
+        QCOMPARE(values.at(1).first, QLatin1String("bcc"));
+        QCOMPARE(values.at(1).second, QLatin1String("ccs@kde.org"));
+        QCOMPARE(values.at(2).first, QLatin1String("to"));
+        QCOMPARE(values.at(2).second, QLatin1String("foo@kde.org, bar@kde.org, baz@kde.org, ff@kde.org"));
+    }
+    {
+        //Bug 427697
+        const QByteArray ba(QByteArrayLiteral("mailto:julia.lawall%40inria.fr?In-Reply-To=%3Calpine.DEB.2.22.394.2009272255220.20726@hadrien%3E&#38;Cc=Gilles.Muller%40lip6.fr%2Ccocci%40systeme.lip6.fr%2Ccorbet%40lwn.net%2Clinux-doc%40vger.kernel.org%2Clinux-kernel%40vger.kernel.org%2Cmichal.lkml%40markovi.net%2Cnicolas.palix%40imag.fr%2Csylphrenadin%40gmail.com&#38;Subject=Re%3A%20%5BCocci%5D%20%5BPATCH%201%2F2%5D%20scripts%3A%20coccicheck%3A%20Change%20default%20value%20for%09parallelism"));
+        QUrl urlDecoded(QUrl::fromPercentEncoding(ba));
+        QVector<QPair<QString, QString> > values = StringUtil::parseMailtoUrl(urlDecoded);
+        QCOMPARE(values.size(), 4);
+        QCOMPARE(values.at(0).first, QLatin1String("to"));
+        QCOMPARE(values.at(0).second, QLatin1String("julia.lawall@inria.fr"));
+        QCOMPARE(values.at(1).first, QLatin1String("in-reply-to"));
+        QCOMPARE(values.at(1).second, QLatin1String("<alpine.DEB.2.22.394.2009272255220.20726@hadrien>"));
+        QCOMPARE(values.at(2).first, QLatin1String("cc"));
+        QCOMPARE(values.at(2).second, QLatin1String("Gilles.Muller@lip6.fr,cocci@systeme.lip6.fr,corbet@lwn.net,linux-doc@vger.kernel.org,linux-kernel@vger.kernel.org,michal.lkml@markovi.net,nicolas.palix@imag.fr,sylphrenadin@gmail.com"));
+        QCOMPARE(values.at(3).first, QLatin1String("subject"));
+        QCOMPARE(values.at(3).second, QLatin1String("Re: [Cocci] [PATCH 1/2] scripts: coccicheck: Change default value for\tparallelism"));
+    }
 }
 
 void StringUtilTest::test_stripOffMessagePrefix_data()
