@@ -1,31 +1,19 @@
 /******************************************************************************
  *
- *  Copyright 2008 Szymon Tomasz Stefanek <pragma@kvirc.net>
+ *  SPDX-FileCopyrightText: 2008 Szymon Tomasz Stefanek <pragma@kvirc.net>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  *
  *******************************************************************************/
 
-#ifndef __MESSAGELIST_CORE_ITEM_P_H__
-#define __MESSAGELIST_CORE_ITEM_P_H__
+#ifndef MESSAGELIST_CORE_ITEM_P_H
+#define MESSAGELIST_CORE_ITEM_P_H
 
 #include "core/item.h"
 
 #include "MessageCore/StringUtil"
 
-// See the MessageList::ItemPrivate::insertChildItem() function below for an explaination of this macro.
+// See the MessageList::ItemPrivate::insertChildItem() function below for an explanation of this macro.
 #if __GNUC__ >= 3  //krazy:exclude=cpp
 #define GCC_DONT_INLINE_THIS __attribute__((noinline))
 #else
@@ -242,13 +230,14 @@ public:
     QString mSender;                            ///< The sender of the message (or group sender)
     QString mReceiver;                          ///< The receiver of the message (or group receiver)
     QString mSubject;                           ///< The subject of the message (or group subject)
+    QString mFolder;                            ///< The folder of the message
     qint64 mItemId;                             ///< The Akonadi item id
     qint64 mParentCollectionId;                 ///< The Akonadi ID of collection that this particular item comes from (can be virtual collection)
     Akonadi::MessageStatus mStatus;             ///< The status of the message (may be extended to groups in the future)
     int mThisItemIndexGuess;                    ///< The guess for the index in the parent's child list
     Item::Type mType : 4;                       ///< The type of this item
     Item::InitialExpandStatus mInitialExpandStatus : 4; ///< The expand status we have to honor when we attach to the viewable root
-    bool mIsViewable : 1;                       ///< Is this item attacched to the viewable root ?
+    bool mIsViewable : 1;                       ///< Is this item attached to the viewable root ?
     bool mUseReceiver : 1;                      ///< senderOrReceiver() returns receiver rather than sender
 };
 
@@ -506,4 +495,4 @@ public:
 } // namespace Core
 } // namespace MessageList
 
-#endif //!__MESSAGELIST_CORE_ITEM_P_H__
+#endif //!__MESSAGELIST_CORE_ITEM_P_H
