@@ -1,20 +1,8 @@
 /******************************************************************************
  *
- *  Copyright 2008 Szymon Tomasz Stefanek <pragma@kvirc.net>
+ *  SPDX-FileCopyrightText: 2008 Szymon Tomasz Stefanek <pragma@kvirc.net>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  *
  *******************************************************************************/
 
@@ -37,19 +25,17 @@
 #include "MessageCore/MessageCoreSettings"
 
 #include "messagelistutil.h"
+#include "messagelistutil_p.h"
 
-#include <QPixmap>
 #include <kmime/kmime_dateformatter.h> // kdepimlibs
 
 #include <KConfig>
 #include "messagelist_debug.h"
 #include <KLocalizedString>
 
-#include <QStandardPaths>
-
 using namespace MessageList::Core;
 
-Manager *Manager::mInstance = Q_NULLPTR;
+Manager *Manager::mInstance = nullptr;
 
 Manager::Manager()
     : QObject()
@@ -58,87 +44,29 @@ Manager::Manager()
 
     mDateFormatter = new KMime::DateFormatter();
 
-    mPixmapMessageNew = new QPixmap(QIcon::fromTheme(QStringLiteral("mail-unread-new")).pixmap(64, 64));
-    mPixmapMessageUnread = new QPixmap(QIcon::fromTheme(QStringLiteral("mail-unread")).pixmap(64, 64));
-    mPixmapMessageRead = new QPixmap(QIcon::fromTheme(QStringLiteral("mail-read")).pixmap(64, 64));
-    mPixmapMessageDeleted = new QPixmap(QIcon::fromTheme(QStringLiteral("mail-deleted")).pixmap(64, 64));
-    mPixmapMessageReplied = new QPixmap(QIcon::fromTheme(QStringLiteral("mail-replied")).pixmap(64, 64));
-    mPixmapMessageRepliedAndForwarded = new QPixmap(QIcon::fromTheme(QStringLiteral("mail-forwarded-replied")).pixmap(64, 64));
-    mPixmapMessageQueued = new QPixmap(QIcon::fromTheme(QStringLiteral("mail-queued")).pixmap(64, 64));       // mail-queue ?
-    mPixmapMessageActionItem = new QPixmap(QIcon::fromTheme(QStringLiteral("mail-task")).pixmap(64, 64));
-    mPixmapMessageSent = new QPixmap(QIcon::fromTheme(QStringLiteral("mail-sent")).pixmap(64, 64));
-    mPixmapMessageForwarded = new QPixmap(QIcon::fromTheme(QStringLiteral("mail-forwarded")).pixmap(64, 64));
-    mPixmapMessageImportant = new QPixmap(QIcon::fromTheme(QStringLiteral("emblem-important")).pixmap(64, 64));       // "flag"
-    mPixmapMessageWatched = new QPixmap(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("messagelist/pics/mail-thread-watch.png")));
-    mPixmapMessageIgnored = new QPixmap(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("messagelist/pics/mail-thread-ignored.png")));
-    mPixmapMessageSpam = new QPixmap(QIcon::fromTheme(QStringLiteral("mail-mark-junk")).pixmap(64, 64));
-    mPixmapMessageHam = new QPixmap(QIcon::fromTheme(QStringLiteral("mail-mark-notjunk")).pixmap(64, 64));
-    mPixmapMessageFullySigned = new QPixmap(QIcon::fromTheme(QStringLiteral("mail-signed-verified")).pixmap(64, 64));
-    mPixmapMessagePartiallySigned = new QPixmap(QIcon::fromTheme(QStringLiteral("mail-signed-part")).pixmap(64, 64));
-    mPixmapMessageUndefinedSigned = new QPixmap(QIcon::fromTheme(QStringLiteral("mail-signed")).pixmap(64, 64));
-    mPixmapMessageNotSigned = new QPixmap(QIcon::fromTheme(QStringLiteral("text-plain")).pixmap(64, 64));
-    mPixmapMessageFullyEncrypted = new QPixmap(QIcon::fromTheme(QStringLiteral("mail-encrypted-full")).pixmap(64, 64));
-    mPixmapMessagePartiallyEncrypted = new QPixmap(QIcon::fromTheme(QStringLiteral("mail-encrypted-part")).pixmap(64, 64));
-    mPixmapMessageUndefinedEncrypted = new QPixmap(QIcon::fromTheme(QStringLiteral("mail-encrypted")).pixmap(64, 64));
-    mPixmapMessageNotEncrypted = new QPixmap(QIcon::fromTheme(QStringLiteral("text-plain")).pixmap(64, 64));
-    mPixmapMessageAttachment = new QPixmap(QIcon::fromTheme(QStringLiteral("mail-attachment")).pixmap(64, 64));
-    mPixmapMessageAnnotation = new QPixmap(QIcon::fromTheme(QStringLiteral("view-pim-notes")).pixmap(64, 64));
-    mPixmapMessageInvitation = new QPixmap(QIcon::fromTheme(QStringLiteral("mail-invitation")).pixmap(64, 64));
-    if (QApplication::isRightToLeft()) {
-        mPixmapShowMore = new QPixmap(QIcon::fromTheme(QStringLiteral("arrow-left")).pixmap(64, 64));
-    } else {
-        mPixmapShowMore = new QPixmap(QIcon::fromTheme(QStringLiteral("arrow-right")).pixmap(64, 64));
-    }
-    mPixmapShowLess = new QPixmap(QIcon::fromTheme(QStringLiteral("arrow-down")).pixmap(64, 64));
-    mPixmapVerticalLine = new QPixmap(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("messagelist/pics/mail-vertical-separator-line.png")));
-    mPixmapHorizontalSpacer = new QPixmap(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("messagelist/pics/mail-horizontal-space.png")));
-
     mCachedLocalizedUnknownText = i18nc("Unknown date", "Unknown");
 
     loadConfiguration();
-    connect(MessageListSettings::self(), &MessageListSettings::configChanged, this, &Manager::reloadGlobalConfiguration);
+    connect(MessageListSettings::self(), &MessageListSettings::configChanged,
+            this, &Manager::reloadGlobalConfiguration);
+    connect(MessageCore::MessageCoreSettings::self(), &MessageCore::MessageCoreSettings::configChanged,
+            this, &Manager::reloadGlobalConfiguration);
 }
 
 Manager::~Manager()
 {
+    disconnect(MessageListSettings::self(), &MessageListSettings::configChanged,
+            this, &Manager::reloadGlobalConfiguration);
+    disconnect(MessageCore::MessageCoreSettings::self(), &MessageCore::MessageCoreSettings::configChanged,
+            this, &Manager::reloadGlobalConfiguration);
+
     saveConfiguration();
     removeAllAggregations();
     removeAllThemes();
 
-    delete mPixmapMessageNew;
-    delete mPixmapMessageUnread;
-    delete mPixmapMessageRead;
-    delete mPixmapMessageDeleted;
-    delete mPixmapMessageReplied;
-    delete mPixmapMessageRepliedAndForwarded;
-    delete mPixmapMessageQueued;
-    delete mPixmapMessageActionItem;
-    delete mPixmapMessageSent;
-    delete mPixmapMessageForwarded;
-    delete mPixmapMessageImportant; // "flag"
-    delete mPixmapMessageWatched;
-    delete mPixmapMessageIgnored;
-    delete mPixmapMessageSpam;
-    delete mPixmapMessageHam;
-    delete mPixmapMessageFullySigned;
-    delete mPixmapMessagePartiallySigned;
-    delete mPixmapMessageUndefinedSigned;
-    delete mPixmapMessageNotSigned;
-    delete mPixmapMessageFullyEncrypted;
-    delete mPixmapMessagePartiallyEncrypted;
-    delete mPixmapMessageUndefinedEncrypted;
-    delete mPixmapMessageNotEncrypted;
-    delete mPixmapMessageAttachment;
-    delete mPixmapMessageAnnotation;
-    delete mPixmapMessageInvitation;
-    delete mPixmapShowMore;
-    delete mPixmapShowLess;
-    delete mPixmapVerticalLine;
-    delete mPixmapHorizontalSpacer;
-
     delete mDateFormatter;
 
-    mInstance = Q_NULLPTR;
+    mInstance = nullptr;
 }
 
 void Manager::registerWidget(Widget *pWidget)
@@ -161,7 +89,7 @@ void Manager::unregisterWidget(Widget *pWidget)
 
     if (mInstance->mWidgetList.isEmpty()) {
         delete mInstance;
-        mInstance = Q_NULLPTR;
+        mInstance = nullptr;
     }
 }
 
@@ -182,7 +110,7 @@ const Aggregation *Manager::defaultAggregation()
 
     const QString aggregationId = conf.readEntry(QStringLiteral("DefaultSet"), "");
 
-    Aggregation *opt = Q_NULLPTR;
+    Aggregation *opt = nullptr;
 
     if (!aggregationId.isEmpty()) {
         opt = mAggregations.value(aggregationId);
@@ -193,7 +121,7 @@ const Aggregation *Manager::defaultAggregation()
     }
 
     // try just the first one
-    QHash< QString, Aggregation * >::ConstIterator it = mAggregations.constBegin();
+    QMap< QString, Aggregation * >::ConstIterator it = mAggregations.constBegin();
     if (it != mAggregations.constEnd()) {
         return *it;
     }
@@ -264,12 +192,12 @@ const Aggregation *Manager::aggregationForStorageModel(const QString &storageId,
 
     const QString aggregationId = conf.readEntry(MessageList::Util::setForStorageModelConfigName().arg(storageId), "");
 
-    Aggregation *opt = Q_NULLPTR;
+    Aggregation *opt = nullptr;
 
     if (!aggregationId.isEmpty()) {
         // a private aggregation was stored
         opt = mAggregations.value(aggregationId);
-        *storageUsesPrivateAggregation = (opt != Q_NULLPTR);
+        *storageUsesPrivateAggregation = (opt != nullptr);
     }
 
     if (opt) {
@@ -298,7 +226,7 @@ void Manager::createDefaultAggregations()
                  "Messages are threaded. " \
                  "So for example, in \"Today\" you will find all the messages arrived today " \
                  "and all the threads that have been active today."
-                ),
+                 ),
             Aggregation::GroupByDateRange,
             Aggregation::ExpandRecentGroups,
             Aggregation::PerfectReferencesAndSubject,
@@ -306,8 +234,8 @@ void Manager::createDefaultAggregations()
             Aggregation::ExpandThreadsWithUnreadOrImportantMessages,
             Aggregation::FavorInteractivity,
             true
-        )
-    );
+            )
+        );
 
     addAggregation(
         new Aggregation(
@@ -315,7 +243,7 @@ void Manager::createDefaultAggregations()
             i18n("This view uses smart date range groups. " \
                  "Messages are not threaded. " \
                  "So for example, in \"Today\" you will simply find all the messages arrived today."
-                ),
+                 ),
             Aggregation::GroupByDateRange,
             Aggregation::ExpandRecentGroups,
             Aggregation::NoThreading,
@@ -323,8 +251,8 @@ void Manager::createDefaultAggregations()
             Aggregation::NeverExpandThreads,
             Aggregation::FavorInteractivity,
             true
-        )
-    );
+            )
+        );
 
     addAggregation(
         new Aggregation(
@@ -333,7 +261,7 @@ void Manager::createDefaultAggregations()
                  "Messages are threaded. " \
                  "So for example, in \"Today\" you will find all the messages arrived today " \
                  "and all the threads that have been active today."
-                ),
+                 ),
             Aggregation::GroupByDate,
             Aggregation::ExpandRecentGroups,
             Aggregation::PerfectReferencesAndSubject,
@@ -341,8 +269,8 @@ void Manager::createDefaultAggregations()
             Aggregation::ExpandThreadsWithUnreadOrImportantMessages,
             Aggregation::FavorInteractivity,
             true
-        )
-    );
+            )
+        );
 
     addAggregation(
         new Aggregation(
@@ -350,7 +278,7 @@ void Manager::createDefaultAggregations()
             i18n("This view uses day-by-day groups. " \
                  "Messages are not threaded. " \
                  "So for example, in \"Today\" you will simply find all the messages arrived today."
-                ),
+                 ),
             Aggregation::GroupByDate,
             Aggregation::ExpandRecentGroups,
             Aggregation::NoThreading,
@@ -358,8 +286,8 @@ void Manager::createDefaultAggregations()
             Aggregation::NeverExpandThreads,
             Aggregation::FavorInteractivity,
             true
-        )
-    );
+            )
+        );
 
     addAggregation(
         new Aggregation(
@@ -372,14 +300,14 @@ void Manager::createDefaultAggregations()
             Aggregation::ExpandThreadsWithUnreadOrImportantMessages,
             Aggregation::FavorInteractivity,
             true
-        )
-    );
+            )
+        );
 
     addAggregation(
         new Aggregation(
             i18n("Flat Date View"),
             i18n("This is a plain and old list of messages sorted by date: no groups and no threading." \
-                ),
+                 ),
             Aggregation::NoGrouping,
             Aggregation::NeverExpandGroups,
             Aggregation::NoThreading,
@@ -388,8 +316,8 @@ void Manager::createDefaultAggregations()
             Aggregation::FavorInteractivity,
             true
 
-        )
-    );
+            )
+        );
 
     addAggregation(
         new Aggregation(
@@ -397,7 +325,7 @@ void Manager::createDefaultAggregations()
             i18n("This view groups the messages by senders or receivers (depending on the folder " \
                  "type). " \
                  "Messages are not threaded."
-                ),
+                 ),
             Aggregation::GroupBySenderOrReceiver,
             Aggregation::NeverExpandGroups,
             Aggregation::NoThreading,
@@ -405,8 +333,8 @@ void Manager::createDefaultAggregations()
             Aggregation::NeverExpandThreads,
             Aggregation::FavorSpeed,
             true
-        )
-    );
+            )
+        );
 
     addAggregation(
         new Aggregation(
@@ -419,8 +347,8 @@ void Manager::createDefaultAggregations()
             Aggregation::NeverExpandThreads,
             Aggregation::FavorSpeed,
             true
-        )
-    );
+            )
+        );
 
     /*
     FIX THIS
@@ -444,8 +372,8 @@ void Manager::createDefaultAggregations()
 
 void Manager::removeAllAggregations()
 {
-    QHash< QString, Aggregation * >::ConstIterator end(mAggregations.constEnd());
-    for (QHash< QString, Aggregation * >::ConstIterator it = mAggregations.constBegin(); it != end; ++it) {
+    QMap< QString, Aggregation * >::ConstIterator end(mAggregations.constEnd());
+    for (QMap< QString, Aggregation * >::ConstIterator it = mAggregations.constBegin(); it != end; ++it) {
         delete(*it);
     }
 
@@ -480,8 +408,7 @@ const SortOrder Manager::sortOrderForStorageModel(const StorageModel *storageMod
     return ret;
 }
 
-void Manager::saveSortOrderForStorageModel(const StorageModel *storageModel,
-        const SortOrder &order, bool storageUsesPrivateSortOrder)
+void Manager::saveSortOrderForStorageModel(const StorageModel *storageModel, SortOrder order, bool storageUsesPrivateSortOrder)
 {
     KConfigGroup conf(MessageListSettings::self()->config(), MessageList::Util::storageModelSortOrderGroup());
     order.writeConfig(conf, storageModel->id(), storageUsesPrivateSortOrder);
@@ -503,7 +430,7 @@ const Theme *Manager::defaultTheme()
 
     const QString themeId = conf.readEntry(QStringLiteral("DefaultSet"), "");
 
-    Theme *opt = Q_NULLPTR;
+    Theme *opt = nullptr;
 
     if (!themeId.isEmpty()) {
         opt = mThemes.value(themeId);
@@ -514,7 +441,7 @@ const Theme *Manager::defaultTheme()
     }
 
     // try just the first one
-    QHash< QString, Theme * >::ConstIterator it = mThemes.constBegin();
+    QMap< QString, Theme * >::ConstIterator it = mThemes.constBegin();
     if (it != mThemes.constEnd()) {
         return *it;
     }
@@ -554,7 +481,7 @@ void Manager::saveThemeForStorageModel(const QString &storageModelIndex, const Q
     }
 }
 
-const Theme *Manager::themeForStorageModel(const Akonadi::Collection &col,  bool *storageUsesPrivateTheme)
+const Theme *Manager::themeForStorageModel(const Akonadi::Collection &col, bool *storageUsesPrivateTheme)
 {
     Q_ASSERT(storageUsesPrivateTheme);
 
@@ -564,12 +491,10 @@ const Theme *Manager::themeForStorageModel(const Akonadi::Collection &col,  bool
         return defaultTheme();
     }
     return Manager::themeForStorageModel(QString::number(col.id()), storageUsesPrivateTheme);
-
 }
 
 const Theme *Manager::themeForStorageModel(const StorageModel *storageModel, bool *storageUsesPrivateTheme)
 {
-
     Q_ASSERT(storageUsesPrivateTheme);
 
     *storageUsesPrivateTheme = false; // this is by default
@@ -585,12 +510,12 @@ const Theme *Manager::themeForStorageModel(const QString &id, bool *storageUsesP
     KConfigGroup conf(MessageListSettings::self()->config(), MessageList::Util::storageModelThemesGroup());
     const QString themeId = conf.readEntry(MessageList::Util::setForStorageModelConfigName().arg(id), "");
 
-    Theme *opt = Q_NULLPTR;
+    Theme *opt = nullptr;
 
     if (!themeId.isEmpty()) {
         // a private theme was stored
         opt = mThemes.value(themeId);
-        *storageUsesPrivateTheme = (opt != Q_NULLPTR);
+        *storageUsesPrivateTheme = (opt != nullptr);
     }
 
     if (opt) {
@@ -684,7 +609,7 @@ void Manager::createDefaultThemes()
     s = new Theme(
         i18nc("Default theme name", "Classic"),
         i18n("A simple, backward compatible, single row theme"), true   /*readOnly*/
-    );
+        );
 
     c = new Theme::Column();
     c->setLabel(i18nc("@title:column Subject of messages", "Subject"));
@@ -729,10 +654,12 @@ void Manager::createDefaultThemes()
     add_theme_simple_text_column(s, i18nc("Date of a message", "Date"), Theme::ContentItem::Date, true, SortOrder::SortMessagesByDateTime, false, false);
     add_theme_simple_text_column(s, i18n("Most Recent Date"), Theme::ContentItem::MostRecentDate, false, SortOrder::SortMessagesByDateTimeOfMostRecent, false, true);
     add_theme_simple_text_column(s, i18nc("Size of a message", "Size"), Theme::ContentItem::Size, false, SortOrder::SortMessagesBySize, false, false);
-    add_theme_simple_icon_column(s, i18nc("Attachement indication", "Attachment"), QStringLiteral("mail-attachment"), Theme::ContentItem::AttachmentStateIcon, false, SortOrder::SortMessagesByAttachmentStatus);
-    add_theme_simple_icon_column(s, i18n("Read/Unread"), QStringLiteral("mail-unread-new"), Theme::ContentItem::ReadStateIcon, false, SortOrder::SortMessagesByUnreadStatus);
+    add_theme_simple_icon_column(s, i18nc("Attachment indication", "Attachment"), QStringLiteral(
+                                     "mail-attachment"), Theme::ContentItem::AttachmentStateIcon, false, SortOrder::SortMessagesByAttachmentStatus);
+    add_theme_simple_icon_column(s, i18n("Read/Unread"), QStringLiteral("mail-mark-unread-new"), Theme::ContentItem::ReadStateIcon, false, SortOrder::SortMessagesByUnreadStatus);
     add_theme_simple_icon_column(s, i18n("Replied"), QStringLiteral("mail-replied"), Theme::ContentItem::RepliedStateIcon, false, SortOrder::NoMessageSorting);
-    add_theme_simple_icon_column(s, i18nc("Message importance indication", "Important"), QStringLiteral("emblem-important"), Theme::ContentItem::ImportantStateIcon, false, SortOrder::SortMessagesByImportantStatus);
+    add_theme_simple_icon_column(s, i18nc("Message importance indication", "Important"), QStringLiteral(
+                                     "mail-mark-important"), Theme::ContentItem::ImportantStateIcon, false, SortOrder::SortMessagesByImportantStatus);
     add_theme_simple_icon_column(s, i18n("Action Item"), QStringLiteral("mail-task"), Theme::ContentItem::ActionItemStateIcon, false, SortOrder::SortMessagesByActionItemStatus);
     add_theme_simple_icon_column(s, i18n("Spam/Ham"), QStringLiteral("mail-mark-junk"), Theme::ContentItem::SpamHamStateIcon, false, SortOrder::NoMessageSorting);
     add_theme_simple_icon_column(s, i18n("Watched/Ignored"), QStringLiteral("mail-thread-watch"), Theme::ContentItem::WatchedIgnoredStateIcon, false, SortOrder::NoMessageSorting);
@@ -749,7 +676,7 @@ void Manager::createDefaultThemes()
     s = new Theme(
         i18n("Smart"),
         i18n("A smart multiline and multi item theme"), true   /*readOnly*/
-    );
+        );
 
     c = new Theme::Column();
     c->setLabel(i18n("Message"));
@@ -871,8 +798,8 @@ void Manager::createDefaultThemes()
 
 void Manager::removeAllThemes()
 {
-    QHash< QString, Theme * >::ConstIterator end(mThemes.constEnd());
-    for (QHash< QString, Theme * >::ConstIterator it = mThemes.constBegin(); it != end; ++it) {
+    QMap< QString, Theme * >::ConstIterator end(mThemes.constEnd());
+    for (QMap< QString, Theme * >::ConstIterator it = mThemes.constBegin(); it != end; ++it) {
         delete(*it);
     }
 
@@ -893,7 +820,6 @@ void Manager::themesConfigurationCompleted()
 
 void Manager::reloadAllWidgets()
 {
-
     QList< Widget * >::ConstIterator end(mWidgetList.constEnd());
     for (QList< Widget * >::ConstIterator it = mWidgetList.constBegin(); it != end; ++it) {
         if ((*it)->view()) {
@@ -911,9 +837,9 @@ void Manager::reloadGlobalConfiguration()
     loadGlobalConfiguration();
 
     if (
-        (oldDateFormat != (int)mDateFormatter->format()) ||
-        (oldDateCustomFormat != mDateFormatter->customFormat())
-    ) {
+        (oldDateFormat != (int)mDateFormatter->format())
+        || (oldDateCustomFormat != mDateFormatter->customFormat())
+        ) {
         reloadAllWidgets();
     }
 }
@@ -922,7 +848,7 @@ void Manager::loadGlobalConfiguration()
 {
     // Load the date format
     const KMime::DateFormatter::FormatType type = static_cast<KMime::DateFormatter::FormatType>(
-                MessageCore::MessageCoreSettings::self()->dateFormat());
+        MessageCore::MessageCoreSettings::self()->dateFormat());
     mDateFormatter->setCustomFormat(MessageCore::MessageCoreSettings::self()->customDateFormat());
     mDateFormatter->setFormat(type);
 }
@@ -995,7 +921,6 @@ void Manager::loadConfiguration()
             createDefaultThemes();
         }
     }
-
 }
 
 void Manager::saveGlobalConfiguration()
@@ -1016,8 +941,8 @@ void Manager::saveConfiguration()
         conf.writeEntry("Count", mAggregations.count());
 
         int idx = 0;
-        QHash< QString, Aggregation * >::ConstIterator end(mAggregations.end());
-        for (QHash< QString, Aggregation * >::ConstIterator it = mAggregations.constBegin(); it != end; ++it) {
+        QMap< QString, Aggregation * >::ConstIterator end(mAggregations.end());
+        for (QMap< QString, Aggregation * >::ConstIterator it = mAggregations.constBegin(); it != end; ++it) {
             conf.writeEntry(QStringLiteral("Set%1").arg(idx), (*it)->saveToString());
             ++idx;
         }
@@ -1032,8 +957,8 @@ void Manager::saveConfiguration()
         conf.writeEntry("Count", mThemes.count());
 
         int idx = 0;
-        QHash< QString, Theme * >::ConstIterator end(mThemes.constEnd());
-        for (QHash< QString, Theme * >::ConstIterator it = mThemes.constBegin(); it != end; ++it) {
+        QMap< QString, Theme * >::ConstIterator end(mThemes.constEnd());
+        for (QMap< QString, Theme * >::ConstIterator it = mThemes.constBegin(); it != end; ++it) {
             conf.writeEntry(QStringLiteral("Set%1").arg(idx), (*it)->saveToString());
             ++idx;
         }
@@ -1041,4 +966,3 @@ void Manager::saveConfiguration()
 
     MessageListSettings::self()->config()->sync();
 }
-
