@@ -1,25 +1,13 @@
 /******************************************************************************
  *
- *  Copyright 2008 Szymon Tomasz Stefanek <pragma@kvirc.net>
+ *  SPDX-FileCopyrightText: 2008 Szymon Tomasz Stefanek <pragma@kvirc.net>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  *
  *******************************************************************************/
 
-#ifndef __MESSAGELIST_CORE_MODELINVARIANTINDEX_P_H__
-#define __MESSAGELIST_CORE_MODELINVARIANTINDEX_P_H__
+#ifndef MESSAGELIST_CORE_MODELINVARIANTINDEX_P_H
+#define MESSAGELIST_CORE_MODELINVARIANTINDEX_P_H
 
 #include "core/modelinvariantindex.h"
 
@@ -61,4 +49,4 @@ public:
 } // namespace Core
 } // namespace MessageList
 
-#endif //!__MESSAGELIST_CORE_MODELINVARIANTINDEX_P_H__
+#endif //!__MESSAGELIST_CORE_MODELINVARIANTINDEX_P_H
