@@ -1,20 +1,8 @@
 /******************************************************************************
  *
- *  Copyright 2008 Szymon Tomasz Stefanek <pragma@kvirc.net>
+ *  SPDX-FileCopyrightText: 2008 Szymon Tomasz Stefanek <pragma@kvirc.net>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  *
  *******************************************************************************/
 
@@ -68,7 +56,9 @@ ModelInvariantRowMapper::ModelInvariantRowMapper()
     d->mLazyUpdateChunkInterval = 50;
     d->mLazyUpdateIdleInterval = 50;
 
-    connect(d->mUpdateTimer, &QTimer::timeout, this, [this]() { d->slotPerformLazyUpdate(); });
+    connect(d->mUpdateTimer, &QTimer::timeout, this, [this]() {
+        d->slotPerformLazyUpdate();
+    });
 }
 
 ModelInvariantRowMapper::~ModelInvariantRowMapper()
@@ -208,7 +198,7 @@ ModelInvariantIndex *ModelInvariantRowMapperPrivate::modelIndexRowToModelInvaria
         //   if ( potentialPreviousModelIndexRow >= shift->mMinimumRowIndex )
         //     previousIndexRow = potentialPreviousModelIndexRow;
         //
-        // or by simplyfying...
+        // or by simplifying...
 
         int potentialPreviousModelIndexRow = previousIndexRow - shift->mShift;
         if (potentialPreviousModelIndexRow >= shift->mMinimumRowIndex) {
