@@ -1,28 +1,16 @@
 /******************************************************************************
  *
- *  Copyright 2008 Szymon Tomasz Stefanek <pragma@kvirc.net>
+ *  SPDX-FileCopyrightText: 2008 Szymon Tomasz Stefanek <pragma@kvirc.net>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  *
  *******************************************************************************/
 
-#ifndef __MESSAGELIST_CORE_STORAGEMODELBASE_H__
-#define __MESSAGELIST_CORE_STORAGEMODELBASE_H__
+#ifndef MESSAGELIST_CORE_STORAGEMODELBASE_H
+#define MESSAGELIST_CORE_STORAGEMODELBASE_H
 
 #include <QAbstractItemModel>
-
+#include <QVector>
 namespace Akonadi {
 class MessageStatus;
 }
@@ -77,7 +65,7 @@ public:
     /**
     * This method should use the inner model implementation to fill in the
     * base data for the specified MessageItem from the underlying storage slot at
-    * the specified row index. Must return true if the data fetch was succesfull
+    * the specified row index. Must return true if the data fetch was successful
     * and false otherwise. For base data we intend: subject, sender, receiver,
     * senderOrReceiver, size, date, encryption state, signature state and status.
     * If bUseReceiver is true then the "senderOrReceiver"
@@ -116,10 +104,10 @@ public:
     * The implementation-specific mime data for this list of items.
     *    Called when the user initiates a drag from the messagelist.
     */
-    virtual QMimeData *mimeData(const QList< MessageItem * > &) const = 0;
+    virtual QMimeData *mimeData(const QVector< MessageItem * > &) const = 0;
     using QAbstractItemModel::mimeData;
 };
 } // namespace Core
 } // namespace MessageList
 
-#endif //!__MESSAGELIST_CORE_STORAGEMODEL_H__
+#endif //!__MESSAGELIST_CORE_STORAGEMODEL_H
