@@ -1,25 +1,13 @@
 /******************************************************************************
  *
- *  Copyright 2008 Szymon Tomasz Stefanek <pragma@kvirc.net>
+ *  SPDX-FileCopyrightText: 2008 Szymon Tomasz Stefanek <pragma@kvirc.net>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  *
  *******************************************************************************/
 
-#ifndef __MESSAGELIST_CORE_THEME_H__
-#define __MESSAGELIST_CORE_THEME_H__
+#ifndef MESSAGELIST_CORE_THEME_H
+#define MESSAGELIST_CORE_THEME_H
 
 #include <QList>
 #include <QPair>
@@ -145,7 +133,7 @@ public:
             */
             ReadStateIcon = 7 | ApplicableToMessageItems | IsIcon,
             /**
-            * The icon that displays the atachment state (may be disabled)
+            * The icon that displays the attachment state (may be disabled)
             */
             AttachmentStateIcon = 8 | CanBeDisabled | ApplicableToMessageItems | IsIcon,
             /**
@@ -212,11 +200,15 @@ public:
             /**
             * Whether the message is an invitation
             */
-            InvitationIcon = 24 | ApplicableToMessageItems | IsIcon
+            InvitationIcon = 24 | ApplicableToMessageItems | IsIcon,
+            /**
+            * Folder of the message
+            */
+            Folder = 25 | DisplaysText | CanUseCustomColor | ApplicableToMessageItems
 #if 0
-                             TotalMessageCount
-                             UnreadMessageCount
-                             NewMessageCount
+                     TotalMessageCount
+                     UnreadMessageCount
+                     NewMessageCount
 #endif
         };
 
@@ -821,7 +813,7 @@ public:
     };
 
     /**
-    * How do we manage the QHeaderView attacched to our View ?
+    * How do we manage the QHeaderView attached to our View ?
     */
     enum ViewHeaderPolicy {
         ShowHeaderAlways,
@@ -965,7 +957,7 @@ public:
     * The returned descriptors are pairs in that the first item is the localized description
     * of the option value and the second item is the integer option value itself.
     */
-    static QList< QPair< QString, int > > enumerateGroupHeaderBackgroundStyles();
+    static QVector< QPair< QString, int > > enumerateGroupHeaderBackgroundStyles();
 
     /**
     * Returns the currently set ViewHeaderPolicy
@@ -994,7 +986,7 @@ public:
     * The returned descriptors are pairs in that the first item is the localized description
     * of the option value and the second item is the integer option value itself.
     */
-    static QList< QPair< QString, int > > enumerateViewHeaderPolicyOptions();
+    static QVector<QPair<QString, int> > enumerateViewHeaderPolicyOptions();
 
     inline const QPixmap *pixmap(ThemeIcon icon) const
     {
@@ -1021,4 +1013,4 @@ protected:
 } // namespace Core
 } // namespace MessageList
 
-#endif //!__MESSAGELIST_CORE_SKIN_H__
+#endif //!__MESSAGELIST_CORE_SKIN_H
