@@ -1,20 +1,8 @@
 /******************************************************************************
  *
- *  Copyright 2008 Szymon Tomasz Stefanek <pragma@kvirc.net>
+ *  SPDX-FileCopyrightText: 2008 Szymon Tomasz Stefanek <pragma@kvirc.net>
  *
- *  This program is free softhisare; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Softhisare Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Softhisare
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  *
  *******************************************************************************/
 
@@ -161,8 +149,7 @@ static inline void paint_right_aligned_elided_text(const QString &text, Theme::C
     }
 }
 
-static inline void compute_bounding_rect_for_right_aligned_elided_text(const QString &text, Theme::ContentItem *ci, int &left, int top, int &right, QRect &outRect, Qt::LayoutDirection layoutDir,
-                                                                       const QFont &font)
+static inline void compute_bounding_rect_for_right_aligned_elided_text(const QString &text, Theme::ContentItem *ci, int &left, int top, int &right, QRect &outRect, Qt::LayoutDirection layoutDir, const QFont &font)
 {
     Q_UNUSED(font);
     const QFontMetrics &fontMetrics = cachedFontMetrics(ci);
@@ -201,8 +188,7 @@ static inline void paint_left_aligned_elided_text(const QString &text, Theme::Co
     }
 }
 
-static inline void compute_bounding_rect_for_left_aligned_elided_text(const QString &text, Theme::ContentItem *ci, int &left, int top, int &right, QRect &outRect, Qt::LayoutDirection layoutDir,
-                                                                      const QFont &font)
+static inline void compute_bounding_rect_for_left_aligned_elided_text(const QString &text, Theme::ContentItem *ci, int &left, int top, int &right, QRect &outRect, Qt::LayoutDirection layoutDir, const QFont &font)
 {
     Q_UNUSED(font);
     const QFontMetrics &fontMetrics = cachedFontMetrics(ci);
@@ -257,19 +243,15 @@ static inline const QPixmap *get_encryption_state_icon(const Theme *theme, Messa
     case MessageItem::FullyEncrypted:
         *treatAsEnabled = true;
         return theme->pixmap(Theme::IconFullyEncrypted);
-        break;
     case MessageItem::PartiallyEncrypted:
         *treatAsEnabled = true;
         return theme->pixmap(Theme::IconPartiallyEncrypted);
-        break;
     case MessageItem::EncryptionStateUnknown:
         *treatAsEnabled = false;
         return theme->pixmap(Theme::IconUndefinedEncrypted);
-        break;
     case MessageItem::NotEncrypted:
         *treatAsEnabled = false;
         return theme->pixmap(Theme::IconNotEncrypted);
-        break;
     default:
         // should never happen
         Q_ASSERT(false);
@@ -286,19 +268,15 @@ static inline const QPixmap *get_signature_state_icon(const Theme *theme, Messag
     case MessageItem::FullySigned:
         *treatAsEnabled = true;
         return theme->pixmap(Theme::IconFullySigned);
-        break;
     case MessageItem::PartiallySigned:
         *treatAsEnabled = true;
         return theme->pixmap(Theme::IconPartiallySigned);
-        break;
     case MessageItem::SignatureStateUnknown:
         *treatAsEnabled = false;
         return theme->pixmap(Theme::IconUndefinedSigned);
-        break;
     case MessageItem::NotSigned:
         *treatAsEnabled = false;
         return theme->pixmap(Theme::IconNotSigned);
-        break;
     default:
         // should never happen
         Q_ASSERT(false);
@@ -812,7 +790,6 @@ void ThemeDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
     default:
         Q_ASSERT(false);
         return; // bug
-        break;
     }
 
     Qt::LayoutDirection layoutDir = mItemView->layoutDirection();
@@ -825,7 +802,8 @@ void ThemeDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
         // paint right aligned stuff first
         int r = right;
         int l = left;
-        for (const auto itemit : qAsConst(row->rightItems())) {
+        const auto rightItems = row->rightItems();
+        for (const auto itemit : rightItems) {
             auto ci = const_cast<Theme::ContentItem *>(itemit);
 
             if (ci->canUseCustomColor()) {
@@ -875,6 +853,9 @@ void ThemeDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
             case Theme::ContentItem::Size:
                 paint_right_aligned_elided_text(item->formattedSize(), ci, painter, l, top, r, layoutDir, font);
                 break;
+            case Theme::ContentItem::Folder:
+                paint_right_aligned_elided_text(item->folder(), ci, painter, l, top, r, layoutDir, font);
+                break;
             case Theme::ContentItem::GroupHeaderLabel:
                 if (groupHeaderItem) {
                     paint_right_aligned_elided_text(groupHeaderItem->label(), ci, painter, l, top, r, layoutDir, font);
@@ -988,7 +969,8 @@ void ThemeDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
         }
 
         // then paint left aligned stuff
-        for (const auto itemit : qAsConst(row->leftItems())) {
+        const auto leftItems = row->leftItems();
+        for (const auto itemit : leftItems) {
             auto ci = const_cast<Theme::ContentItem *>(itemit);
 
             if (ci->canUseCustomColor()) {
@@ -1038,6 +1020,9 @@ void ThemeDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
             case Theme::ContentItem::Size:
                 paint_left_aligned_elided_text(item->formattedSize(), ci, painter, l, top, r, layoutDir, font);
                 break;
+            case Theme::ContentItem::Folder:
+                paint_left_aligned_elided_text(item->folder(), ci, painter, l, top, r, layoutDir, font);
+                break;
             case Theme::ContentItem::GroupHeaderLabel:
                 if (groupHeaderItem) {
                     paint_left_aligned_elided_text(groupHeaderItem->label(), ci, painter, l, top, r, layoutDir, font);
@@ -1259,7 +1244,8 @@ bool ThemeDelegate::hitTest(const QPoint &viewportPoint, bool exact)
 
         int r = right;
         int l = left;
-        for (const auto itemit : qAsConst(mHitRow->rightItems())) {
+        const auto rightItems = mHitRow->rightItems();
+        for (const auto itemit : rightItems) {
             auto ci = const_cast<Theme::ContentItem *>(itemit);
 
             mHitContentItemRect = QRect();
@@ -1291,6 +1277,9 @@ bool ThemeDelegate::hitTest(const QPoint &viewportPoint, bool exact)
             case Theme::ContentItem::Size:
                 compute_bounding_rect_for_right_aligned_elided_text(mHitItem->formattedSize(), ci, l, top, r, mHitContentItemRect, layoutDir, font);
                 break;
+            case Theme::ContentItem::Folder:
+                compute_bounding_rect_for_right_aligned_elided_text(mHitItem->folder(), ci, l, top, r, mHitContentItemRect, layoutDir, font);
+                break;
             case Theme::ContentItem::GroupHeaderLabel:
                 if (groupHeaderItem) {
                     compute_bounding_rect_for_right_aligned_elided_text(groupHeaderItem->label(), ci, l, top, r, mHitContentItemRect, layoutDir, font);
@@ -1403,7 +1392,8 @@ bool ThemeDelegate::hitTest(const QPoint &viewportPoint, bool exact)
         // then check left aligned stuff
         mHitContentItemRight = false;
 
-        for (const auto itemit : qAsConst(mHitRow->leftItems())) {
+        const auto leftItems = mHitRow->leftItems();
+        for (const auto itemit : leftItems) {
             auto ci = const_cast<Theme::ContentItem *>(itemit);
 
             mHitContentItemRect = QRect();
@@ -1435,6 +1425,9 @@ bool ThemeDelegate::hitTest(const QPoint &viewportPoint, bool exact)
             case Theme::ContentItem::Size:
                 compute_bounding_rect_for_left_aligned_elided_text(mHitItem->formattedSize(), ci, l, top, r, mHitContentItemRect, layoutDir, font);
                 break;
+            case Theme::ContentItem::Folder:
+                compute_bounding_rect_for_left_aligned_elided_text(mHitItem->folder(), ci, l, top, r, mHitContentItemRect, layoutDir, font);
+                break;
             case Theme::ContentItem::GroupHeaderLabel:
                 if (groupHeaderItem) {
                     compute_bounding_rect_for_left_aligned_elided_text(groupHeaderItem->label(), ci, l, top, r, mHitContentItemRect, layoutDir, font);
