@@ -1,20 +1,7 @@
 /*
-  Copyright (c) 2014-2018 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
 
- This library is free software; you can redistribute it and/or modify it
- under the terms of the GNU Library General Public License as published by
- the Free Software Foundation; either version 2 of the License, or (at your
- option) any later version.
-
- This library is distributed in the hope that it will be useful, but WITHOUT
- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
- License for more details.
-
- You should have received a copy of the GNU Library General Public License
- along with this library; see the file COPYING.LIB.  If not, write to the
- Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- 02110-1301, USA.
+ SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
@@ -25,10 +12,9 @@
 
 #include "searchlinestatus.h"
 #include <KLocalizedString>
-#include <KComboBox>
 
 #include <QPushButton>
-
+#include <QComboBox>
 #include <QHBoxLayout>
 #include <QStandardPaths>
 
@@ -37,14 +23,13 @@ QuickSearchLine::QuickSearchLine(QWidget *parent)
     : QWidget(parent)
 {
     QVBoxLayout *vbox = new QVBoxLayout(this);
-    vbox->setMargin(0);
+    vbox->setContentsMargins(0, 0, 0, 0);
     vbox->setSpacing(0);
 
     QWidget *w = new QWidget;
-    QHBoxLayout *hbox = new QHBoxLayout;
-    hbox->setMargin(0);
+    QHBoxLayout *hbox = new QHBoxLayout(w);
+    hbox->setContentsMargins(0, 0, 0, 0);
     hbox->setSpacing(0);
-    w->setLayout(hbox);
     vbox->addWidget(w);
 
     mSearchEdit = new SearchLineStatus(this);
@@ -61,7 +46,7 @@ QuickSearchLine::QuickSearchLine(QWidget *parent)
     hbox->addWidget(mSearchEdit);
 
     // The status filter button. Will be populated later, as populateStatusFilterCombo() is virtual
-    mTagFilterCombo = new KComboBox(this);
+    mTagFilterCombo = new QComboBox(this);
     mTagFilterCombo->setMaximumWidth(300);
     mTagFilterCombo->setMaximumWidth(200);
     mTagFilterCombo->hide();
@@ -117,7 +102,7 @@ void QuickSearchLine::focusQuickSearch(const QString &selectedText)
     mSearchEdit->setFocus();
 }
 
-KComboBox *QuickSearchLine::tagFilterComboBox() const
+QComboBox *QuickSearchLine::tagFilterComboBox() const
 {
     return mTagFilterCombo;
 }
@@ -136,13 +121,13 @@ void QuickSearchLine::resetFilter()
     mSearchEdit->setLocked(false);
 }
 
-void QuickSearchLine::slotFilterActionChanged(const QList<Akonadi::MessageStatus> &lst)
+void QuickSearchLine::slotFilterActionChanged(const QVector<Akonadi::MessageStatus> &lst)
 {
     mLstStatus = lst;
     Q_EMIT statusButtonsClicked();
 }
 
-QList<Akonadi::MessageStatus> QuickSearchLine::status() const
+QVector<Akonadi::MessageStatus> QuickSearchLine::status() const
 {
     return mLstStatus;
 }
