@@ -1,19 +1,7 @@
 /*
- * Copyright (c) 2016 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+ * SPDX-FileCopyrightText: 2016 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
@@ -25,24 +13,18 @@
 #include "messagelist_private_export.h"
 class KJob;
 
-namespace Akonadi
-{
-namespace Search
-{
-namespace PIM
-{
+namespace Akonadi {
+namespace Search {
+namespace PIM {
 class IndexedItems;
 }
 }
 }
-namespace Akonadi
-{
+namespace Akonadi {
 class CollectionFetchJob;
 }
-namespace MessageList
-{
-namespace Core
-{
+namespace MessageList {
+namespace Core {
 class MESSAGELIST_TESTS_EXPORT SearchCollectionIndexingWarning : public KMessageWidget
 {
     Q_OBJECT
@@ -62,7 +44,7 @@ private:
 
     Akonadi::Collection mCollection;
     Akonadi::Collection::List mCollections;
-    Akonadi::Search::PIM::IndexedItems *mIndexedItems;
+    Akonadi::Search::PIM::IndexedItems *mIndexedItems = nullptr;
 };
 }
 }
