@@ -1,19 +1,7 @@
 /*
-    Copyright (c) 2009 Kevin Ottens <ervin@kde.org>
+    SPDX-FileCopyrightText: 2009 Kevin Ottens <ervin@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "pane.h"
@@ -26,6 +14,7 @@
 #include <KXMLGUIClient>
 #include <QAction>
 #include <KToggleAction>
+#include <KStandardAction>
 
 #include <QAbstractItemModel>
 #include <QAbstractProxyModel>
@@ -35,6 +24,8 @@
 #include <QMouseEvent>
 #include <QHeaderView>
 #include <QRegularExpression>
+#include <QVector>
+#include <QApplication>
 
 #include "storagemodel.h"
 #include "core/widgets/quicksearchline.h"
@@ -68,7 +59,7 @@ public:
     {
     }
 
-    void onSelectionChanged(const QItemSelection &selected, const QItemSelection &deselected);
+    void setCurrentFolder(const QModelIndex &etmIndex);
     void onNewTabClicked();
     void onCloseTabClicked();
     void activateTab();
@@ -84,7 +75,6 @@ public:
     void changeQuicksearchVisibility(bool);
     void addActivateTabAction(int i);
     void slotTabCloseRequested(int index);
-    QItemSelection mapSelectionToSource(const QItemSelection &selection) const;
     QItemSelection mapSelectionFromSource(const QItemSelection &selection) const;
     void updateTabControls();
 
@@ -127,7 +117,7 @@ Pane::Pane(bool restoreSession, QAbstractItemModel *model, QItemSelectionModel *
     const QAbstractProxyModel *proxyModel = qobject_cast<const QAbstractProxyModel *>(d->mSelectionModel->model());
 
     while (proxyModel) {
-        if (static_cast<const QAbstractItemModel *>(proxyModel) == d->mModel) {
+        if (proxyModel == d->mModel) {
             break;
         }
 
@@ -136,7 +126,7 @@ Pane::Pane(bool restoreSession, QAbstractItemModel *model, QItemSelectionModel *
 
         if (!nextProxyModel) {
             // It's the final model in the chain, so it is necessarily the sourceModel.
-            Q_ASSERT(qobject_cast<const QAbstractItemModel *>(proxyModel->sourceModel()) == d->mModel);
+            Q_ASSERT(proxyModel->sourceModel() == d->mModel);
             break;
         }
         proxyModel = nextProxyModel;
@@ -150,7 +140,9 @@ Pane::Pane(bool restoreSession, QAbstractItemModel *model, QItemSelectionModel *
     d->mNewTabButton->setAccessibleName(i18n("New tab"));
 #endif
     setCornerWidget(d->mNewTabButton, Qt::TopLeftCorner);
-    connect(d->mNewTabButton, &QToolButton::clicked, this, [this]() { d->onNewTabClicked(); });
+    connect(d->mNewTabButton, &QToolButton::clicked, this, [this]() {
+        d->onNewTabClicked();
+    });
 
     d->mCloseTabButton = new QToolButton(this);
     d->mCloseTabButton->setIcon(QIcon::fromTheme(QStringLiteral("tab-close")));
@@ -161,25 +153,32 @@ Pane::Pane(bool restoreSession, QAbstractItemModel *model, QItemSelectionModel *
 #endif
     setCornerWidget(d->mCloseTabButton, Qt::TopRightCorner);
     connect(d->mCloseTabButton, &QToolButton::clicked,
-            this, [this]() {d->onCloseTabClicked(); });
+            this, [this]() {
+        d->onCloseTabClicked();
+    });
 
     setTabsClosable(true);
-    connect(this, SIGNAL(tabCloseRequested(int)), this, SLOT(slotTabCloseRequested(int)));
+    connect(this, &Pane::tabCloseRequested, this, [this](int index) {
+        d->slotTabCloseRequested(index);
+    });
 
     readConfig(restoreSession);
     setMovable(true);
 
-    connect(d->mSelectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-            this, SLOT(onSelectionChanged(QItemSelection,QItemSelection)));
-    connect(this, SIGNAL(currentChanged(int)),
-            this, SLOT(onCurrentTabChanged()));
+    connect(this, &Pane::currentChanged,
+            this, [this]() {
+        d->onCurrentTabChanged();
+    });
 
     setContextMenuPolicy(Qt::CustomContextMenu);
-    connect(this, SIGNAL(customContextMenuRequested(QPoint)),
-            this, SLOT(onTabContextMenuRequest(QPoint)));
+    connect(this, &Pane::customContextMenuRequested, this, [this](const QPoint &point) {
+        d->onTabContextMenuRequest(point);
+    });
 
-    connect(MessageListSettings::self(), SIGNAL(configChanged()),
-            this, SLOT(updateTabControls()));
+    connect(MessageListSettings::self(), &MessageListSettings::configChanged,
+            this, [this]() {
+        d->updateTabControls();
+    });
 
     connect(this, &QTabWidget::tabBarDoubleClicked,
             this, &Pane::createNewTab);
@@ -189,18 +188,20 @@ Pane::Pane(bool restoreSession, QAbstractItemModel *model, QItemSelectionModel *
 
 Pane::~Pane()
 {
+    saveCurrentSelection();
     writeConfig(true);
     delete d;
 }
 
 void Pane::Private::addActivateTabAction(int i)
 {
-    QString actionname;
-    actionname.sprintf("activate_tab_%02d", i);
+    const QString actionname = QString::asprintf("activate_tab_%02d", i);
     QAction *action = new QAction(i18n("Activate Tab %1", i), q);
     mXmlGuiClient->actionCollection()->addAction(actionname, action);
     mXmlGuiClient->actionCollection()->setDefaultShortcut(action, QKeySequence(QStringLiteral("Alt+%1").arg(i)));
-    connect(action, SIGNAL(triggered(bool)), q, SLOT(activateTab()));
+    connect(action, &QAction::triggered, q, [this]() {
+        activateTab();
+    });
 }
 
 void Pane::Private::slotTabCloseRequested(int index)
@@ -220,11 +221,15 @@ void Pane::setXmlGuiClient(KXMLGUIClient *xmlGuiClient)
     showHideQuicksearch->setChecked(MessageListSettings::showQuickSearch());
 
     d->mXmlGuiClient->actionCollection()->addAction(QStringLiteral("show_quick_search"), showHideQuicksearch);
-    connect(showHideQuicksearch, SIGNAL(triggered(bool)), this, SLOT(changeQuicksearchVisibility(bool)));
+    connect(showHideQuicksearch, &KToggleAction::triggered, this, [this](bool state) {
+        d->changeQuicksearchVisibility(state);
+    });
 
     for (int i = 0; i < count(); ++i) {
         Widget *w = qobject_cast<Widget *>(widget(i));
-        w->setXmlGuiClient(d->mXmlGuiClient);
+        if (w) {
+            w->setXmlGuiClient(d->mXmlGuiClient);
+        }
     }
 
     // Setup "View->Message List" actions.
@@ -241,40 +246,81 @@ void Pane::setXmlGuiClient(KXMLGUIClient *xmlGuiClient)
         QAction *action = new QAction(i18n("Create New Tab"), this);
         d->mXmlGuiClient->actionCollection()->addAction(QStringLiteral("create_new_tab"), action);
         d->mXmlGuiClient->actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_O));
-        connect(action, &QAction::triggered, this, [this]() { d->onNewTabClicked(); });
+        connect(action, &QAction::triggered, this, [this]() {
+            d->onNewTabClicked();
+        });
         d->mActionMenu->addAction(action);
+        d->mActionMenu->addSeparator();
 
         d->mMaxTabCreated = count();
         for (int i = 1; i < 10 && i <= count(); ++i) {
             d->addActivateTabAction(i);
         }
 
-        d->mCloseTabAction = new QAction(i18n("Close Tab"), this);
-        d->mXmlGuiClient->actionCollection()->addAction(QStringLiteral("close_current_tab"), d->mCloseTabAction);
-        d->mXmlGuiClient->actionCollection()->setDefaultShortcuts(d->mCloseTabAction, QList<QKeySequence>() << QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_W) << QKeySequence(Qt::CTRL + Qt::Key_W));
-        connect(d->mCloseTabAction, SIGNAL(triggered(bool)), SLOT(onCloseTabClicked()));
-        d->mActionMenu->addAction(d->mCloseTabAction);
-        d->mCloseTabAction->setEnabled(false);
+        QList<QKeySequence> nextShortcut;
+        QList<QKeySequence> prevShortcut;
+
+        QString nextIcon, prevIcon;
+        if (QApplication::isRightToLeft()) {
+            nextShortcut.append(KStandardShortcut::tabPrev());
+            prevShortcut.append(KStandardShortcut::tabNext());
+            nextIcon = QStringLiteral("go-previous-view");
+            prevIcon = QStringLiteral("go-next-view");
+        } else {
+            nextShortcut.append(KStandardShortcut::tabNext());
+            prevShortcut.append(KStandardShortcut::tabPrev());
+            nextIcon = QStringLiteral("go-next-view");
+            prevIcon = QStringLiteral("go-previous-view");
+        }
 
         d->mActivateNextTabAction = new QAction(i18n("Activate Next Tab"), this);
         d->mXmlGuiClient->actionCollection()->addAction(QStringLiteral("activate_next_tab"), d->mActivateNextTabAction);
         d->mActivateNextTabAction->setEnabled(false);
-        connect(d->mActivateNextTabAction, SIGNAL(triggered(bool)), SLOT(activateNextTab()));
+        d->mActivateNextTabAction->setIcon(QIcon::fromTheme(nextIcon));
+        d->mXmlGuiClient->actionCollection()->setDefaultShortcuts(d->mActivateNextTabAction, nextShortcut);
+        connect(d->mActivateNextTabAction, &QAction::triggered, [this]() {
+            d->activateNextTab();
+        });
+        d->mActionMenu->addAction(d->mActivateNextTabAction);
 
         d->mActivatePreviousTabAction = new QAction(i18n("Activate Previous Tab"), this);
         d->mXmlGuiClient->actionCollection()->addAction(QStringLiteral("activate_previous_tab"), d->mActivatePreviousTabAction);
+        d->mXmlGuiClient->actionCollection()->setDefaultShortcuts(d->mActivatePreviousTabAction, prevShortcut);
+        d->mActivatePreviousTabAction->setIcon(QIcon::fromTheme(prevIcon));
         d->mActivatePreviousTabAction->setEnabled(false);
-        connect(d->mActivatePreviousTabAction, SIGNAL(triggered(bool)), SLOT(activatePreviousTab()));
+        connect(d->mActivatePreviousTabAction, &QAction::triggered, this, [this]() {
+            d->activatePreviousTab();
+        });
+        d->mActionMenu->addAction(d->mActivatePreviousTabAction);
+
+        d->mActionMenu->addSeparator();
 
         d->mMoveTabLeftAction = new QAction(i18n("Move Tab Left"), this);
         d->mXmlGuiClient->actionCollection()->addAction(QStringLiteral("move_tab_left"), d->mMoveTabLeftAction);
         d->mMoveTabLeftAction->setEnabled(false);
-        connect(d->mMoveTabLeftAction, SIGNAL(triggered(bool)), SLOT(moveTabLeft()));
+        connect(d->mMoveTabLeftAction, &QAction::triggered, this, [this]() {
+            d->moveTabLeft();
+        });
+        d->mActionMenu->addAction(d->mMoveTabLeftAction);
 
         d->mMoveTabRightAction = new QAction(i18n("Move Tab Right"), this);
         d->mXmlGuiClient->actionCollection()->addAction(QStringLiteral("move_tab_right"), d->mMoveTabRightAction);
         d->mMoveTabRightAction->setEnabled(false);
-        connect(d->mMoveTabRightAction, SIGNAL(triggered(bool)), SLOT(moveTabRight()));
+        connect(d->mMoveTabRightAction, &QAction::triggered, this, [this]() {
+            d->moveTabRight();
+        });
+        d->mActionMenu->addAction(d->mMoveTabRightAction);
+
+        d->mActionMenu->addSeparator();
+
+        d->mCloseTabAction = new QAction(i18n("Close Tab"), this);
+        d->mXmlGuiClient->actionCollection()->addAction(QStringLiteral("close_current_tab"), d->mCloseTabAction);
+        d->mXmlGuiClient->actionCollection()->setDefaultShortcuts(d->mCloseTabAction, QList<QKeySequence>() << QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_W) << QKeySequence(Qt::CTRL + Qt::Key_W));
+        connect(d->mCloseTabAction, &QAction::triggered, this, [this]() {
+            d->onCloseTabClicked();
+        });
+        d->mActionMenu->addAction(d->mCloseTabAction);
+        d->mCloseTabAction->setEnabled(false);
     }
 }
 
@@ -451,7 +497,7 @@ void Pane::setQuickSearchClickMessage(const QString &msg)
     }
 }
 
-void Pane::Private::onSelectionChanged(const QItemSelection &selected, const QItemSelection &deselected)
+void Pane::Private::setCurrentFolder(const QModelIndex &etmIndex)
 {
     if (mPreferEmptyTab) {
         q->createNewTab();
@@ -463,11 +509,12 @@ void Pane::Private::onSelectionChanged(const QItemSelection &selected, const QIt
     w->saveCurrentSelection();
 
     // Deselect old before we select new - so that the messagelist can clear first.
-    s->select(mapSelectionToSource(deselected), QItemSelectionModel::Deselect);
+    s->clear();
     if (s->selection().isEmpty()) {
         w->view()->model()->setPreSelectionMode(mPreSelectionMode);
     }
-    s->select(mapSelectionToSource(selected), QItemSelectionModel::Select);
+    Q_ASSERT(s->model() == etmIndex.model());
+    s->select(etmIndex, QItemSelectionModel::Select);
 
     QString label;
     QIcon icon;
@@ -497,15 +544,10 @@ void Pane::Private::onSelectionChanged(const QItemSelection &selected, const QIt
     q->setTabIcon(index, icon);
     q->setTabToolTip(index, toolTip);
     if (mPreferEmptyTab) {
-        disconnect(mSelectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-                   q, SLOT(onSelectionChanged(QItemSelection,QItemSelection)));
-
         mSelectionModel->select(mapSelectionFromSource(s->selection()),
                                 QItemSelectionModel::ClearAndSelect);
-
-        connect(mSelectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-                q, SLOT(onSelectionChanged(QItemSelection,QItemSelection)));
     }
+    mPreferEmptyTab = false;
 }
 
 void Pane::Private::activateTab()
@@ -605,6 +647,11 @@ void Pane::Private::closeTab(QWidget *w)
         return;
     }
 
+    Widget *wWidget = qobject_cast<Widget *>(w);
+    if (wWidget) {
+        wWidget->saveCurrentSelection();
+    }
+
     delete w;
     updateTabControls();
 }
@@ -613,7 +660,9 @@ void Pane::Private::changeQuicksearchVisibility(bool show)
 {
     for (int i = 0; i < q->count(); ++i) {
         Widget *w = qobject_cast<Widget *>(q->widget(i));
-        w->changeQuicksearchVisibility(show);
+        if (w) {
+            w->changeQuicksearchVisibility(show);
+        }
     }
 }
 
@@ -621,7 +670,7 @@ bool Pane::eventFilter(QObject *object, QEvent *event)
 {
     if (event->type() == QEvent::MouseButtonPress) {
         QMouseEvent *const mouseEvent = static_cast<QMouseEvent *>(event);
-        if (mouseEvent->button() == Qt::MidButton) {
+        if (mouseEvent->button() == Qt::MiddleButton) {
             return true;
         }
     }
@@ -636,14 +685,8 @@ void Pane::Private::onCurrentTabChanged()
 
     QItemSelectionModel *s = mWidgetSelectionHash[w];
 
-    disconnect(mSelectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-               q, SLOT(onSelectionChanged(QItemSelection,QItemSelection)));
-
     mSelectionModel->select(mapSelectionFromSource(s->selection()),
                             QItemSelectionModel::ClearAndSelect);
-
-    connect(mSelectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-            q, SLOT(onSelectionChanged(QItemSelection,QItemSelection)));
 }
 
 void Pane::Private::onTabContextMenuRequest(const QPoint &pos)
@@ -674,7 +717,7 @@ void Pane::Private::onTabContextMenuRequest(const QPoint &pos)
     QAction *action = menu.exec(q->mapToGlobal(pos));
 
     if (action == allOther) {   // Close all other tabs
-        QList<Widget *> widgets;
+        QVector<Widget *> widgets;
         const int index = q->indexOf(w);
 
         for (int i = 0; i < q->count(); ++i) {
@@ -683,10 +726,13 @@ void Pane::Private::onTabContextMenuRequest(const QPoint &pos)
             }
 
             Widget *other = qobject_cast<Widget *>(q->widget(i));
-            widgets << other;
+            if (other) {
+                widgets << other;
+            }
         }
 
         foreach (Widget *other, widgets) {
+            other->saveCurrentSelection();
             delete other;
         }
 
@@ -710,8 +756,9 @@ Akonadi::Collection Pane::currentFolder() const
     return {};
 }
 
-void Pane::setCurrentFolder(const Akonadi::Collection &collection, bool, Core::PreSelectionMode preSelectionMode, const QString &overrideLabel)
+void Pane::setCurrentFolder(const Akonadi::Collection &collection, const QModelIndex &etmIndex, bool, Core::PreSelectionMode preSelectionMode, const QString &overrideLabel)
 {
+    d->setCurrentFolder(etmIndex);
     d->mPreSelectionMode = preSelectionMode;
     Widget *w = static_cast<Widget *>(currentWidget());
     if (w) {
@@ -730,7 +777,7 @@ void Pane::updateTabIconText(const Akonadi::Collection &collection, const QStrin
 {
     for (int i = 0; i < count(); ++i) {
         Widget *w = qobject_cast<Widget *>(widget(i));
-        if (w->currentCollection() == collection) {
+        if (w && (w->currentCollection() == collection)) {
             const int index = indexOf(w);
             setTabText(index, label);
             setTabIcon(index, icon);
@@ -770,22 +817,14 @@ QItemSelectionModel *Pane::createNewTab()
     connect(w, &Core::Widget::statusMessage,
             this, &Pane::statusMessage);
 
+    connect(w, &Core::Widget::forceLostFocus,
+            this, &Pane::forceLostFocus);
+
     d->updateTabControls();
     setCurrentWidget(w);
     return s;
 }
 
-QItemSelection Pane::Private::mapSelectionToSource(const QItemSelection &selection) const
-{
-    QItemSelection result = selection;
-
-    for (const QAbstractProxyModel *proxy : qAsConst(mProxyStack)) {
-        result = proxy->mapSelectionToSource(result);
-    }
-
-    return result;
-}
-
 QItemSelection Pane::Private::mapSelectionFromSource(const QItemSelection &selection) const
 {
     QItemSelection result = selection;
@@ -864,11 +903,11 @@ KMime::Message::Ptr Pane::currentMessage() const
     return w->currentMessage();
 }
 
-QList<KMime::Message::Ptr > Pane::selectionAsMessageList(bool includeCollapsedChildren) const
+QVector<KMime::Message::Ptr > Pane::selectionAsMessageList(bool includeCollapsedChildren) const
 {
     Widget *w = static_cast<Widget *>(currentWidget());
     if (w == nullptr) {
-        return QList<KMime::Message::Ptr>();
+        return QVector<KMime::Message::Ptr>();
     }
     return w->selectionAsMessageList(includeCollapsedChildren);
 }
@@ -882,11 +921,11 @@ Akonadi::Item::List Pane::selectionAsMessageItemList(bool includeCollapsedChildr
     return w->selectionAsMessageItemList(includeCollapsedChildren);
 }
 
-QList<Akonadi::Item::Id> Pane::selectionAsListMessageId(bool includeCollapsedChildren) const
+QVector<Akonadi::Item::Id> Pane::selectionAsListMessageId(bool includeCollapsedChildren) const
 {
     Widget *w = static_cast<Widget *>(currentWidget());
     if (w == nullptr) {
-        return QList<Akonadi::Item::Id>();
+        return QVector<Akonadi::Item::Id>();
     }
     return w->selectionAsListMessageId(includeCollapsedChildren);
 }
@@ -934,11 +973,11 @@ void Pane::markMessageItemsAsAboutToBeRemoved(MessageList::Core::MessageItemSetR
     }
 }
 
-QList<Akonadi::MessageStatus> Pane::currentFilterStatus() const
+QVector<Akonadi::MessageStatus> Pane::currentFilterStatus() const
 {
     Widget *w = static_cast<Widget *>(currentWidget());
     if (w == nullptr) {
-        return QList<Akonadi::MessageStatus>();
+        return QVector<Akonadi::MessageStatus>();
     }
     return w->currentFilterStatus();
 }
@@ -1055,7 +1094,9 @@ void Pane::saveCurrentSelection()
 {
     for (int i = 0; i < count(); ++i) {
         Widget *w = qobject_cast<Widget *>(widget(i));
-        w->saveCurrentSelection();
+        if (w) {
+            w->saveCurrentSelection();
+        }
     }
 }
 
@@ -1063,7 +1104,9 @@ void Pane::updateTagComboBox()
 {
     for (int i = 0; i < count(); ++i) {
         Widget *w = qobject_cast<Widget *>(widget(i));
-        w->populateStatusFilterCombo();
+        if (w) {
+            w->populateStatusFilterCombo();
+        }
     }
 }
 
@@ -1083,9 +1126,11 @@ void Pane::writeConfig(bool restoreSession)
 
         for (int i = 0; i < count(); ++i) {
             Widget *w = qobject_cast<Widget *>(widget(i));
-            KConfigGroup grp(MessageList::MessageListSettings::self()->config(), QStringLiteral("MessageListTab%1").arg(i));
-            grp.writeEntry(QStringLiteral("collectionId"), w->currentCollection().id());
-            grp.writeEntry(QStringLiteral("HeaderState"), w->view()->header()->saveState());
+            if (w) {
+                KConfigGroup grp(MessageList::MessageListSettings::self()->config(), QStringLiteral("MessageListTab%1").arg(i));
+                grp.writeEntry(QStringLiteral("collectionId"), w->currentCollection().id());
+                grp.writeEntry(QStringLiteral("HeaderState"), w->view()->header()->saveState());
+            }
         }
     }
     conf.sync();
@@ -1131,7 +1176,9 @@ void Pane::restoreHeaderSettings(int index)
     KConfigGroup grp(MessageList::MessageListSettings::self()->config(), QStringLiteral("MessageListTab%1").arg(index));
     if (grp.exists()) {
         Widget *w = qobject_cast<Widget *>(widget(index));
-        w->view()->header()->restoreState(grp.readEntry(QStringLiteral("HeaderState"), QByteArray()));
+        if (w) {
+            w->view()->header()->restoreState(grp.readEntry(QStringLiteral("HeaderState"), QByteArray()));
+        }
     }
 }
 
@@ -1178,7 +1225,9 @@ void Pane::populateStatusFilterCombo()
 {
     for (int i = 0; i < count(); ++i) {
         Widget *w = qobject_cast<Widget *>(widget(i));
-        w->populateStatusFilterCombo();
+        if (w) {
+            w->populateStatusFilterCombo();
+        }
     }
 }
 
