@@ -1,19 +1,7 @@
 /*
-    Copyright (c) 2009 Kevin Ottens <ervin@kde.org>
+    SPDX-FileCopyrightText: 2009 Kevin Ottens <ervin@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "storagemodel.h"
@@ -45,6 +33,7 @@
 #include <QMimeData>
 #include <QCryptographicHash>
 #include <QFontDatabase>
+#include <QHash>
 
 namespace MessageList {
 class Q_DECL_HIDDEN StorageModel::Private
@@ -60,6 +49,8 @@ public:
     QAbstractItemModel *mChildrenFilterModel = nullptr;
     QItemSelectionModel *mSelectionModel = nullptr;
 
+    QHash<Akonadi::Collection::Id, QString> mFolderHash;
+
     Private(StorageModel *owner)
         : q(owner)
     {
@@ -145,6 +136,7 @@ Collection::List StorageModel::displayedCollections() const
     Collection::List collections;
     const QModelIndexList indexes = d->mSelectionModel->selectedRows();
 
+    collections.reserve(indexes.count());
     for (const QModelIndex &index : indexes) {
         Collection c = index.data(EntityTreeModel::CollectionRole).value<Collection>();
         if (c.isValid()) {
@@ -160,6 +152,7 @@ QString StorageModel::id() const
     QStringList ids;
     const QModelIndexList indexes = d->mSelectionModel->selectedRows();
 
+    ids.reserve(indexes.count());
     for (const QModelIndex &index : indexes) {
         Collection c = index.data(EntityTreeModel::CollectionRole).value<Collection>();
         if (c.isValid()) {
@@ -254,6 +247,19 @@ bool StorageModel::initializeMessageItem(MessageList::Core::MessageItem *mi, int
 
     mi->setSubject(subject);
 
+    auto it = d->mFolderHash.find(item.storageCollectionId());
+    if (it == d->mFolderHash.end()) {
+        QString folder;
+        Collection collection = collectionForId(item.storageCollectionId());
+        while (collection.parentCollection().isValid()) {
+            folder = collection.displayName() + QLatin1Char('/') + folder;
+            collection = collection.parentCollection();
+        }
+        folder.chop(1);
+        it = d->mFolderHash.insert(item.storageCollectionId(), folder);
+    }
+    mi->setFolder(it.value());
+
     updateMessageItemData(mi, row);
 
     return true;
@@ -404,7 +410,7 @@ int StorageModel::rowCount(const QModelIndex &parent) const
     return 0; // this model is flat.
 }
 
-QMimeData *StorageModel::mimeData(const QList< MessageList::Core::MessageItem * > &items) const
+QMimeData *StorageModel::mimeData(const QVector< MessageList::Core::MessageItem * > &items) const
 {
     QMimeData *data = new QMimeData();
     QList<QUrl> urls;
@@ -427,6 +433,7 @@ void StorageModel::Private::onSourceDataChanged(const QModelIndex &topLeft, cons
 
 void StorageModel::Private::onSelectionChanged()
 {
+    mFolderHash.clear();
     Q_EMIT q->headerDataChanged(Qt::Horizontal, 0, q->columnCount() - 1);
 }
 
@@ -488,6 +495,20 @@ Collection StorageModel::parentCollectionForRow(int row) const
     return col;
 }
 
+Akonadi::Collection StorageModel::collectionForId(Akonadi::Collection::Id colId) const
+{
+    // Get ETM
+    QAbstractProxyModel *childrenProxy = static_cast<QAbstractProxyModel *>(d->mChildrenFilterModel);
+    QAbstractItemModel *etm = childrenProxy->sourceModel();
+
+    // get index in EntityTreeModel
+    const QModelIndex idx = EntityTreeModel::modelIndexForCollection(etm, Collection(colId));
+    Q_ASSERT(idx.isValid());
+
+    // get and return collection
+    return idx.data(EntityTreeModel::CollectionRole).value<Collection>();
+}
+
 void StorageModel::resetModelStorage()
 {
     beginResetModel();
