@@ -1,20 +1,8 @@
 /******************************************************************************
  *
- *  Copyright 2008 Szymon Tomasz Stefanek <pragma@kvirc.net>
+ *  SPDX-FileCopyrightText: 2008 Szymon Tomasz Stefanek <pragma@kvirc.net>
  *
- *  This program is free softhisare; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Softhisare Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Softhisare
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  *
  *******************************************************************************/
 
@@ -22,14 +10,14 @@
 #include "core/aggregation.h"
 #include "utils/comboboxutils.h"
 
-#include <KLineEdit>
+#include <QLineEdit>
 #include <KTextEdit>
 #include <QLabel>
 #include <QGridLayout>
 #include <QPushButton>
 #include <QCheckBox>
 
-#include <KComboBox>
+#include <QComboBox>
 #include <KLocalizedString>
 
 using namespace MessageList::Utils;
@@ -47,27 +35,27 @@ AggregationEditor::AggregationEditor(QWidget *parent)
     QGridLayout *tabg = new QGridLayout(tab);
 
     tabg->addWidget(new QLabel(i18n("Grouping:"), tab), 0, 0);
-    mGroupingCombo = new KComboBox(tab);
+    mGroupingCombo = new QComboBox(tab);
     tabg->addWidget(mGroupingCombo, 0, 1);
 
-    connect(mGroupingCombo, QOverload<int>::of(&KComboBox::activated), this, &AggregationEditor::groupingComboActivated);
+    connect(mGroupingCombo, qOverload<int>(&QComboBox::activated), this, &AggregationEditor::groupingComboActivated);
 
     tabg->addWidget(new QLabel(i18n("Group expand policy:"), tab), 3, 0);
-    mGroupExpandPolicyCombo = new KComboBox(tab);
+    mGroupExpandPolicyCombo = new QComboBox(tab);
     tabg->addWidget(mGroupExpandPolicyCombo, 3, 1);
 
     tabg->addWidget(new QLabel(i18n("Threading:"), tab), 4, 0);
-    mThreadingCombo = new KComboBox(tab);
+    mThreadingCombo = new QComboBox(tab);
     tabg->addWidget(mThreadingCombo, 4, 1);
 
-    connect(mThreadingCombo, QOverload<int>::of(&KComboBox::activated), this, &AggregationEditor::threadingComboActivated);
+    connect(mThreadingCombo, qOverload<int>(&QComboBox::activated), this, &AggregationEditor::threadingComboActivated);
 
     tabg->addWidget(new QLabel(i18n("Thread leader:"), tab), 5, 0);
-    mThreadLeaderCombo = new KComboBox(tab);
+    mThreadLeaderCombo = new QComboBox(tab);
     tabg->addWidget(mThreadLeaderCombo, 5, 1);
 
     tabg->addWidget(new QLabel(i18n("Thread expand policy:"), tab), 6, 0);
-    mThreadExpandPolicyCombo = new KComboBox(tab);
+    mThreadExpandPolicyCombo = new QComboBox(tab);
     tabg->addWidget(mThreadExpandPolicyCombo, 6, 1);
 
     tabg->setColumnStretch(1, 1);
@@ -80,7 +68,7 @@ AggregationEditor::AggregationEditor(QWidget *parent)
     tabg = new QGridLayout(tab);
 
     tabg->addWidget(new QLabel(i18n("Fill view strategy:"), tab), 0, 0);
-    mFillViewStrategyCombo = new KComboBox(tab);
+    mFillViewStrategyCombo = new QComboBox(tab);
     tabg->addWidget(mFillViewStrategyCombo, 0, 1);
 
     tabg->setColumnStretch(1, 1);
