@@ -1,20 +1,8 @@
 /******************************************************************************
  *
- *  Copyright 2008 Szymon Tomasz Stefanek <pragma@kvirc.net>
+ *  SPDX-FileCopyrightText: 2008 Szymon Tomasz Stefanek <pragma@kvirc.net>
  *
- *  This program is free softhisare; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Softhisare Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Softhisare
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  *
  *******************************************************************************/
 
@@ -48,8 +36,8 @@
 #include <QMimeData>
 
 #include <QColorDialog>
-#include <KComboBox>
-#include <KLineEdit>
+#include <QComboBox>
+#include <QLineEdit>
 #include <KLocalizedString>
 #include <QMenu>
 #include <KIconLoader>
@@ -65,13 +53,11 @@ using namespace MessageList::Core;
 static const char gThemeContentItemTypeDndMimeDataFormat[] = "application/x-kmail-messagelistview-theme-contentitem-type";
 
 ThemeColumnPropertiesDialog::ThemeColumnPropertiesDialog(QWidget *parent, Theme::Column *column, const QString &title)
-    : QDialog(parent), mColumn(column)
+    : QDialog(parent)
+    , mColumn(column)
 {
-    //setAttribute( Qt::WA_DeleteOnClose );
-    setWindowModality(Qt::ApplicationModal);   // FIXME: Sure ?
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
-    QVBoxLayout *mainLayout = new QVBoxLayout;
-    setLayout(mainLayout);
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -84,19 +70,17 @@ ThemeColumnPropertiesDialog::ThemeColumnPropertiesDialog(QWidget *parent, Theme:
 
     QGridLayout *g = new QGridLayout(base);
 
-    QLabel *l;
-
-    l = new QLabel(i18nc("@label:textbox Property name", "Name:"), base);
+    QLabel *l = new QLabel(i18nc("@label:textbox Property name", "Name:"), base);
     g->addWidget(l, 0, 0);
 
-    mNameEdit = new KLineEdit(base);
+    mNameEdit = new QLineEdit(base);
     mNameEdit->setToolTip(i18n("The label that will be displayed in the column header."));
     g->addWidget(mNameEdit, 0, 1);
 
     l = new QLabel(i18n("Header click sorts messages:"), base);
     g->addWidget(l, 1, 0);
 
-    mMessageSortingCombo = new KComboBox(base);
+    mMessageSortingCombo = new QComboBox(base);
     mMessageSortingCombo->setToolTip(i18n("The sorting order that clicking on this column header will switch to."));
     g->addWidget(mMessageSortingCombo, 1, 1);
 
@@ -119,7 +103,6 @@ ThemeColumnPropertiesDialog::ThemeColumnPropertiesDialog(QWidget *parent, Theme:
     mIsSenderOrReceiverCheck->setChecked(mColumn->isSenderOrReceiver());
     ComboBoxUtils::fillIntegerOptionCombo(mMessageSortingCombo, SortOrder::enumerateMessageSortingOptions(Aggregation::PerfectReferencesAndSubject));
     ComboBoxUtils::setIntegerOptionComboValue(mMessageSortingCombo, mColumn->messageSorting());
-
 }
 
 void ThemeColumnPropertiesDialog::slotOkButtonClicked()
@@ -134,14 +117,15 @@ void ThemeColumnPropertiesDialog::slotOkButtonClicked()
     mColumn->setMessageSorting(
         static_cast< SortOrder::MessageSorting >(
             ComboBoxUtils::getIntegerOptionComboValue(mMessageSortingCombo, SortOrder::NoMessageSorting)
-        )
-    );
+            )
+        );
 
     accept();
 }
 
 ThemeContentItemSourceLabel::ThemeContentItemSourceLabel(QWidget *parent, Theme::ContentItem::Type type)
-    : QLabel(parent), mType(type)
+    : QLabel(parent)
+    , mType(type)
 {
     setFrameStyle(QFrame::StyledPanel | QFrame::Raised);
 }
@@ -181,7 +165,7 @@ void ThemeContentItemSourceLabel::startDrag()
     QMimeData *data = new QMimeData();
     QByteArray arry;
     arry.resize(sizeof(Theme::ContentItem::Type));
-    *((Theme::ContentItem::Type *) arry.data()) = mType;
+    *((Theme::ContentItem::Type *)arry.data()) = mType;
     data->setData(QLatin1String(gThemeContentItemTypeDndMimeDataFormat), arry);
     QDrag *drag = new QDrag(this);
     drag->setMimeData(data);
@@ -197,25 +181,26 @@ ThemePreviewDelegate::ThemePreviewDelegate(QAbstractItemView *parent)
 
     mSampleGroupHeaderItem = new GroupHeaderItem(i18n("Message Group"));
 
-    mSampleGroupHeaderItem->setDate(time(Q_NULLPTR));
-    mSampleGroupHeaderItem->setMaxDate(time(Q_NULLPTR) + 31337);
+    mSampleGroupHeaderItem->setDate(time(nullptr));
+    mSampleGroupHeaderItem->setMaxDate(time(nullptr) + 31337);
     mSampleGroupHeaderItem->setSubject(i18n("Very long subject very long subject very long subject very long subject very long subject very long"));
 
     mSampleMessageItem = new FakeItem();
 
-    mSampleMessageItem->setDate(time(Q_NULLPTR));
+    mSampleMessageItem->setDate(time(nullptr));
     mSampleMessageItem->setSize(0x31337);
-    mSampleMessageItem->setMaxDate(time(Q_NULLPTR) + 31337);
+    mSampleMessageItem->setMaxDate(time(nullptr) + 31337);
     mSampleMessageItem->setSender(i18n("Sender"));
     mSampleMessageItem->setReceiver(i18n("Receiver"));
     mSampleMessageItem->setSubject(i18n("Very long subject very long subject very long subject very long subject very long subject very long"));
+    mSampleMessageItem->setFolder(i18n("Folder"));
     mSampleMessageItem->setSignatureState(MessageItem::FullySigned);
     mSampleMessageItem->setEncryptionState(MessageItem::FullyEncrypted);
 
     QList< MessageItem::Tag * > list;
-    list.append(new MessageItem::Tag(SmallIcon(QStringLiteral("feed-subscribe")), i18n("Sample Tag 1"), QString()));
-    list.append(new MessageItem::Tag(SmallIcon(QStringLiteral("feed-subscribe")), i18n("Sample Tag 2"), QString()));
-    list.append(new MessageItem::Tag(SmallIcon(QStringLiteral("feed-subscribe")), i18n("Sample Tag 3"), QString()));
+    list.append(new MessageItem::Tag(QIcon::fromTheme(QStringLiteral("feed-subscribe")).pixmap(KIconLoader::SizeSmall), i18n("Sample Tag 1"), QString()));
+    list.append(new MessageItem::Tag(QIcon::fromTheme(QStringLiteral("feed-subscribe")).pixmap(KIconLoader::SizeSmall), i18n("Sample Tag 2"), QString()));
+    list.append(new MessageItem::Tag(QIcon::fromTheme(QStringLiteral("feed-subscribe")).pixmap(KIconLoader::SizeSmall), i18n("Sample Tag 3"), QString()));
     mSampleMessageItem->setFakeTags(list);
 
     mRowMapper->createModelInvariantIndex(0, mSampleMessageItem);
@@ -253,11 +238,11 @@ Item *ThemePreviewDelegate::itemFromIndex(const QModelIndex &index) const
 }
 
 ThemePreviewWidget::ThemePreviewWidget(QWidget *parent)
-    : QTreeWidget(parent),
-      mTheme(Q_NULLPTR)
+    : QTreeWidget(parent)
+    , mTheme(nullptr)
 {
-    mSelectedThemeContentItem = Q_NULLPTR;
-    mSelectedThemeColumn = Q_NULLPTR;
+    mSelectedThemeContentItem = nullptr;
+    mSelectedThemeColumn = nullptr;
     mFirstShow = true;
     mReadOnly = false;
 
@@ -278,7 +263,7 @@ ThemePreviewWidget::ThemePreviewWidget(QWidget *parent)
     m->setText(0, QString());
 
     mGroupHeaderSampleItem->setExpanded(true);
-    header()->setMovable(false);
+    header()->setSectionsMovable(false);
 }
 
 void ThemePreviewWidget::changeEvent(QEvent *event)
@@ -412,7 +397,7 @@ void ThemePreviewWidget::setTheme(Theme *theme)
 {
     bool themeChanged = theme != mTheme;
 
-    mSelectedThemeContentItem = Q_NULLPTR;
+    mSelectedThemeContentItem = nullptr;
     mThemeSelectedContentItemRect = QRect();
     mDropIndicatorPoint1 = QPoint();
     mDropIndicatorPoint2 = QPoint();
@@ -505,7 +490,7 @@ void ThemePreviewWidget::internalHandleDragMoveEvent(QDragMoveEvent *e)
         return;    // ugh
     }
 
-    Theme::ContentItem::Type type = *((Theme::ContentItem::Type *) arry.data());
+    Theme::ContentItem::Type type = *((Theme::ContentItem::Type *)arry.data());
 
     if (!computeContentItemInsertPosition(e->pos(), type)) {
         return;
@@ -551,14 +536,14 @@ void ThemePreviewWidget::dropEvent(QDropEvent *e)
         return;    // ugh
     }
 
-    Theme::ContentItem::Type type = *((Theme::ContentItem::Type *) arry.data());
+    Theme::ContentItem::Type type = *((Theme::ContentItem::Type *)arry.data());
 
     if (!computeContentItemInsertPosition(e->pos(), type)) {
         viewport()->update();
         return;
     }
 
-    Theme::Row *row = Q_NULLPTR;
+    Theme::Row *row = nullptr;
 
     switch (mRowInsertPosition) {
     case AboveRow:
@@ -604,9 +589,9 @@ void ThemePreviewWidget::dropEvent(QDropEvent *e)
             delete ci;
             return;
         }
-        idx = mDelegate->hitContentItemRight() ? \
-              row->rightItems().indexOf(const_cast< Theme::ContentItem * >(mDelegate->hitContentItem())) : \
-              row->leftItems().indexOf(const_cast< Theme::ContentItem * >(mDelegate->hitContentItem()));
+        idx = mDelegate->hitContentItemRight()   \
+              ? row->rightItems().indexOf(const_cast< Theme::ContentItem * >(mDelegate->hitContentItem()))   \
+              : row->leftItems().indexOf(const_cast< Theme::ContentItem * >(mDelegate->hitContentItem()));
         if (idx < 0) {
             // bleah
             delete ci;
@@ -624,9 +609,9 @@ void ThemePreviewWidget::dropEvent(QDropEvent *e)
             delete ci;
             return;
         }
-        idx = mDelegate->hitContentItemRight() ? \
-              row->rightItems().indexOf(const_cast< Theme::ContentItem * >(mDelegate->hitContentItem())) : \
-              row->leftItems().indexOf(const_cast< Theme::ContentItem * >(mDelegate->hitContentItem()));
+        idx = mDelegate->hitContentItemRight()   \
+              ? row->rightItems().indexOf(const_cast< Theme::ContentItem * >(mDelegate->hitContentItem()))   \
+              : row->leftItems().indexOf(const_cast< Theme::ContentItem * >(mDelegate->hitContentItem()));
         if (idx < 0) {
             // bleah
             delete ci;
@@ -659,7 +644,7 @@ void ThemePreviewWidget::dropEvent(QDropEvent *e)
 
     mThemeSelectedContentItemRect = QRect();
     mDropIndicatorPoint1 = mDropIndicatorPoint2;
-    mSelectedThemeContentItem = Q_NULLPTR;
+    mSelectedThemeContentItem = nullptr;
 
     setTheme(mTheme);   // this will reset theme cache and trigger a global update
 }
@@ -721,11 +706,11 @@ bool ThemePreviewWidget::computeContentItemInsertPosition(const QPoint &pos, The
     if (!mDelegate->hitContentItem()) {
         // didn't hit anything... probably no items in the row
         if (pos.x() < (rowRect.left() + (rowRect.width() / 2))) {
-            mItemInsertPosition =  AsLastLeftItem;
+            mItemInsertPosition = AsLastLeftItem;
             mDropIndicatorPoint1 = QPoint(rowRect.left(), rowRect.top());
             mDropIndicatorPoint2 = QPoint(rowRect.left(), rowRect.bottom());
         } else {
-            mItemInsertPosition =  AsLastRightItem;
+            mItemInsertPosition = AsLastRightItem;
             mDropIndicatorPoint1 = QPoint(rowRect.right(), rowRect.top());
             mDropIndicatorPoint2 = QPoint(rowRect.right(), rowRect.bottom());
         }
@@ -812,7 +797,7 @@ void ThemePreviewWidget::mouseMoveEvent(QMouseEvent *e)
     QMimeData *data = new QMimeData();
     QByteArray arry;
     arry.resize(sizeof(Theme::ContentItem::Type));
-    *((Theme::ContentItem::Type *) arry.data()) = mSelectedThemeContentItem->type();
+    *((Theme::ContentItem::Type *)arry.data()) = mSelectedThemeContentItem->type();
     data->setData(QLatin1String(gThemeContentItemTypeDndMimeDataFormat), arry);
     QDrag *drag = new QDrag(this);
     drag->setMimeData(data);
@@ -840,7 +825,7 @@ void ThemePreviewWidget::mouseMoveEvent(QMouseEvent *e)
         }
     }
 
-    mSelectedThemeContentItem = Q_NULLPTR;
+    mSelectedThemeContentItem = nullptr;
     mThemeSelectedContentItemRect = QRect();
     mDropIndicatorPoint1 = mDropIndicatorPoint2;
 
@@ -863,7 +848,7 @@ void ThemePreviewWidget::mousePressEvent(QMouseEvent *e)
         mSelectedThemeContentItem = const_cast< Theme::ContentItem * >(mDelegate->hitContentItem());
         mThemeSelectedContentItemRect = mSelectedThemeContentItem ? mDelegate->hitContentItemRect() : QRect();
     } else {
-        mSelectedThemeContentItem = Q_NULLPTR;
+        mSelectedThemeContentItem = nullptr;
         mThemeSelectedContentItemRect = QRect();
     }
 
@@ -874,12 +859,10 @@ void ThemePreviewWidget::mousePressEvent(QMouseEvent *e)
         QMenu menu;
 
         if (mSelectedThemeContentItem) {
-
             menu.addSection(Theme::ContentItem::description(mSelectedThemeContentItem->type()));
 
             if (mSelectedThemeContentItem->displaysText()) {
-                QAction *act;
-                act = menu.addAction(i18nc("@action:inmenu soften the text color", "Soften"));
+                QAction *act = menu.addAction(i18nc("@action:inmenu soften the text color", "Soften"));
                 act->setCheckable(true);
                 act->setChecked(mSelectedThemeContentItem->softenByBlending());
                 connect(act, &QAction::triggered, this, &ThemePreviewWidget::slotSoftenActionTriggered);
@@ -905,8 +888,7 @@ void ThemePreviewWidget::mousePressEvent(QMouseEvent *e)
 
                 QActionGroup *grp = new QActionGroup(childmenu);
 
-                QAction *act;
-                act = childmenu->addAction(i18nc("@action:inmenu Foreground color setting", "Default"));
+                QAction *act = childmenu->addAction(i18nc("@action:inmenu Foreground color setting", "Default"));
                 act->setData(QVariant(static_cast< int >(0)));
                 act->setCheckable(true);
                 act->setChecked(!mSelectedThemeContentItem->useCustomColor());
@@ -927,8 +909,7 @@ void ThemePreviewWidget::mousePressEvent(QMouseEvent *e)
 
                 QActionGroup *grp = new QActionGroup(childmenu);
 
-                QAction *act;
-                act = childmenu->addAction(i18nc("Hide a mark if the mail does not have the attribute, e.g. Important mark on a non important mail", "Hide"));
+                QAction *act = childmenu->addAction(i18nc("Hide a mark if the mail does not have the attribute, e.g. Important mark on a non important mail", "Hide"));
                 act->setData(QVariant(static_cast< int >(Theme::ContentItem::HideWhenDisabled)));
                 act->setCheckable(true);
                 act->setChecked(mSelectedThemeContentItem->hideWhenDisabled());
@@ -948,7 +929,6 @@ void ThemePreviewWidget::mousePressEvent(QMouseEvent *e)
 
                 menu.addMenu(childmenu)->setText(i18n("When Disabled"));
             }
-
         }
 
         if (mDelegate->hitItem()) {
@@ -960,8 +940,7 @@ void ThemePreviewWidget::mousePressEvent(QMouseEvent *e)
 
                 QActionGroup *grp = new QActionGroup(childmenu);
 
-                QAction *act;
-                act = childmenu->addAction(i18nc("@action:inmenu Group header background color setting", "None"));
+                QAction *act = childmenu->addAction(i18nc("@action:inmenu Group header background color setting", "None"));
                 act->setData(QVariant(static_cast< int >(Theme::Transparent)));
                 act->setCheckable(true);
                 act->setChecked(mTheme->groupHeaderBackgroundMode() == Theme::Transparent);
@@ -985,10 +964,10 @@ void ThemePreviewWidget::mousePressEvent(QMouseEvent *e)
                 childmenu = new QMenu(&menu);
 
                 grp = new QActionGroup(childmenu);
-                QList< QPair< QString, int > > styles = Theme::enumerateGroupHeaderBackgroundStyles();
-                QList< QPair< QString, int > >::ConstIterator end(styles.constEnd());
+                QVector< QPair< QString, int > > styles = Theme::enumerateGroupHeaderBackgroundStyles();
+                QVector< QPair< QString, int > >::ConstIterator end(styles.constEnd());
 
-                for (QList< QPair< QString, int > >::ConstIterator it = styles.constBegin(); it != end; ++it) {
+                for (QVector< QPair< QString, int > >::ConstIterator it = styles.constBegin(); it != end; ++it) {
                     act = childmenu->addAction((*it).first);
                     act->setData(QVariant((*it).second));
                     act->setCheckable(true);
@@ -1003,7 +982,6 @@ void ThemePreviewWidget::mousePressEvent(QMouseEvent *e)
                 if (mTheme->groupHeaderBackgroundMode() == Theme::Transparent) {
                     act->setEnabled(false);
                 }
-
             }
         }
 
@@ -1012,7 +990,6 @@ void ThemePreviewWidget::mousePressEvent(QMouseEvent *e)
         }
 
         menu.exec(viewport()->mapToGlobal(e->pos()));
-
     }
 }
 
@@ -1110,17 +1087,18 @@ void ThemePreviewWidget::slotGroupHeaderBackgroundModeMenuTriggered(QAction *act
     case Theme::AutoColor:
         mTheme->setGroupHeaderBackgroundMode(Theme::AutoColor);
         break;
-    case Theme::CustomColor: {
+    case Theme::CustomColor:
+    {
         QColor clr;
         clr = QColorDialog::getColor(mTheme->groupHeaderBackgroundColor(), this);
-        if (clr.isValid()) {
+        if (!clr.isValid()) {
             return;
         }
 
         mTheme->setGroupHeaderBackgroundMode(Theme::CustomColor);
         mTheme->setGroupHeaderBackgroundColor(clr);
+        break;
     }
-    break;
     }
 
     setTheme(mTheme);   // this will reset theme cache and trigger a global update
@@ -1144,9 +1122,9 @@ void ThemePreviewWidget::paintEvent(QPaintEvent *e)
     QTreeWidget::paintEvent(e);
 
     if (
-        mThemeSelectedContentItemRect.isValid() ||
-        (mDropIndicatorPoint1 != mDropIndicatorPoint2)
-    ) {
+        mThemeSelectedContentItemRect.isValid()
+        || (mDropIndicatorPoint1 != mDropIndicatorPoint2)
+        ) {
         QPainter painter(viewport());
 
         if (mThemeSelectedContentItemRect.isValid()) {
@@ -1190,9 +1168,7 @@ void ThemePreviewWidget::slotHeaderContextMenuRequested(const QPoint &pos)
 
     menu.setTitle(mSelectedThemeColumn->label());
 
-    QAction *act;
-
-    act = menu.addAction(i18n("Column Properties..."));
+    QAction *act = menu.addAction(i18n("Column Properties..."));
     connect(act, &QAction::triggered, this, &ThemePreviewWidget::slotColumnProperties);
 
     act = menu.addAction(i18n("Add Column..."));
@@ -1257,22 +1233,20 @@ void ThemePreviewWidget::slotAddColumn()
     mSelectedThemeColumn->addMessageRow(new Theme::Row());
     mSelectedThemeColumn->addGroupHeaderRow(new Theme::Row());
 
-    ThemeColumnPropertiesDialog *dlg =
-        new ThemeColumnPropertiesDialog(this, mSelectedThemeColumn, i18n("Add New Column"));
+    ThemeColumnPropertiesDialog *dlg
+        = new ThemeColumnPropertiesDialog(this, mSelectedThemeColumn, i18n("Add New Column"));
 
     if (dlg->exec() == QDialog::Accepted) {
         mTheme->insertColumn(newColumnIndex, mSelectedThemeColumn);
 
-        mSelectedThemeContentItem = Q_NULLPTR;
+        mSelectedThemeContentItem = nullptr;
         mThemeSelectedContentItemRect = QRect();
         mDropIndicatorPoint1 = mDropIndicatorPoint2;
 
         setTheme(mTheme);   // this will reset theme cache and trigger a global update
-
     } else {
-
         delete mSelectedThemeColumn;
-        mSelectedThemeColumn = Q_NULLPTR;
+        mSelectedThemeColumn = nullptr;
     }
 
     delete dlg;
@@ -1284,11 +1258,11 @@ void ThemePreviewWidget::slotColumnProperties()
         return;
     }
 
-    ThemeColumnPropertiesDialog *dlg =
-        new ThemeColumnPropertiesDialog(this, mSelectedThemeColumn, i18n("Column Properties"));
+    ThemeColumnPropertiesDialog *dlg
+        = new ThemeColumnPropertiesDialog(this, mSelectedThemeColumn, i18n("Column Properties"));
 
     if (dlg->exec() == QDialog::Accepted) {
-        mSelectedThemeContentItem = Q_NULLPTR;
+        mSelectedThemeContentItem = nullptr;
         mThemeSelectedContentItemRect = QRect();
         mDropIndicatorPoint1 = mDropIndicatorPoint2;
 
@@ -1311,9 +1285,9 @@ void ThemePreviewWidget::slotDeleteColumn()
 
     mTheme->removeColumn(mSelectedThemeColumn);
     delete mSelectedThemeColumn;
-    mSelectedThemeColumn = Q_NULLPTR;
+    mSelectedThemeColumn = nullptr;
 
-    mSelectedThemeContentItem = Q_NULLPTR;
+    mSelectedThemeContentItem = nullptr;
     mThemeSelectedContentItemRect = QRect();
     mDropIndicatorPoint1 = mDropIndicatorPoint2;
 
@@ -1323,7 +1297,7 @@ void ThemePreviewWidget::slotDeleteColumn()
 ThemeEditor::ThemeEditor(QWidget *parent)
     : OptionSetEditor(parent)
 {
-    mCurrentTheme = Q_NULLPTR;
+    mCurrentTheme = nullptr;
 
     // Appearance tab
     QWidget *tab = new QWidget(this);
@@ -1336,6 +1310,8 @@ ThemeEditor::ThemeEditor(QWidget *parent)
 
     QGridLayout *gblayout = new QGridLayout(gb);
 
+    Theme dummyTheme;
+
     ThemeContentItemSourceLabel *cil = new ThemeContentItemSourceLabel(gb, Theme::ContentItem::Subject);
     cil->setText(Theme::ContentItem::description(cil->type()));
     cil->setToolTip(Theme::ContentItem::description(cil->type()));
@@ -1376,78 +1352,83 @@ ThemeEditor::ThemeEditor(QWidget *parent)
     cil->setToolTip(Theme::ContentItem::description(cil->type()));
     gblayout->addWidget(cil, 1, 2);
 
+    cil = new ThemeContentItemSourceLabel(gb, Theme::ContentItem::Folder);
+    cil->setText(Theme::ContentItem::description(cil->type()));
+    cil->setToolTip(Theme::ContentItem::description(cil->type()));
+    gblayout->addWidget(cil, 2, 2);
+
     cil = new ThemeContentItemSourceLabel(gb, Theme::ContentItem::CombinedReadRepliedStateIcon);
-    cil->setPixmap(*(Manager::instance()->pixmapMessageRepliedAndForwarded()));
+    cil->setPixmap(*dummyTheme.pixmap(Theme::IconRepliedAndForwarded));
     cil->setToolTip(Theme::ContentItem::description(cil->type()));
     gblayout->addWidget(cil, 0, 3);
 
     cil = new ThemeContentItemSourceLabel(gb, Theme::ContentItem::ReadStateIcon);
-    cil->setPixmap(*(Manager::instance()->pixmapMessageNew()));
+    cil->setPixmap(*dummyTheme.pixmap(Theme::IconNew));
     cil->setToolTip(Theme::ContentItem::description(cil->type()));
     gblayout->addWidget(cil, 1, 3);
 
     cil = new ThemeContentItemSourceLabel(gb, Theme::ContentItem::RepliedStateIcon);
-    cil->setPixmap(*(Manager::instance()->pixmapMessageReplied()));
+    cil->setPixmap(*dummyTheme.pixmap(Theme::IconReplied));
     cil->setToolTip(Theme::ContentItem::description(cil->type()));
     gblayout->addWidget(cil, 2, 3);
 
     cil = new ThemeContentItemSourceLabel(gb, Theme::ContentItem::AttachmentStateIcon);
-    cil->setPixmap(*(Manager::instance()->pixmapMessageAttachment()));
+    cil->setPixmap(*dummyTheme.pixmap(Theme::IconAttachment));
     cil->setToolTip(Theme::ContentItem::description(cil->type()));
     gblayout->addWidget(cil, 0, 4);
 
     cil = new ThemeContentItemSourceLabel(gb, Theme::ContentItem::EncryptionStateIcon);
-    cil->setPixmap(*(Manager::instance()->pixmapMessageFullyEncrypted()));
+    cil->setPixmap(*dummyTheme.pixmap(Theme::IconFullyEncrypted));
     cil->setToolTip(Theme::ContentItem::description(cil->type()));
     gblayout->addWidget(cil, 1, 4);
 
     cil = new ThemeContentItemSourceLabel(gb, Theme::ContentItem::SignatureStateIcon);
-    cil->setPixmap(*(Manager::instance()->pixmapMessageFullySigned()));
+    cil->setPixmap(*dummyTheme.pixmap(Theme::IconFullySigned));
     cil->setToolTip(Theme::ContentItem::description(cil->type()));
     gblayout->addWidget(cil, 2, 4);
 
     cil = new ThemeContentItemSourceLabel(gb, Theme::ContentItem::ActionItemStateIcon);
-    cil->setPixmap(*(Manager::instance()->pixmapMessageActionItem()));
+    cil->setPixmap(*dummyTheme.pixmap(Theme::IconActionItem));
     cil->setToolTip(Theme::ContentItem::description(cil->type()));
     gblayout->addWidget(cil, 0, 5);
 
     cil = new ThemeContentItemSourceLabel(gb, Theme::ContentItem::AnnotationIcon);
-    cil->setPixmap(*(Manager::instance()->pixmapMessageAnnotation()));
+    cil->setPixmap(*dummyTheme.pixmap(Theme::IconAnnotation));
     cil->setToolTip(Theme::ContentItem::description(cil->type()));
     gblayout->addWidget(cil, 1, 5);
 
     cil = new ThemeContentItemSourceLabel(gb, Theme::ContentItem::InvitationIcon);
-    cil->setPixmap(*(Manager::instance()->pixmapMessageInvitation()));
+    cil->setPixmap(*dummyTheme.pixmap(Theme::IconInvitation));
     cil->setToolTip(Theme::ContentItem::description(cil->type()));
     gblayout->addWidget(cil, 2, 5);
 
     cil = new ThemeContentItemSourceLabel(gb, Theme::ContentItem::ImportantStateIcon);
-    cil->setPixmap(*(Manager::instance()->pixmapMessageImportant()));
+    cil->setPixmap(*dummyTheme.pixmap(Theme::IconImportant));
     cil->setToolTip(Theme::ContentItem::description(cil->type()));
     gblayout->addWidget(cil, 0, 6);
 
     cil = new ThemeContentItemSourceLabel(gb, Theme::ContentItem::SpamHamStateIcon);
-    cil->setPixmap(*(Manager::instance()->pixmapMessageSpam()));
+    cil->setPixmap(*dummyTheme.pixmap(Theme::IconSpam));
     cil->setToolTip(Theme::ContentItem::description(cil->type()));
     gblayout->addWidget(cil, 1, 6);
 
     cil = new ThemeContentItemSourceLabel(gb, Theme::ContentItem::WatchedIgnoredStateIcon);
-    cil->setPixmap(*(Manager::instance()->pixmapMessageWatched()));
+    cil->setPixmap(*dummyTheme.pixmap(Theme::IconWatched));
     cil->setToolTip(Theme::ContentItem::description(cil->type()));
     gblayout->addWidget(cil, 2, 6);
 
     cil = new ThemeContentItemSourceLabel(gb, Theme::ContentItem::ExpandedStateIcon);
-    cil->setPixmap(*(Manager::instance()->pixmapShowMore()));
+    cil->setPixmap(*dummyTheme.pixmap(Theme::IconShowMore));
     cil->setToolTip(Theme::ContentItem::description(cil->type()));
     gblayout->addWidget(cil, 0, 7);
 
     cil = new ThemeContentItemSourceLabel(gb, Theme::ContentItem::VerticalLine);
-    cil->setPixmap(*(Manager::instance()->pixmapVerticalLine()));
+    cil->setPixmap(*dummyTheme.pixmap(Theme::IconVerticalLine));
     cil->setToolTip(Theme::ContentItem::description(cil->type()));
     gblayout->addWidget(cil, 1, 7);
 
     cil = new ThemeContentItemSourceLabel(gb, Theme::ContentItem::HorizontalSpacer);
-    cil->setPixmap(*(Manager::instance()->pixmapHorizontalSpacer()));
+    cil->setPixmap(*dummyTheme.pixmap(Theme::IconHorizontalSpacer));
     cil->setToolTip(Theme::ContentItem::description(cil->type()));
     gblayout->addWidget(cil, 2, 7);
 
@@ -1455,7 +1436,8 @@ ThemeEditor::ThemeEditor(QWidget *parent)
     tabg->addWidget(mPreviewWidget, 1, 0);
 
     QLabel *l = new QLabel(tab);
-    l->setText(i18n("Right click on the header to add or modify columns. Drag the content items and drop them on the columns in order to compose your theme. Right click on the items inside the view for more options."));
+    l->setText(i18n(
+                   "Right click on the header to add or modify columns. Drag the content items and drop them on the columns in order to compose your theme. Right click on the items inside the view for more options."));
     l->setWordWrap(true);
     l->setAlignment(Qt::AlignCenter);
     tabg->addWidget(l, 2, 0);
@@ -1471,7 +1453,7 @@ ThemeEditor::ThemeEditor(QWidget *parent)
     l = new QLabel(i18n("Header:"), tab);
     tabg->addWidget(l, 0, 0);
 
-    mViewHeaderPolicyCombo = new KComboBox(tab);
+    mViewHeaderPolicyCombo = new QComboBox(tab);
     tabg->addWidget(mViewHeaderPolicyCombo, 0, 1);
 
     l = new QLabel(i18n("Icon size:"), tab);
@@ -1482,14 +1464,13 @@ ThemeEditor::ThemeEditor(QWidget *parent)
     mIconSizeSpinBox->setMaximum(64);
     mIconSizeSpinBox->setSuffix(ki18ncp("suffix in a spinbox", " pixel", " pixels"));
 
-    QObject::connect(mIconSizeSpinBox, static_cast<void (KPluralHandlingSpinBox::*)(int)>(&KPluralHandlingSpinBox::valueChanged), this, &ThemeEditor::slotIconSizeSpinBoxValueChanged);
+    QObject::connect(mIconSizeSpinBox, qOverload<int>(&KPluralHandlingSpinBox::valueChanged), this, &ThemeEditor::slotIconSizeSpinBoxValueChanged);
 
     tabg->addWidget(mIconSizeSpinBox, 1, 1);
 
     tabg->setColumnStretch(1, 1);
     tabg->setRowStretch(2, 1);
     fillViewHeaderPolicyCombo();
-
 }
 
 ThemeEditor::~ThemeEditor()
@@ -1535,7 +1516,7 @@ void ThemeEditor::commit()
 
     mCurrentTheme->setViewHeaderPolicy(
         (Theme::ViewHeaderPolicy)ComboBoxUtils::getIntegerOptionComboValue(mViewHeaderPolicyCombo, 0)
-    );
+        );
     mCurrentTheme->setIconSize(mIconSizeSpinBox->value());
     // other settings are already committed to this theme
 }
@@ -1545,7 +1526,7 @@ void ThemeEditor::fillViewHeaderPolicyCombo()
     ComboBoxUtils::fillIntegerOptionCombo(
         mViewHeaderPolicyCombo,
         Theme::enumerateViewHeaderPolicyOptions()
-    );
+        );
 }
 
 void ThemeEditor::slotNameEditTextEdited(const QString &newName)
@@ -1571,4 +1552,3 @@ MessageList::Core::Theme *ThemeEditor::editedTheme() const
 {
     return mCurrentTheme;
 }
-
