@@ -1,19 +1,7 @@
 /*
-    Copyright (c) 2009 Kevin Ottens <ervin@kde.org>
+    SPDX-FileCopyrightText: 2009 Kevin Ottens <ervin@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "widget.h"
@@ -34,10 +22,10 @@
 #include <QDragMoveEvent>
 #include <QDropEvent>
 #include <QMimeData>
+#include <QUrlQuery>
 
 #include "messagelist_debug.h"
 #include <QIcon>
-#include <KIconLoader>
 #include <KLocalizedString>
 #include <QMenu>
 #include <KXMLGUIClient>
@@ -52,14 +40,17 @@
 #include <TagFetchScope>
 #include <TagAttribute>
 
-namespace MessageList
-{
-
+namespace MessageList {
 class Q_DECL_HIDDEN Widget::Private
 {
 public:
     Private(Widget *owner)
-        : q(owner), mLastSelectedMessage(-1), mXmlGuiClient(nullptr), mMonitor(nullptr) { }
+        : q(owner)
+        , mLastSelectedMessage(-1)
+        , mXmlGuiClient(nullptr)
+        , mMonitor(nullptr)
+    {
+    }
 
     Akonadi::Item::List selectionAsItems() const;
     Akonadi::Item itemForRow(int row) const;
@@ -68,22 +59,23 @@ public:
     Widget *const q;
 
     int mLastSelectedMessage;
-    KXMLGUIClient *mXmlGuiClient;
+    KXMLGUIClient *mXmlGuiClient = nullptr;
     QModelIndex mGroupHeaderItemIndex;
-    Akonadi::Monitor *mMonitor;
+    Akonadi::Monitor *mMonitor = nullptr;
 };
-
 } // namespace MessageList
 
 using namespace MessageList;
 using namespace Akonadi;
 
 Widget::Widget(QWidget *parent)
-    : Core::Widget(parent), d(new Private(this))
+    : Core::Widget(parent)
+    , d(new Private(this))
 {
     populateStatusFilterCombo();
 
     d->mMonitor = new Akonadi::Monitor(this);
+    d->mMonitor->setObjectName(QStringLiteral("MessageListTagMonitor"));
     d->mMonitor->setTypeMonitored(Akonadi::Monitor::Tags);
     connect(d->mMonitor, &Akonadi::Monitor::tagAdded, this, &Widget::populateStatusFilterCombo);
     connect(d->mMonitor, &Akonadi::Monitor::tagRemoved, this, &Widget::populateStatusFilterCombo);
@@ -123,7 +115,8 @@ bool Widget::canAcceptDrag(const QDropEvent *e)
         if (collection.isValid()) {   // You're not supposed to drop collections here
             return false;
         } else { // Yay, this is an item!
-            const QString type = url.queryItemValue(QStringLiteral("type"));
+            QUrlQuery query(url);
+            const QString type = query.queryItemValue(QStringLiteral("type"));
             if (!target.contentMimeTypes().contains(type)) {
                 return false;
             }
@@ -133,18 +126,12 @@ bool Widget::canAcceptDrag(const QDropEvent *e)
     return true;
 }
 
-bool Widget::selectNextMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter,
-                                   MessageList::Core::ExistingSelectionBehaviour existingSelectionBehaviour,
-                                   bool centerItem,
-                                   bool loop)
+bool Widget::selectNextMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, MessageList::Core::ExistingSelectionBehaviour existingSelectionBehaviour, bool centerItem, bool loop)
 {
     return view()->selectNextMessageItem(messageTypeFilter, existingSelectionBehaviour, centerItem, loop);
 }
 
-bool Widget::selectPreviousMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter,
-                                       MessageList::Core::ExistingSelectionBehaviour existingSelectionBehaviour,
-                                       bool centerItem,
-                                       bool loop)
+bool Widget::selectPreviousMessageItem(MessageList::Core::MessageTypeFilter messageTypeFilter, MessageList::Core::ExistingSelectionBehaviour existingSelectionBehaviour, bool centerItem, bool loop)
 {
     return view()->selectPreviousMessageItem(messageTypeFilter, existingSelectionBehaviour, centerItem, loop);
 }
@@ -237,7 +224,7 @@ void Widget::slotTagsFetched(KJob *job)
             QString iconName = QStringLiteral("mail-tagged");
             const QString label = akonadiTag.name();
             const QString id = akonadiTag.url().url();
-            Akonadi::TagAttribute *attr = akonadiTag.attribute<Akonadi::TagAttribute>();
+            const Akonadi::TagAttribute *attr = akonadiTag.attribute<Akonadi::TagAttribute>();
             if (attr) {
                 iconName = attr->iconName();
             }
@@ -307,8 +294,7 @@ void Widget::viewSelectionChanged()
     }
 }
 
-void Widget::viewMessageListContextPopupRequest(const QList< MessageList::Core::MessageItem * > &selectedItems,
-        const QPoint &globalPos)
+void Widget::viewMessageListContextPopupRequest(const QVector< MessageList::Core::MessageItem * > &selectedItems, const QPoint &globalPos)
 {
     Q_UNUSED(selectedItems);
 
@@ -348,7 +334,7 @@ void Widget::viewGroupHeaderContextPopupRequest(MessageList::Core::GroupHeaderIt
 
     QMenu menu(this);
 
-    QAction *act;
+    QAction *act = nullptr;
 
     QModelIndex index = view()->model()->index(ghi, 0);
     d->mGroupHeaderItemIndex = index;
@@ -407,7 +393,7 @@ void Widget::viewDropEvent(QDropEvent *e)
         return;
     }
 
-    QList<QUrl> urls = e->mimeData()->urls();
+    const QList<QUrl> urls = e->mimeData()->urls();
     if (urls.isEmpty()) {
         qCWarning(MESSAGELIST_LOG) << "Could not decode drag data!";
         e->ignore();
@@ -420,14 +406,11 @@ void Widget::viewDropEvent(QDropEvent *e)
     if ((e->possibleActions() & Qt::MoveAction) == 0) {     // We can't move anyway
         action = DragCopy;
     } else {
-        action = DragCancel;
-        int keybstate = QApplication::keyboardModifiers();
+        const auto keybstate = QApplication::keyboardModifiers();
         if (keybstate & Qt::CTRL) {
             action = DragCopy;
-
         } else if (keybstate & Qt::SHIFT) {
             action = DragMove;
-
         } else {
             QMenu menu;
             QAction *moveAction = menu.addAction(QIcon::fromTheme(QStringLiteral("go-jump")), i18n("&Move Here"));
@@ -453,7 +436,7 @@ void Widget::viewDropEvent(QDropEvent *e)
     Collection target = collections.at(0);
     Item::List items;
     items.reserve(urls.count());
-    foreach (const QUrl &url, urls) {
+    for (const QUrl &url : qAsConst(urls)) {
         items << Item::fromUrl(url);
     }
 
@@ -472,14 +455,14 @@ void Widget::viewStartDragRequest()
         return;    // no folder here
     }
 
-    const QList<Core::MessageItem *> selection = view()->selectionAsMessageItemList();
+    const QVector<Core::MessageItem *> selection = view()->selectionAsMessageItemList();
     if (selection.isEmpty()) {
         return;
     }
 
     bool readOnly = false;
 
-    foreach (const Collection &c, collections) {
+    for (const Collection &c : qAsConst(collections)) {
         // We won't be able to remove items from this collection
         if ((c.rights() & Collection::CanDeleteItem) == 0) {
             // So the drag will be read-only
@@ -493,7 +476,9 @@ void Widget::viewStartDragRequest()
     for (Core::MessageItem *mi : selection) {
         const Item i = d->itemForRow(mi->currentModelIndexRow());
         QUrl url = i.url(Item::Item::Item::UrlWithMimeType);
-        url.addQueryItem(QStringLiteral("parent"), QString::number(mi->parentCollectionId()));
+        QUrlQuery query(url);
+        query.addQueryItem(QStringLiteral("parent"), QString::number(mi->parentCollectionId()));
+        url.setQuery(query);
         urls << url;
     }
 
@@ -506,9 +491,9 @@ void Widget::viewStartDragRequest()
     // Set pixmap
     QPixmap pixmap;
     if (selection.size() == 1) {
-        pixmap = QPixmap(DesktopIcon(QStringLiteral("mail-message"), KIconLoader::SizeSmall));
+        pixmap = QIcon::fromTheme(QStringLiteral("mail-message")).pixmap(style()->pixelMetric(QStyle::PM_SmallIconSize));
     } else {
-        pixmap = QPixmap(DesktopIcon(QStringLiteral("document-multiple"), KIconLoader::SizeSmall));
+        pixmap = QIcon::fromTheme(QStringLiteral("document-multiple")).pixmap(style()->pixelMetric(QStyle::PM_SmallIconSize));
     }
 
     // Calculate hotspot (as in Konqueror)
@@ -527,10 +512,10 @@ void Widget::viewStartDragRequest()
 Item::List Widget::Private::selectionAsItems() const
 {
     Item::List res;
-    QList<Core::MessageItem *> selection = q->view()->selectionAsMessageItemList();
+    const QVector<Core::MessageItem *> selection = q->view()->selectionAsMessageItemList();
     res.reserve(selection.count());
 
-    foreach (Core::MessageItem *mi, selection) {
+    for (Core::MessageItem *mi : qAsConst(selection)) {
         Item i = itemForRow(mi->currentModelIndexRow());
         Q_ASSERT(i.isValid());
         res << i;
@@ -571,15 +556,15 @@ KMime::Message::Ptr Widget::currentMessage() const
     return d->messageForRow(mi->currentModelIndexRow());
 }
 
-QList<KMime::Message::Ptr > Widget::selectionAsMessageList(bool includeCollapsedChildren) const
+QVector<KMime::Message::Ptr > Widget::selectionAsMessageList(bool includeCollapsedChildren) const
 {
-    QList<KMime::Message::Ptr> lstMiPtr;
-    QList<Core::MessageItem *> lstMi = view()->selectionAsMessageItemList(includeCollapsedChildren);
+    QVector<KMime::Message::Ptr> lstMiPtr;
+    const QVector<Core::MessageItem *> lstMi = view()->selectionAsMessageItemList(includeCollapsedChildren);
     if (lstMi.isEmpty()) {
         return lstMiPtr;
     }
     lstMiPtr.reserve(lstMi.count());
-    foreach (Core::MessageItem *it, lstMi) {
+    for (Core::MessageItem *it : qAsConst(lstMi)) {
         lstMiPtr.append(d->messageForRow(it->currentModelIndexRow()));
     }
     return lstMiPtr;
@@ -588,12 +573,12 @@ QList<KMime::Message::Ptr > Widget::selectionAsMessageList(bool includeCollapsed
 Akonadi::Item::List Widget::selectionAsMessageItemList(bool includeCollapsedChildren) const
 {
     Akonadi::Item::List lstMiPtr;
-    QList<Core::MessageItem *> lstMi = view()->selectionAsMessageItemList(includeCollapsedChildren);
+    const QVector<Core::MessageItem *> lstMi = view()->selectionAsMessageItemList(includeCollapsedChildren);
     if (lstMi.isEmpty()) {
         return lstMiPtr;
     }
     lstMiPtr.reserve(lstMi.count());
-    foreach (Core::MessageItem *it, lstMi) {
+    for (Core::MessageItem *it : qAsConst(lstMi)) {
         lstMiPtr.append(d->itemForRow(it->currentModelIndexRow()));
     }
     return lstMiPtr;
@@ -602,26 +587,26 @@ Akonadi::Item::List Widget::selectionAsMessageItemList(bool includeCollapsedChil
 QVector<qlonglong> Widget::selectionAsMessageItemListId(bool includeCollapsedChildren) const
 {
     QVector<qlonglong> lstMiPtr;
-    QList<Core::MessageItem *> lstMi = view()->selectionAsMessageItemList(includeCollapsedChildren);
+    const QVector<Core::MessageItem *> lstMi = view()->selectionAsMessageItemList(includeCollapsedChildren);
     if (lstMi.isEmpty()) {
         return lstMiPtr;
     }
     lstMiPtr.reserve(lstMi.count());
-    foreach (Core::MessageItem *it, lstMi) {
+    for (Core::MessageItem *it : qAsConst(lstMi)) {
         lstMiPtr.append(d->itemForRow(it->currentModelIndexRow()).id());
     }
     return lstMiPtr;
 }
 
-QList<Akonadi::Item::Id> Widget::selectionAsListMessageId(bool includeCollapsedChildren) const
+QVector<Akonadi::Item::Id> Widget::selectionAsListMessageId(bool includeCollapsedChildren) const
 {
-    QList<qlonglong> lstMiPtr;
-    QList<Core::MessageItem *> lstMi = view()->selectionAsMessageItemList(includeCollapsedChildren);
+    QVector<qlonglong> lstMiPtr;
+    const QVector<Core::MessageItem *> lstMi = view()->selectionAsMessageItemList(includeCollapsedChildren);
     if (lstMi.isEmpty()) {
         return lstMiPtr;
     }
     lstMiPtr.reserve(lstMi.count());
-    foreach (Core::MessageItem *it, lstMi) {
+    for (Core::MessageItem *it : qAsConst(lstMi)) {
         lstMiPtr.append(d->itemForRow(it->currentModelIndexRow()).id());
     }
     return lstMiPtr;
@@ -630,12 +615,12 @@ QList<Akonadi::Item::Id> Widget::selectionAsListMessageId(bool includeCollapsedC
 Akonadi::Item::List Widget::currentThreadAsMessageList() const
 {
     Akonadi::Item::List lstMiPtr;
-    QList<Core::MessageItem *> lstMi = view()->currentThreadAsMessageItemList();
+    const QVector<Core::MessageItem *> lstMi = view()->currentThreadAsMessageItemList();
     if (lstMi.isEmpty()) {
         return lstMiPtr;
     }
     lstMiPtr.reserve(lstMi.count());
-    foreach (Core::MessageItem *it, lstMi) {
+    for (Core::MessageItem *it : qAsConst(lstMi)) {
         lstMiPtr.append(d->itemForRow(it->currentModelIndexRow()));
     }
     return lstMiPtr;
@@ -646,7 +631,7 @@ MessageList::Core::QuickSearchLine::SearchOptions Widget::currentOptions() const
     return view()->currentOptions();
 }
 
-QList<Akonadi::MessageStatus> Widget::currentFilterStatus() const
+QVector<Akonadi::MessageStatus> Widget::currentFilterStatus() const
 {
     return view()->currentFilterStatus();
 }
@@ -667,10 +652,7 @@ bool Widget::selectionEmpty() const
 }
 
 bool Widget::getSelectionStats(
-    Akonadi::Item::List &selectedItems,
-    Akonadi::Item::List &selectedVisibleItems,
-    bool *allSelectedBelongToSameThread,
-    bool includeCollapsedChildren) const
+    Akonadi::Item::List &selectedItems, Akonadi::Item::List &selectedVisibleItems, bool *allSelectedBelongToSameThread, bool includeCollapsedChildren) const
 {
     if (!storageModel()) {
         return false;
@@ -679,13 +661,13 @@ bool Widget::getSelectionStats(
     selectedItems.clear();
     selectedVisibleItems.clear();
 
-    QList< Core::MessageItem * > selected = view()->selectionAsMessageItemList(includeCollapsedChildren);
+    const QVector< Core::MessageItem * > selected = view()->selectionAsMessageItemList(includeCollapsedChildren);
 
     Core::MessageItem *topmost = nullptr;
 
     *allSelectedBelongToSameThread = true;
 
-    foreach (Core::MessageItem *it, selected) {
+    for (Core::MessageItem *it : qAsConst(selected)) {
         const Item item = d->itemForRow(it->currentModelIndexRow());
         selectedItems.append(item);
         if (view()->isDisplayedWithParentsExpanded(it)) {
@@ -718,10 +700,10 @@ void Widget::markMessageItemsAsAboutToBeRemoved(MessageList::Core::MessageItemSe
 Akonadi::Item::List Widget::itemListFromPersistentSet(MessageList::Core::MessageItemSetReference ref)
 {
     Akonadi::Item::List lstItem;
-    QList< Core::MessageItem * > refList = view()->persistentSetCurrentMessageItemList(ref);
+    const QList< Core::MessageItem * > refList = view()->persistentSetCurrentMessageItemList(ref);
     if (!refList.isEmpty()) {
         lstItem.reserve(refList.count());
-        foreach (Core::MessageItem *it, refList) {
+        for (Core::MessageItem *it : qAsConst(refList)) {
             lstItem.append(d->itemForRow(it->currentModelIndexRow()));
         }
     }
@@ -730,7 +712,7 @@ Akonadi::Item::List Widget::itemListFromPersistentSet(MessageList::Core::Message
 
 MessageList::Core::MessageItemSetReference Widget::selectionAsPersistentSet(bool includeCollapsedChildren) const
 {
-    QList<Core::MessageItem *> lstMi = view()->selectionAsMessageItemList(includeCollapsedChildren);
+    QVector<Core::MessageItem *> lstMi = view()->selectionAsMessageItemList(includeCollapsedChildren);
     if (lstMi.isEmpty()) {
         return -1;
     }
@@ -739,7 +721,7 @@ MessageList::Core::MessageItemSetReference Widget::selectionAsPersistentSet(bool
 
 MessageList::Core::MessageItemSetReference Widget::currentThreadAsPersistentSet() const
 {
-    QList<Core::MessageItem *> lstMi = view()->currentThreadAsMessageItemList();
+    QVector<Core::MessageItem *> lstMi = view()->currentThreadAsMessageItemList();
     if (lstMi.isEmpty()) {
         return -1;
     }
@@ -764,4 +746,3 @@ void Widget::slotExpandItem()
 {
     view()->setExpandItem(d->mGroupHeaderItemIndex);
 }
-
