@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2019 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef DKIMMANAGER_H
@@ -27,7 +14,6 @@
 #include <AkonadiCore/Item>
 
 namespace MessageViewer {
-class DKIMAuthenticationStatusInfo;
 /**
  * @brief The DKIMManager class
  * @author Laurent Montel <montel@kde.org>
@@ -47,6 +33,7 @@ public:
 
     Q_REQUIRED_RESULT DKIMCheckPolicy policy() const;
     void setPolicy(const DKIMCheckPolicy &policy);
+    void recheckDKim(const Akonadi::Item &item);
 Q_SIGNALS:
     void result(const MessageViewer::DKIMCheckSignatureJob::CheckSignatureResult &checkResult, Akonadi::Item::Id id);
     void clearInfo();
