@@ -1,20 +1,7 @@
 /*
-   Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "headerstyleinterface.h"
@@ -24,6 +11,7 @@
 #include "header/headerstyle.h"
 #include "header/headerstrategy.h"
 #include "messageviewer_debug.h"
+#include "utils/messageviewerutil_p.h"
 #include "messageviewer/messageviewersettings.h"
 
 #include <KActionMenu>
@@ -43,23 +31,13 @@ public:
     void readSettings();
     void writeSettings(const QString &pluginName);
     void initialize(KActionCollection *ac);
-    void addHelpTextAction(QAction *act, const QString &text);
     void setPluginName(const QString &pluginName);
     QHash<QString, MessageViewer::HeaderStyleInterface *> lstInterface;
     QActionGroup *group = nullptr;
     KActionMenu *headerMenu = nullptr;
-    HeaderStyleMenuManager *q = nullptr;
+    HeaderStyleMenuManager *const q = nullptr;
 };
 
-void HeaderStyleMenuManagerPrivate::addHelpTextAction(QAction *act, const QString &text)
-{
-    act->setStatusTip(text);
-    act->setToolTip(text);
-    if (act->whatsThis().isEmpty()) {
-        act->setWhatsThis(text);
-    }
-}
-
 void HeaderStyleMenuManagerPrivate::setPluginName(const QString &pluginName)
 {
     MessageViewer::HeaderStyleInterface *interface = lstInterface.value(pluginName);
@@ -138,7 +116,7 @@ void HeaderStyleMenuManagerPrivate::initialize(KActionCollection *ac)
     if (ac) {
         ac->addAction(QStringLiteral("view_headers"), headerMenu);
     }
-    addHelpTextAction(headerMenu, i18n("Choose display style of message headers"));
+    MessageViewer::Util::addHelpTextAction(headerMenu, i18n("Choose display style of message headers"));
     group = new QActionGroup(q);
 
     const QVector<MessageViewer::HeaderStylePlugin *> lstPlugin
