@@ -5,29 +5,16 @@
   Copyright (c) James Ashton - Sydney University - June 1990. //krazy:exclude=copyright
 
   Additions for KDE:
-  Copyright (c) 2004 Jakob Schröter <js@camaya.net>
+  SPDX-FileCopyrightText: 2004 Jakob Schröter <js@camaya.net>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kxface.h"
 
 #include <QBuffer>
 #include <QImage>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QString>
 
 #include <stdlib.h>
@@ -150,8 +137,8 @@ QString KXFace::fromImage(const QImage &image)
             tmp[i - 1] = t;
         }
     }
-    tmp.replace(QRegExp(QLatin1String("(\\w{12})")), QStringLiteral("\\1\n"));
-    tmp.replace(QRegExp(QLatin1String("(\\w{4})")), QStringLiteral("0x\\1,"));
+    tmp.replace(QRegularExpression(QStringLiteral("(\\w{12})")), QStringLiteral("\\1\n"));
+    tmp.replace(QRegularExpression(QStringLiteral("(\\w{4})")), QStringLiteral("0x\\1,"));
     len = tmp.length();
     char *fbuf = (char *)malloc(len + 1);
     strncpy(fbuf, tmp.toLatin1().constData(), len);
