@@ -5,22 +5,9 @@
   Copyright (c) James Ashton - Sydney University - June 1990. //krazy:exclude=copyright
 
   Additions for KDE:
-  Copyright (c) 2004 Jakob Schröter <js@camaya.net>
+  SPDX-FileCopyrightText: 2004 Jakob Schröter <js@camaya.net>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef MESSAGEVIEWER_KXFACE_H
@@ -556,13 +543,13 @@ private:
 
     void RevPush(const Prob *p);
     void BigPush(Prob *p);
-    int  BigPop(const Prob *p);
+    Q_REQUIRED_RESULT int  BigPop(const Prob *p);
     void BigDiv(unsigned char a, unsigned char *r);
     void BigMul(unsigned char a);
     void BigAdd(unsigned char a);
     void BigClear();
 
-    QByteArray WriteFace();
+    Q_REQUIRED_RESULT QByteArray WriteFace();
     void UnCompAll(char *fbuf);
     void UnCompress(char *f, int wid, int hei, int lev);
     void BigWrite(char *fbuf);
@@ -574,9 +561,9 @@ private:
     void PopGreys(char *f, int wid, int hei);
     void CompAll(char *fbuf);
     void Compress(char *f, int wid, int hei, int lev);
-    int  AllWhite(char *f, int wid, int hei);
-    int  AllBlack(char *f, int wid, int hei);
-    int  Same(char *f, int wid, int hei);
+    Q_REQUIRED_RESULT int  AllWhite(char *f, int wid, int hei);
+    Q_REQUIRED_RESULT int  AllBlack(char *f, int wid, int hei);
+    Q_REQUIRED_RESULT int  Same(char *f, int wid, int hei);
     void PushGreys(char *f, int wid, int hei);
 };
 }
