@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2016-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef WEBENGINEPARTHTMLWRITER_H
 #define WEBENGINEPARTHTMLWRITER_H
@@ -23,7 +11,7 @@
 
 #include <QString>
 #include <QByteArray>
-
+class QTemporaryFile;
 namespace MessageViewer {
 class MailWebEngineView;
 }
@@ -40,22 +28,27 @@ public:
     void end() override;
     void reset() override;
     void embedPart(const QByteArray &contentId, const QString &url) override;
-    void extraHead(const QString &str) override;
+    void setExtraHead(const QString &str) override;
+
+    void setStyleBody(const QString &styleBody) override;
 
 Q_SIGNALS:
     void finished();
 
 private:
     void insertExtraHead();
+    void insertBodyStyle();
 
 private:
     MailWebEngineView *mHtmlView = nullptr;
     QString mExtraHead;
+    QString mStyleBody;
     enum State {
         Begun,
         Queued,
         Ended
-    } mState;
+    } mState = Ended;
+    QTemporaryFile *mTempFile = nullptr;
 };
 }
 #endif // WEBENGINEPARTHTMLWRITER_H
