@@ -1,21 +1,8 @@
 /*
-  Copyright (c) 2010 Volker Krause <vkrause@kde.org>
-  Copyright (c) 2016 Sandro Knauß <sknauss@kde.org>
+  SPDX-FileCopyrightText: 2010 Volker Krause <vkrause@kde.org>
+  SPDX-FileCopyrightText: 2016 Sandro Knauß <sknauss@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "rendertest.h"
@@ -39,6 +26,7 @@ void RenderTest::initTestCase()
 {
     Test::setupEnv();
 }
+
 #ifndef Q_OS_WIN
 void initLocale()
 {
@@ -268,7 +256,8 @@ QString renderTreeHelper(const MimeTreeParser::MessagePart::Ptr &messagePart, QS
     QString ret = line;
 
     indent += QLatin1Char(' ');
-    foreach (const auto &subPart, messagePart->subParts()) {
+    const auto subParts = messagePart->subParts();
+    for (const auto &subPart : subParts) {
         ret += renderTreeHelper(subPart, indent);
     }
     return ret;
@@ -312,11 +301,11 @@ void RenderTest::testRender()
     QFETCH(bool, showSignatureDetails);
     QFETCH(QString, asyncFileName);
 
-    const QString htmlFileName = outFileName + QStringLiteral(".html");
+    //const QString htmlFileName = outFileName + QStringLiteral(".html");
     const bool bAsync = !asyncFileName.isEmpty();
 
     // load input mail
-    const KMime::Message::Ptr msg(Test::readAndParseMail(mailFileName));
+    KMime::Message::Ptr msg(Test::readAndParseMail(mailFileName));
 
     // render the mail
     FileHtmlWriter fileWriter(outFileName);
@@ -361,6 +350,7 @@ void RenderTest::testRender()
         testRenderTree(otp.parsedPart());
     }
     Test::compareFile(outFileName, referenceFileName);
+    msg.clear();
 }
 
 QTEST_MAIN(RenderTest)
