@@ -1,20 +1,7 @@
 /*
-   Copyright (c) 2016 Sandro Knauß <sknauss@kde.org>
+   SPDX-FileCopyrightText: 2016 Sandro Knauß <sknauss@kde.org>
 
-   This library is free software; you can redistribute it and/or modify it
-   under the terms of the GNU Library General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or (at your
-   option) any later version.
-
-   This library is distributed in the hope that it will be useful, but WITHOUT
-   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-   License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to the
-   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-   02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "defaultrenderer.h"
@@ -46,7 +33,6 @@
 #include <KEmailAddress>
 #include <KIconLoader>
 #include <KLocalizedString>
-#include <QRegularExpression>
 
 #include <QUrl>
 
@@ -56,8 +42,6 @@
 #include <grantlee/templateloader.h>
 #include <grantlee/template.h>
 
-#include <qtwebenginewidgetsversion.h>
-
 using namespace MimeTreeParser;
 using namespace MessageViewer;
 
@@ -242,44 +226,6 @@ QString sigStatusToString(const QGpgME::Protocol *cryptProto, int status_code, G
     return result;
 }
 
-// FIXME this used to go through the full webkit parser to extract the body and head blocks
-// until we have that back, at least attempt to fix some of the damage
-// yes, "parsing" HTML with regexps is very very wrong, but it's still better than not filtering
-// this at all...
-QString processHtml(const QString &htmlSource, QString &extraHead)
-{
-    QString s = htmlSource.trimmed();
-    s = s.remove(QRegExp(QStringLiteral("^<!DOCTYPE[^>]*>"), Qt::CaseInsensitive)).trimmed();
-    s = s.remove(QRegExp(QStringLiteral("^<html[^>]*>"), Qt::CaseInsensitive)).trimmed();
-
-    // head
-    s = s.remove(QRegExp(QStringLiteral("^<head/>"), Qt::CaseInsensitive)).trimmed();
-    const int startIndex = s.indexOf(QLatin1String("<head>"), Qt::CaseInsensitive);
-    if (startIndex >= 0) {
-        const auto endIndex = s.indexOf(QLatin1String("</head>"), Qt::CaseInsensitive);
-
-        if (endIndex < 0) {
-            return htmlSource;
-        }
-        extraHead = s.mid(startIndex + 6, endIndex - startIndex - 6);
-#if QTWEBENGINEWIDGETS_VERSION < QT_VERSION_CHECK(5, 13, 0)
-        //Remove this hack with https://codereview.qt-project.org/#/c/256100/2 is merged
-        //Don't authorize to refresh content.
-        if (MessageViewer::Util::excludeExtraHeader(s)) {
-            extraHead.clear();
-        }
-#endif
-
-        s = s.mid(endIndex + 7).trimmed();
-    }
-
-    // body
-    s = s.remove(QRegExp(QStringLiteral("<body[^>]*>"), Qt::CaseInsensitive)).trimmed();
-    s = s.remove(QRegExp(QStringLiteral("</html>$"), Qt::CaseInsensitive)).trimmed();
-    s = s.remove(QRegExp(QStringLiteral("</body>$"), Qt::CaseInsensitive)).trimmed();
-    return s;
-}
-
 DefaultRendererPrivate::DefaultRendererPrivate(CSSHelperBase *cssHelper, const MessagePartRendererFactory *rendererFactory)
     : mCSSHelper(cssHelper)
     , mRendererFactory(rendererFactory)
@@ -378,18 +324,18 @@ void DefaultRendererPrivate::render(const HtmlMessagePart::Ptr &mp, HtmlWriter *
     block.setProperty("loadExternal", htmlLoadExternal());
     block.setProperty("isPrinting", isPrinting());
     {
-        QString extraHead;
         //laurent: FIXME port to async method webengine
-        QString bodyText = processHtml(mp->bodyHtml(), extraHead);
+        Util::HtmlMessageInfo messageInfo = Util::processHtml(mp->bodyHtml());
 
         if (isHtmlPreferred) {
             mp->nodeHelper()->setNodeDisplayedEmbedded(mp->content(), true);
-            htmlWriter->extraHead(extraHead);
+            htmlWriter->setExtraHead(messageInfo.extraHead);
+            htmlWriter->setStyleBody(Util::parseBodyStyle(messageInfo.bodyStyle));
         }
 
         block.setProperty("containsExternalReferences",
-                          Util::containsExternalReferences(bodyText, extraHead));
-        c.insert(QStringLiteral("content"), bodyText);
+                          Util::containsExternalReferences(messageInfo.htmlSource, messageInfo.extraHead));
+        c.insert(QStringLiteral("content"), messageInfo.htmlSource);
     }
 
     {
@@ -822,7 +768,7 @@ void DefaultRendererPrivate::renderFactory(const MessagePart::Ptr &msgPart, Html
     const QString className = QString::fromUtf8(msgPart->metaObject()->className());
 
     if (isHiddenHint(msgPart)) {
-        QByteArray cid = msgPart->content()->contentID()->identifier();
+        const QByteArray cid = msgPart->content()->contentID()->identifier();
         auto mp = msgPart.dynamicCast<MimeTreeParser::TextMessagePart>();
         if (!cid.isEmpty() && mp) {
             QString fileName = mp->temporaryFilePath();
@@ -906,9 +852,9 @@ bool DefaultRendererPrivate::isHiddenHint(const MimeTreeParser::MessagePart::Ptr
     bool isHtmlPreferred = (preferredMode == MimeTreeParser::Util::Html) || (preferredMode == MimeTreeParser::Util::MultipartHtml);
 
     QByteArray mediaType("text");
-    if (content->contentType(false) && !content->contentType()->mediaType().isEmpty()
-        && !content->contentType()->subType().isEmpty()) {
-        mediaType = content->contentType()->mediaType();
+    if (content->contentType(false) && !content->contentType(false)->mediaType().isEmpty()
+        && !content->contentType(false)->subType().isEmpty()) {
+        mediaType = content->contentType(false)->mediaType();
     }
     const bool isTextPart = (mediaType == QByteArrayLiteral("text"));
 
@@ -958,9 +904,9 @@ MimeTreeParser::IconType DefaultRendererPrivate::displayHint(const MimeTreeParse
     bool isHtmlPreferred = (preferredMode == MimeTreeParser::Util::Html) || (preferredMode == MimeTreeParser::Util::MultipartHtml);
 
     QByteArray mediaType("text");
-    if (content->contentType(false) && !content->contentType()->mediaType().isEmpty()
-        && !content->contentType()->subType().isEmpty()) {
-        mediaType = content->contentType()->mediaType();
+    if (content->contentType(false) && !content->contentType(false)->mediaType().isEmpty()
+        && !content->contentType(false)->subType().isEmpty()) {
+        mediaType = content->contentType(false)->mediaType();
     }
     const bool isTextPart = (mediaType == QByteArrayLiteral("text"));
 
