@@ -1,24 +1,10 @@
 /*
-   Copyright (c) 2015 Sandro Knauß <sknauss@kde.org>
+   SPDX-FileCopyrightText: 2015 Sandro Knauß <sknauss@kde.org>
 
-   This library is free software; you can redistribute it and/or modify it
-   under the terms of the GNU Library General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or (at your
-   option) any later version.
-
-   This library is distributed in the hope that it will be useful, but WITHOUT
-   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-   License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to the
-   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-   02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "htmlblock.h"
-#include "mimetreeparser_debug.h"
 
 #include "interfaces/htmlwriter.h"
 
@@ -26,10 +12,9 @@
 
 #include <QApplication>
 
-using namespace MimeTreeParser;
+using namespace MessageViewer;
 
 HTMLBlock::HTMLBlock()
-    : entered(false)
 {
 }
 
@@ -60,7 +45,7 @@ QString HTMLBlock::exit()
     return QString();
 }
 
-AttachmentMarkBlock::AttachmentMarkBlock(MimeTreeParser::HtmlWriter *writer, KMime::Content *node)
+AttachmentMarkBlock::AttachmentMarkBlock(HtmlWriter *writer, KMime::Content *node)
     : mNode(node)
     , mWriter(writer)
 {
