@@ -1,20 +1,7 @@
 /*
-   Copyright (c) 2017 Volker Krause <vkrause@kde.org>
+   SPDX-FileCopyrightText: 2017 Volker Krause <vkrause@kde.org>
 
-   This library is free software; you can redistribute it and/or modify it
-   under the terms of the GNU Library General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or (at your
-   option) any later version.
-
-   This library is distributed in the hope that it will be useful, but WITHOUT
-   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-   License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to the
-   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-   02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "grantleeextension.h"
@@ -40,7 +27,11 @@ void CallbackTag::render(Grantlee::OutputStream *stream, Grantlee::Context *cont
 
 Grantlee::Node *CallbackTagFactory::getNode(const QString &tagContent, Grantlee::Parser *parser) const
 {
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     auto expr = tagContent.split(QLatin1Char(' '), QString::SkipEmptyParts);
+#else
+    auto expr = tagContent.split(QLatin1Char(' '), Qt::SkipEmptyParts);
+#endif
     if (expr.size() != 2) {
         return nullptr;
     }
