@@ -2,32 +2,9 @@
     csshelper.cpp
 
     This file is part of KMail, the KDE mail client.
-    Copyright (c) 2003 Marc Mutz <mutz@kde.org>
+    SPDX-FileCopyrightText: 2003 Marc Mutz <mutz@kde.org>
 
-    KMail is free software; you can redistribute it and/or modify it
-    under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    KMail is distributed in the hope that it will be useful, but
-    WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License along
-    with this program; if not, write to the Free Software Foundation, Inc.,
-    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "csshelperbase.h"
@@ -38,6 +15,7 @@
 #include <QPaintDevice>
 #include <QPalette>
 #include <QUrl>
+
 #define USE_HTML_STYLE_COLOR 1
 namespace MessageViewer {
 namespace {
@@ -82,9 +60,7 @@ static const struct {
 }
 
 CSSHelperBase::CSSHelperBase(const QPaintDevice *pd)
-    : mRecycleQuoteColors(false)
-    , mShrinkQuotes(false)
-    , mPaintDevice(pd)
+    : mPaintDevice(pd)
 {
     recalculatePGPColors();
     const QString imgSrcShow = QStringLiteral("quicklistClosed.png");
@@ -413,7 +389,7 @@ QString CSSHelperBase::quoteCssDefinition() const
                                    "  margin: 4pt 0 4pt 0;\n"
                                    "  padding: 0 0 0 1em;\n"
                                    "  border-left: 2px solid %1;\n"
-                                   "  unicode-bidi: -webkit-plaintext\n"
+                                   "  unicode-bidi: plaintext\n"
                                    "}\n\n").arg(quoteColorName(i), blockQuote);
     }
     quoteCSS += QStringLiteral(".quotemarks{\n"
@@ -442,7 +418,7 @@ QString CSSHelperBase::defaultScreenHeaderFont() const
     const QString headerFont = QStringLiteral("  font-family: \"%1\" ! important;\n"
                                               "  font-size: %2px ! important;\n")
                                .arg(mBodyFont.family())
-                               .arg(pointsToPixel(this->mPaintDevice, mBodyFont.pointSize()));
+                               .arg(pointsToPixel(mPaintDevice, mBodyFont.pointSize()));
     return headerFont;
 }
 
@@ -752,6 +728,7 @@ QString CSSHelperBase::commonCssDefinitions() const
                        "  padding: 10px ! important;\n"
                        "  text-align: left ! important;\n"
                        "  line-height: normal;\n"
+                       "  min-height: %6px;\n"
                        "}\n\n"
 
                        "hr {\n"
@@ -764,7 +741,7 @@ QString CSSHelperBase::commonCssDefinitions() const
                        "  position: absolute;\n"
                        "  margin-left:-10px;\n"
                        "}\n\n").arg(extraCommonCss(headerFont), inlineMessageCss.join(QLatin1String(", ")))
-        .arg(mForegroundColor.red()).arg(mForegroundColor.green()).arg(mForegroundColor.blue());
+        .arg(mForegroundColor.red()).arg(mForegroundColor.green()).arg(mForegroundColor.blue()).arg(QString::number(48));
 }
 
 void CSSHelperBase::setBodyFont(const QFont &font)
