@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2014-2019 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "mimeparttreeview.h"
@@ -91,7 +78,7 @@ KMime::Content::List MimePartTreeView::selectedContents() const
     KMime::Content::List contents;
     QItemSelectionModel *selectModel = selectionModel();
     const QModelIndexList selectedRows = selectModel->selectedRows();
-
+    contents.reserve(selectedRows.count());
     for (const QModelIndex &index : selectedRows) {
         KMime::Content *content = static_cast<KMime::Content *>(index.internalPointer());
         if (content) {
