@@ -1,20 +1,8 @@
 /*
-  Copyright (C) 2009 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-  Copyright (c) 2009 Andras Mantia <andras@kdab.net>
+  SPDX-FileCopyrightText: 2009 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
+  SPDX-FileCopyrightText: 2009 Andras Mantia <andras@kdab.net>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "objecttreeviewersource.h"
@@ -102,7 +90,7 @@ const QTextCodec *MailViewerSource::overrideCodec()
 
 QString MailViewerSource::createMessageHeader(KMime::Message *message)
 {
-    return mViewer->writeMessageHeader(message);
+    return mViewer->writeMessageHeader(message, nullptr, false);
 }
 
 const AttachmentStrategy *MailViewerSource::attachmentStrategy() const
