@@ -1,22 +1,10 @@
 /*
   This file is part of KMail, the KDE mail client.
-  Copyright (c) 1997 Markus Wuebben <markus.wuebben@kde.org>
-  Copyright (C) 2009 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-  Copyright (c) 2009 Andras Mantia <andras@kdab.net>
+  SPDX-FileCopyrightText: 1997 Markus Wuebben <markus.wuebben@kde.org>
+  SPDX-FileCopyrightText: 2009 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
+  SPDX-FileCopyrightText: 2009 Andras Mantia <andras@kdab.net>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef MESSAGEVIEWER_H
@@ -52,9 +40,8 @@ class WebHitTestResult;
 
 namespace MessageViewer {
 class WebHitTestResult;
-#ifdef USE_DKIM_CHECKER
 class DKIMWidgetInfo;
-#endif
+class DKIMViewerMenu;
 class AttachmentStrategy;
 class HeaderStylePlugin;
 class CSSHelper;
@@ -90,8 +77,6 @@ private:
     Private *const d;
 };
 
-//TODO(Andras) once only those methods are public that really need to be public, probably export the whole class instead of just some methods
-
 /**
  * This is the main widget for the viewer.
  * See the documentation of ViewerPrivate for implementation details.
@@ -284,9 +269,15 @@ public:
     Q_REQUIRED_RESULT QAction *saveAsAction() const;
     Q_REQUIRED_RESULT QAction *saveMessageDisplayFormatAction() const;
     Q_REQUIRED_RESULT QAction *resetMessageDisplayFormatAction() const;
+    Q_REQUIRED_RESULT QAction *shareTextAction() const;
+
+
+    Q_REQUIRED_RESULT QAction *developmentToolsAction() const;
     Q_REQUIRED_RESULT KToggleAction *disableEmoticonAction() const;
     Q_REQUIRED_RESULT KActionMenu *shareServiceUrlMenu() const;
     Q_REQUIRED_RESULT HeaderStylePlugin *headerStylePlugin() const;
+    Q_REQUIRED_RESULT MessageViewer::DKIMViewerMenu *dkimViewerMenu();
+
     void setPluginName(const QString &pluginName);
 
     void writeConfig(bool withSync = true);
@@ -319,7 +310,7 @@ public:
     */
     void removeMessageLoadedHandler(AbstractMessageLoadedHandler *handler);
 
-    QString selectedText() const;
+    Q_REQUIRED_RESULT QString selectedText() const;
 
     void setExternalWindow(bool b);
 
@@ -327,14 +318,14 @@ public:
     bool mimePartTreeIsEmpty() const;
 
     void showOpenAttachmentFolderWidget(const QList<QUrl> &urls);
-    QList<QAction *> viewerPluginActionList(
+    Q_REQUIRED_RESULT QList<QAction *> viewerPluginActionList(
         MessageViewer::ViewerPluginInterface::SpecificFeatureTypes features);
-    QList<QAction *> interceptorUrlActions(const WebEngineViewer::WebHitTestResult &result) const;
+    Q_REQUIRED_RESULT QList<QAction *> interceptorUrlActions(const WebEngineViewer::WebHitTestResult &result) const;
 
     void runJavaScript(const QString &code);
     void setPrintElementBackground(bool printElementBackground);
 
-    bool printingMode() const;
+    Q_REQUIRED_RESULT bool printingMode() const;
 
     Q_REQUIRED_RESULT bool showSignatureDetails() const;
     void setShowSignatureDetails(bool showDetails);
@@ -347,10 +338,11 @@ public:
 
     void hasMultiMessages(bool messages);
     void updateShowMultiMessagesButton(bool enablePreviousButton, bool enableNextButton);
-#ifdef USE_DKIM_CHECKER
-    MessageViewer::DKIMWidgetInfo *dkimWidgetInfo();
-#endif
+    Q_REQUIRED_RESULT MessageViewer::DKIMWidgetInfo *dkimWidgetInfo();
 
+    void exportToPdf(const QString &fileName);
+
+    void showDevelopmentTools();
 Q_SIGNALS:
     void moveMessageToTrash();
     void pageIsScrolledToBottom(bool);
@@ -422,7 +414,7 @@ protected:
     void closeEvent(QCloseEvent *) override;
     void resizeEvent(QResizeEvent *) override;
     /** Watch for palette changes */
-    bool event(QEvent *e) override;
+    Q_REQUIRED_RESULT bool event(QEvent *e) override;
     void changeEvent(QEvent *event) override;
 
     ViewerPrivate *const d_ptr;
