@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "mailwebengineview.h"
 #include "mailwebenginepage.h"
@@ -26,6 +13,7 @@
 #include "blockexternalresourcesurlinterceptor/blockexternalresourcesurlinterceptor.h"
 #include "blockmailtrackingurlinterceptor/blockmailtrackingurlinterceptor.h"
 #include "cidreferencesurlinterceptor/cidreferencesurlinterceptor.h"
+#include "cidschemehandler/cidschemehandler.h"
 #include <WebEngineViewer/InterceptorManager>
 #include <WebEngineViewer/WebEngineManageScript>
 
@@ -33,8 +21,10 @@
 #include "scamdetection/scamcheckshorturl.h"
 #include <QContextMenuEvent>
 #include <WebEngineViewer/WebHitTest>
+#include <QWebEngineProfile>
 
 #include <QPrinter>
+#include <QWebEngineUrlScheme>
 
 #include <WebEngineViewer/WebHitTestResult>
 
@@ -91,6 +81,8 @@ MailWebEngineView::MailWebEngineView(KActionCollection *ac, QWidget *parent)
             &MailWebEngineView::openUrl);
     connect(this, &MailWebEngineView::loadFinished, this, &MailWebEngineView::slotLoadFinished);
 
+    d->mPageEngine->profile()->installUrlSchemeHandler(QByteArrayLiteral("cid"), new CidSchemeHandler(this));
+
     d->mNetworkAccessManager = new WebEngineViewer::InterceptorManager(this, ac, this);
     d->mExternalReference = new MessageViewer::LoadExternalReferencesUrlInterceptor(this);
     d->mNetworkAccessManager->addInterceptor(d->mExternalReference);
@@ -382,3 +374,12 @@ bool MailWebEngineView::execPrintPreviewPage(QPrinter *printer, int timeout)
 {
     return d->mPageEngine->execPrintPreviewPage(printer, timeout);
 }
+
+
+void MailWebEngineView::initializeCustomScheme()
+{
+    QWebEngineUrlScheme cidScheme("cid");
+    cidScheme.setFlags(QWebEngineUrlScheme::SecureScheme | QWebEngineUrlScheme::ContentSecurityPolicyIgnored);
+    cidScheme.setSyntax(QWebEngineUrlScheme::Syntax::Path);
+    QWebEngineUrlScheme::registerScheme(cidScheme);
+}
