@@ -1,23 +1,11 @@
 /*
-   Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "viewerplugininterface.h"
+#include "utils/messageviewerutil_p.h"
 #include <QAction>
 using namespace MessageViewer;
 
@@ -105,11 +93,7 @@ void ViewerPluginInterface::refreshActionList(KActionCollection *ac)
 
 void ViewerPluginInterface::addHelpTextAction(QAction *act, const QString &text)
 {
-    act->setStatusTip(text);
-    act->setToolTip(text);
-    if (act->whatsThis().isEmpty()) {
-        act->setWhatsThis(text);
-    }
+    MessageViewer::Util::addHelpTextAction(act, text);
 }
 
 void ViewerPluginInterface::slotActivatePlugin()
