@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "viewerplugintoolmanager.h"
@@ -35,10 +22,9 @@ public:
     {
     }
 
-    void setServiceTypeName(const QString &serviceName);
-    QString serviceTypeName() const;
     void setPluginName(const QString &pluginName);
-    QString pluginName() const;
+    Q_REQUIRED_RESULT QString pluginDirectory() const;
+    Q_REQUIRED_RESULT QString pluginName() const;
     void createView();
     void refreshActionList();
     void closeAllTools();
@@ -48,17 +34,18 @@ public:
     QList<MessageViewer::ViewerPluginInterface *> mListInterface;
     KActionCollection *mActionCollection = nullptr;
     QWidget *mParentWidget = nullptr;
-    ViewerPluginToolManager *q = nullptr;
+    ViewerPluginToolManager *const q = nullptr;
+    void setPluginDirectory(const QString &directory);
 };
 
-void ViewerPluginToolManagerPrivate::setServiceTypeName(const QString &serviceName)
+void ViewerPluginToolManagerPrivate::setPluginDirectory(const QString &directory)
 {
-    MessageViewer::ViewerPluginManager::self()->setServiceTypeName(serviceName);
+    MessageViewer::ViewerPluginManager::self()->setPluginDirectory(directory);
 }
 
-QString ViewerPluginToolManagerPrivate::serviceTypeName() const
+QString ViewerPluginToolManagerPrivate::pluginDirectory() const
 {
-    return MessageViewer::ViewerPluginManager::self()->serviceTypeName();
+    return MessageViewer::ViewerPluginManager::self()->pluginDirectory();
 }
 
 void ViewerPluginToolManagerPrivate::setPluginName(const QString &pluginName)
@@ -161,14 +148,14 @@ void ViewerPluginToolManager::setActionCollection(KActionCollection *ac)
     d->setActionCollection(ac);
 }
 
-void ViewerPluginToolManager::setServiceTypeName(const QString &serviceName)
+void ViewerPluginToolManager::setPluginDirectory(const QString &directory)
 {
-    d->setServiceTypeName(serviceName);
+    d->setPluginDirectory(directory);
 }
 
-QString ViewerPluginToolManager::serviceTypeName() const
+QString ViewerPluginToolManager::pluginDirectory() const
 {
-    return d->serviceTypeName();
+    return d->pluginDirectory();
 }
 
 void ViewerPluginToolManager::setPluginName(const QString &pluginName)
