@@ -1,20 +1,6 @@
-/* Copyright 2015 Sandro Knauß <bugs@sandroknauss.de>
+/* SPDX-FileCopyrightText: 2015 Sandro Knauß <bugs@sandroknauss.de>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 #include "nodehelpertest.h"
 
@@ -37,11 +23,13 @@ void NodeHelperTest::testPersistentIndex()
     KMime::Content *node2 = new KMime::Content();
     KMime::Content *node2Extra = new KMime::Content();
     KMime::Content *subNode = new KMime::Content();
-    KMime::Content *subsubNode = new KMime::Content(), *subsubNode2 = new KMime::Content();
+    KMime::Content *subsubNode = new KMime::Content();
+    KMime::Content *subsubNode2 = new KMime::Content();
     KMime::Content *node2ExtraSubNode = new KMime::Content();
     KMime::Content *node2ExtraSubsubNode = new KMime::Content();
     KMime::Content *node2ExtraSubsubNode2 = new KMime::Content();
-    KMime::Content *extra = new KMime::Content(), *extra2 = new KMime::Content();
+    KMime::Content *extra = new KMime::Content();
+    KMime::Content *extra2 = new KMime::Content();
     KMime::Content *subExtra = new KMime::Content();
     KMime::Content *subsubExtra = new KMime::Content();
     KMime::Content *subsubExtraNode = new KMime::Content();
@@ -121,6 +109,8 @@ void NodeHelperTest::testPersistentIndex()
     QCOMPARE(helper.persistentIndex(node2ExtraSubsubNode2), QStringLiteral("e0:2.3"));
     QCOMPARE(helper.contentFromIndex(node2, QStringLiteral("e0:2.3")), node2ExtraSubsubNode2);
 
+    helper.clear();
+    delete node2;
     delete node;
 }
 
@@ -270,4 +260,23 @@ void NodeHelperTest::testFromAsString()
     QCOMPARE(helper.fromAsString(encSubExtra), encSender);
 }
 
+void NodeHelperTest::shouldTestExtractAttachmentIndex_data()
+{
+    QTest::addColumn<QString>("path");
+    QTest::addColumn<QString>("extractedPath");
+    QTest::newRow("empty") << QString() << QString();
+    QTest::newRow("test1") << QStringLiteral("/bla/qttestn28554.index.2.3:0:2/unnamed") << QStringLiteral("2.3:0:2");
+    QTest::newRow("test2") << QStringLiteral("/bla/qttestn28554.dd.2.3:0:2/unnamed") << QStringLiteral("2.3:0:2");
+    QTest::newRow("test3") << QStringLiteral("/bla/qttestn28554.dd.2.3:0/unnamed") << QStringLiteral("2.3:0");
+    QTest::newRow("test4") << QStringLiteral("/bla/qttestn28554.dd.2.3:0:2:4/unnamed") << QStringLiteral("2.3:0:2:4");
+}
+
+void NodeHelperTest::shouldTestExtractAttachmentIndex()
+{
+    QFETCH(QString, path);
+    QFETCH(QString, extractedPath);
+    NodeHelper helper;
+    QCOMPARE(extractedPath, helper.extractAttachmentIndex(path));
+}
+
 QTEST_GUILESS_MAIN(NodeHelperTest)
