@@ -1,25 +1,18 @@
 /*
     cryptohelper.h
 
-    Copyright (C) 2015 Sandro Knauß <knauss@kolabsys.com>
-    Copyright (C) 2001,2002 the KPGP authors
+    SPDX-FileCopyrightText: 2015 Sandro Knauß <knauss@kolabsys.com>
+    SPDX-FileCopyrightText: 2001,2002 the KPGP authors
     See file AUTHORS.kpgp for details
 
-    KMail is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software Foundation,
-    Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+    SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef __MIMETREEPARSER_CRYPTOHELPER_H__
-#define __MIMETREEPARSER_CRYPTOHELPER_H__
+#ifndef MIMETREEPARSER_CRYPTOHELPER_H
+#define MIMETREEPARSER_CRYPTOHELPER_H
 
 #include <QByteArray>
-#include <QList>
+#include <QVector>
 
 namespace MimeTreeParser {
 enum PGPBlockType {
@@ -36,22 +29,23 @@ enum PGPBlockType {
 class Block
 {
 public:
+    Block();
     Block(const QByteArray &m);
 
     Block(const QByteArray &m, PGPBlockType t);
 
-    QByteArray text() const;
-    PGPBlockType type() const;
-    PGPBlockType determineType() const;
+    Q_REQUIRED_RESULT QByteArray text() const;
+    Q_REQUIRED_RESULT PGPBlockType type() const;
+    Q_REQUIRED_RESULT PGPBlockType determineType() const;
 
     QByteArray msg;
-    PGPBlockType mType;
+    PGPBlockType mType = UnknownBlock;
 };
 
 /** Parses the given message and splits it into OpenPGP blocks and
     Non-OpenPGP blocks.
 */
-QList<Block> prepareMessageForDecryption(const QByteArray &msg);
+QVector<Block> prepareMessageForDecryption(const QByteArray &msg);
 } // namespace MimeTreeParser
 
 Q_DECLARE_TYPEINFO(MimeTreeParser::Block, Q_MOVABLE_TYPE);
