@@ -1,20 +1,8 @@
 /*
-  Copyright (C) 2009 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-  Copyright (c) 2009 Andras Mantia <andras@kdab.net>
+  SPDX-FileCopyrightText: 2009 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
+  SPDX-FileCopyrightText: 2009 Andras Mantia <andras@kdab.net>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "nodehelper.h"
@@ -30,16 +18,16 @@
 
 #include <QTemporaryFile>
 #include <KLocalizedString>
-#include <kcharsets.h>
+#include <KCharsets>
 
 #include <QUrl>
 #include <QDir>
 #include <QTextCodec>
+#include <QRegularExpressionMatch>
 
 #include <string>
 #include <sstream>
 #include <algorithm>
-#include <KCharsets>
 #include <QMimeDatabase>
 #include <QMimeType>
 #include <QFileDevice>
@@ -48,6 +36,7 @@ namespace MimeTreeParser {
 NodeHelper::NodeHelper()
     : mAttachmentFilesDir(new AttachmentTemporaryFilesDirs())
 {
+    mListAttachmentTemporaryDirs.append(mAttachmentFilesDir);
     //TODO(Andras) add methods to modify these prefixes
 
     mLocalCodec = QTextCodec::codecForLocale();
@@ -77,10 +66,11 @@ NodeHelper::NodeHelper()
 
 NodeHelper::~NodeHelper()
 {
-    if (mAttachmentFilesDir) {
-        mAttachmentFilesDir->forceCleanTempFiles();
-        delete mAttachmentFilesDir;
-        mAttachmentFilesDir = nullptr;
+    for (auto att : mListAttachmentTemporaryDirs) {
+        if (att) {
+            att->forceCleanTempFiles();
+            delete att;
+        }
     }
     clear();
 }
@@ -109,7 +99,7 @@ void NodeHelper::setNodeUnprocessed(KMime::Content *node, bool recurse)
     mProcessedNodes.removeAll(node);
 
     //avoid double addition of extra nodes, eg. encrypted attachments
-    const QMap<KMime::Content *, QList<KMime::Content *> >::iterator it = mExtraContents.find(node);
+    const QMap<KMime::Content *, QVector<KMime::Content *> >::iterator it = mExtraContents.find(node);
     if (it != mExtraContents.end()) {
         Q_FOREACH (KMime::Content *c, it.value()) {
             KMime::Content *p = c->parent();
@@ -160,9 +150,9 @@ void NodeHelper::clear()
     std::for_each(mBodyPartMementoMap.begin(), mBodyPartMementoMap.end(),
                   &clearBodyPartMemento);
     mBodyPartMementoMap.clear();
-    QMap<KMime::Content *, QList<KMime::Content *> >::ConstIterator end(mExtraContents.constEnd());
+    QMap<KMime::Content *, QVector<KMime::Content *> >::ConstIterator end(mExtraContents.constEnd());
 
-    for (QMap<KMime::Content *, QList<KMime::Content *> >::ConstIterator it = mExtraContents.constBegin(); it != end; ++it) {
+    for (QMap<KMime::Content *, QVector<KMime::Content *> >::ConstIterator it = mExtraContents.constBegin(); it != end; ++it) {
         Q_FOREACH (KMime::Content *c, it.value()) {
             KMime::Content *p = c->parent();
             if (p) {
@@ -235,7 +225,7 @@ QString NodeHelper::writeNodeToTempFile(KMime::Content *node)
     // If the message part is already written to a file, no point in doing it again.
     // This function is called twice actually, once from the rendering of the attachment
     // in the body and once for the header.
-    QUrl existingFileName = tempFileUrlFromNode(node);
+    const QUrl existingFileName = tempFileUrlFromNode(node);
     if (!existingFileName.isEmpty()) {
         return existingFileName.toLocalFile();
     }
@@ -286,14 +276,15 @@ QUrl NodeHelper::tempFileUrlFromNode(const KMime::Content *node)
 
     const QString index = persistentIndex(node);
 
-    foreach (const QString &path, mAttachmentFilesDir->temporaryFiles()) {
+    const QStringList temporaryFiles = mAttachmentFilesDir->temporaryFiles();
+    for (const QString &path : temporaryFiles) {
         const int right = path.lastIndexOf(QLatin1Char('/'));
         int left = path.lastIndexOf(QLatin1String(".index."), right);
         if (left != -1) {
             left += 7;
         }
 
-        QStringRef storedIndex(&path, left, right - left);
+        const QStringRef storedIndex(&path, left, right - left);
         if (left != -1 && storedIndex == index) {
             return QUrl::fromLocalFile(path);
         }
@@ -334,8 +325,11 @@ void NodeHelper::forceCleanTempFiles()
 void NodeHelper::removeTempFiles()
 {
     //Don't delete as it will be deleted in class
-    mAttachmentFilesDir->removeTempFiles();
+    if (mAttachmentFilesDir) {
+        mAttachmentFilesDir->removeTempFiles();
+    }
     mAttachmentFilesDir = new AttachmentTemporaryFilesDirs();
+    mListAttachmentTemporaryDirs.append(mAttachmentFilesDir);
 }
 
 void NodeHelper::addTempFile(const QString &file)
@@ -349,7 +343,7 @@ bool NodeHelper::isInEncapsulatedMessage(KMime::Content *node)
     const KMime::Content *cur = node;
     while (cur && cur != topLevel) {
         const bool parentIsMessage = cur->parent() && cur->parent()->contentType(false)
-                                     && cur->parent()->contentType()->mimeType().toLower() == "message/rfc822";
+                                     && cur->parent()->contentType(false)->mimeType().toLower() == "message/rfc822";
         if (parentIsMessage && cur->parent() != topLevel) {
             return true;
         }
@@ -493,9 +487,9 @@ void NodeHelper::magicSetType(KMime::Content *node, bool aAutoDecode)
 {
     const QByteArray body = aAutoDecode ? node->decodedContent() : node->body();
     QMimeDatabase db;
-    QMimeType mime = db.mimeTypeForData(body);
+    const QMimeType mime = db.mimeTypeForData(body);
 
-    QString mimetype = mime.name();
+    const QString mimetype = mime.name();
     node->contentType()->setMimeType(mimetype.toLatin1());
 }
 
@@ -516,19 +510,9 @@ KMime::Headers::Base const *NodeHelper::mailHeaderAsBase(const char *header, con
     return message->headerByType(header);
 }
 
-KMime::Headers::Generics::AddressList const *NodeHelper::mailHeaderAsAddressList(const char *header, const KMime::Content *message) const
+QSharedPointer<KMime::Headers::Generics::AddressList> NodeHelper::mailHeaderAsAddressList(const char *header, const KMime::Content *message) const
 {
-    /* works without this is maybe faster ?
-    if(strcmp(header, "to") == 0) {
-        return message->to();
-    } else if(strcmp(header, "replyTo") == 0) {
-        return message->replyTo();
-    } else if(strcmp(header, "bcc") == 0) {
-        return message->bcc();
-    } else if(strcmp(header, "cc") == 0) {
-        return message->cc();
-    } */
-    auto addressList = new KMime::Headers::Generics::AddressList();
+    QSharedPointer<KMime::Headers::Generics::AddressList> addressList(new KMime::Headers::Generics::AddressList());
     const auto hrd = mailHeaderAsBase(header, message);
     const QByteArray &data = hrd->as7BitString(false);
     addressList->from7BitString(data);
@@ -691,11 +675,11 @@ QString NodeHelper::persistentIndex(const KMime::Content *node) const
 
     QString indexStr = node->index().toString();
     if (indexStr.isEmpty()) {
-        QMapIterator<KMime::Message::Content *, QList<KMime::Content *> > it(mExtraContents);
+        QMapIterator<KMime::Message::Content *, QVector<KMime::Content *> > it(mExtraContents);
         while (it.hasNext()) {
             it.next();
             const auto &extraNodes = it.value();
-            for (int i = 0; i < extraNodes.size(); i++) {
+            for (int i = 0; i < extraNodes.size(); ++i) {
                 if (extraNodes[i] == node) {
                     indexStr = QStringLiteral("e%1").arg(i);
                     const QString parentIndex = persistentIndex(it.key());
@@ -709,10 +693,10 @@ QString NodeHelper::persistentIndex(const KMime::Content *node) const
     } else {
         const KMime::Content *const topLevel = node->topLevel();
         //if the node is an extra node, prepend the index of the extra node to the url
-        QMapIterator<KMime::Message::Content *, QList<KMime::Content *> > it(mExtraContents);
+        QMapIterator<KMime::Message::Content *, QVector<KMime::Content *> > it(mExtraContents);
         while (it.hasNext()) {
             it.next();
-            const QList<KMime::Content *> &extraNodes = extraContents(it.key());
+            const QVector<KMime::Content *> &extraNodes = extraContents(it.key());
             for (int i = 0; i < extraNodes.size(); ++i) {
                 KMime::Content *const extraNode = extraNodes[i];
                 if (topLevel == extraNode) {
@@ -732,14 +716,21 @@ QString NodeHelper::persistentIndex(const KMime::Content *node) const
 
 KMime::Content *NodeHelper::contentFromIndex(KMime::Content *node, const QString &persistentIndex) const
 {
+    if (!node) {
+        return nullptr;
+    }
     KMime::Content *c = node->topLevel();
     if (c) {
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         const QStringList pathParts = persistentIndex.split(QLatin1Char(':'), QString::SkipEmptyParts);
+#else
+        const QStringList pathParts = persistentIndex.split(QLatin1Char(':'), Qt::SkipEmptyParts);
+#endif
         const int pathPartsSize(pathParts.size());
         for (int i = 0; i < pathPartsSize; ++i) {
             const QString &path = pathParts[i];
             if (path.startsWith(QLatin1Char('e'))) {
-                const QList<KMime::Content *> &extraParts = mExtraContents.value(c);
+                const QVector<KMime::Content *> &extraParts = mExtraContents.value(c);
                 const int idx = path.midRef(1, -1).toInt();
                 c = (idx < extraParts.size()) ? extraParts[idx] : nullptr;
             } else {
@@ -768,24 +759,33 @@ KMime::Content *NodeHelper::fromHREF(const KMime::Message::Ptr &mMessage, const
         return contentFromIndex(mMessage.data(), url.adjusted(QUrl::StripTrailingSlash).path());
     } else {
         const QString path = url.toLocalFile();
-        // extract from /<path>/qttestn28554.index.2.3:0:2/unnamed -> "2.3:0:2"
-        // start of the index is something that is not a number followed by a dot: \D.
-        // index is only made of numbers,"." and ":": ([0-9.:]+)
-        // index is the last part of the folder name: /
-        const QRegExp rIndex(QStringLiteral("\\D\\.([e0-9.:]+)/"));
-
-        //search the occurrence at most at the end
-        if (rIndex.lastIndexIn(path) != -1) {
-            return contentFromIndex(mMessage.data(), rIndex.cap(1));
+        const QString extractedPath = extractAttachmentIndex(path);
+        if (!extractedPath.isEmpty()) {
+            return contentFromIndex(mMessage.data(), extractedPath);
         }
         return mMessage.data();
     }
 }
 
+QString NodeHelper::extractAttachmentIndex(const QString &path) const
+{
+    // extract from /<path>/qttestn28554.index.2.3:0:2/unnamed -> "2.3:0:2"
+    // start of the index is something that is not a number followed by a dot: \D.
+    // index is only made of numbers,"." and ":": ([0-9.:]+)
+    // index is the last part of the folder name: /
+    static const QRegularExpression re(QStringLiteral("\\D\\.([e0-9.:]+)/"));
+    QRegularExpressionMatch rmatch;
+    path.lastIndexOf(re, -1, &rmatch);
+    if (rmatch.hasMatch()) {
+        return rmatch.captured(1);
+    }
+    return QString();
+}
+
 QString NodeHelper::fixEncoding(const QString &encoding)
 {
     QString returnEncoding = encoding;
-    // According to http://www.iana.org/assignments/character-sets, uppercase is
+    // According to https://www.iana.org/assignments/character-sets, uppercase is
     // preferred in MIME headers
     const QString returnEncodingToUpper = returnEncoding.toUpper();
     if (returnEncodingToUpper.contains(QLatin1String("ISO "))) {
@@ -798,7 +798,7 @@ QString NodeHelper::fixEncoding(const QString &encoding)
 //-----------------------------------------------------------------------------
 QString NodeHelper::encodingForName(const QString &descriptiveName)
 {
-    QString encoding = KCharsets::charsets()->encodingForName(descriptiveName);
+    const QString encoding = KCharsets::charsets()->encodingForName(descriptiveName);
     return NodeHelper::fixEncoding(encoding);
 }
 
@@ -811,7 +811,7 @@ QStringList NodeHelper::supportedEncodings(bool usAscii)
     for (QStringList::ConstIterator it = encodingNames.constBegin();
          it != constEnd; ++it) {
         QTextCodec *codec = KCharsets::charsets()->codecForName(*it);
-        QString mimeName = (codec) ? QString::fromLatin1(codec->name()).toLower() : (*it);
+        const QString mimeName = (codec) ? QString::fromLatin1(codec->name()).toLower() : (*it);
         if (!mimeNames.contains(mimeName)) {
             encodings.append(KCharsets::charsets()->descriptionForEncoding(*it));
             mimeNames.insert(mimeName, true);
@@ -830,7 +830,7 @@ QString NodeHelper::fromAsString(KMime::Content *node) const
         return topLevel->from()->asUnicodeString();
     } else {
         auto realNode = std::find_if(mExtraContents.cbegin(), mExtraContents.cend(),
-                                     [node](const QList<KMime::Content *> &nodes) {
+                                     [node](const QVector<KMime::Content *> &nodes) {
                 return nodes.contains(node);
             });
         if (realNode != mExtraContents.cend()) {
@@ -853,7 +853,7 @@ void NodeHelper::cleanExtraContent(KMime::Content *topLevelNode)
     mExtraContents[topLevelNode].clear();
 }
 
-QList< KMime::Content * > NodeHelper::extraContents(KMime::Content *topLevelnode) const
+QVector< KMime::Content * > NodeHelper::extraContents(KMime::Content *topLevelnode) const
 {
     return mExtraContents.value(topLevelnode);
 }
@@ -864,7 +864,7 @@ void NodeHelper::mergeExtraNodes(KMime::Content *node)
         return;
     }
 
-    const QList<KMime::Content * > extraNodes = extraContents(node);
+    const QVector<KMime::Content * > extraNodes = extraContents(node);
     for (KMime::Content *extra : extraNodes) {
         if (node->bodyIsMessage()) {
             qCWarning(MIMETREEPARSER_LOG) << "Asked to attach extra content to a kmime::message, this does not make sense. Attaching to:" << node
@@ -887,7 +887,7 @@ void NodeHelper::cleanFromExtraNodes(KMime::Content *node)
     if (!node) {
         return;
     }
-    const QList<KMime::Content * > extraNodes = extraContents(node);
+    const QVector<KMime::Content * > extraNodes = extraContents(node);
     for (KMime::Content *extra : extraNodes) {
         QByteArray s = extra->encodedContent();
         const auto children = node->contents();
@@ -930,7 +930,7 @@ KMime::Message *NodeHelper::messageWithExtraContent(KMime::Content *topLevelNode
 
 KMime::Content *NodeHelper::decryptedNodeForContent(KMime::Content *content) const
 {
-    const QList<KMime::Content *> xc = extraContents(content);
+    const QVector<KMime::Content *> xc = extraContents(content);
     if (!xc.empty()) {
         if (xc.size() == 1) {
             return xc.front();
@@ -947,9 +947,9 @@ bool NodeHelper::unencryptedMessage_helper(KMime::Content *node, QByteArray &res
     if (node) {
         KMime::Content *curNode = node;
         KMime::Content *decryptedNode = nullptr;
-        const QByteArray type = node->contentType(false) ? QByteArray(node->contentType()->mediaType()).toLower() : "text";
-        const QByteArray subType = node->contentType(false) ? node->contentType()->subType().toLower() : "plain";
-        const bool isMultipart = node->contentType(false) && node->contentType()->isMultipart();
+        const QByteArray type = node->contentType(false) ? QByteArray(node->contentType(false)->mediaType()).toLower() : "text";
+        const QByteArray subType = node->contentType(false) ? node->contentType(false)->subType().toLower() : "plain";
+        const bool isMultipart = node->contentType(false) && node->contentType(false)->isMultipart();
         bool isSignature = false;
 
         qCDebug(MIMETREEPARSER_LOG) << "(" << recursionLevel << ") Looking at" << type << "/" << subType;
@@ -982,23 +982,23 @@ bool NodeHelper::unencryptedMessage_helper(KMime::Content *node, QByteArray &res
             KMime::Content headers;
             headers.setHead(curNode->head());
             headers.parse();
-            if (decryptedNode->contentType(false)) {
-                headers.contentType()->from7BitString(decryptedNode->contentType()->as7BitString(false));
+            if (auto ct = decryptedNode->contentType(false)) {
+                headers.contentType()->from7BitString(ct->as7BitString(false));
             } else {
                 headers.removeHeader<KMime::Headers::ContentType>();
             }
-            if (decryptedNode->contentTransferEncoding(false)) {
-                headers.contentTransferEncoding()->from7BitString(decryptedNode->contentTransferEncoding()->as7BitString(false));
+            if (auto ct = decryptedNode->contentTransferEncoding(false)) {
+                headers.contentTransferEncoding()->from7BitString(ct->as7BitString(false));
             } else {
                 headers.removeHeader<KMime::Headers::ContentTransferEncoding>();
             }
-            if (decryptedNode->contentDisposition(false)) {
-                headers.contentDisposition()->from7BitString(decryptedNode->contentDisposition()->as7BitString(false));
+            if (auto cd = decryptedNode->contentDisposition(false)) {
+                headers.contentDisposition()->from7BitString(cd->as7BitString(false));
             } else {
                 headers.removeHeader<KMime::Headers::ContentDisposition>();
             }
-            if (decryptedNode->contentDescription(false)) {
-                headers.contentDescription()->from7BitString(decryptedNode->contentDescription()->as7BitString(false));
+            if (auto cd = decryptedNode->contentDescription(false)) {
+                headers.contentDescription()->from7BitString(cd->as7BitString(false));
             } else {
                 headers.removeHeader<KMime::Headers::ContentDescription>();
             }
