@@ -2,35 +2,12 @@
     objecttreeparser.cpp
 
     This file is part of KMail, the KDE mail client.
-    Copyright (c) 2003      Marc Mutz <mutz@kde.org>
-    Copyright (C) 2002-2004 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-    Copyright (c) 2009 Andras Mantia <andras@kdab.net>
-    Copyright (c) 2015 Sandro Knauß <sknauss@kde.org>
+    SPDX-FileCopyrightText: 2003 Marc Mutz <mutz@kde.org>
+    SPDX-FileCopyrightText: 2002-2004 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
+    SPDX-FileCopyrightText: 2009 Andras Mantia <andras@kdab.net>
+    SPDX-FileCopyrightText: 2015 Sandro Knauß <sknauss@kde.org>
 
-    KMail is free software; you can redistribute it and/or modify it
-    under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    KMail is distributed in the hope that it will be useful, but
-    WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 // MessageViewer includes
@@ -227,14 +204,14 @@ MessagePart::Ptr ObjectTreeParser::parseObjectTreeInternal(KMime::Content *node,
             ProcessResult processResult(mNodeHelper);
 
             QByteArray mimeType("text/plain");
-            if (node->contentType(false) && !node->contentType()->mimeType().isEmpty()) {
-                mimeType = node->contentType()->mimeType();
+            if (auto ct = node->contentType(false)) {
+                mimeType = ct->mimeType();
             }
             // unfortunately there's many emails where we can't trust the attachment mimetype
             // so try to see if we can find something better
             if (mimeType == "application/octet-stream") {
                 NodeHelper::magicSetType(node);
-                mimeType = node->contentType()->mimeType();
+                mimeType = node->contentType(false)->mimeType();
             }
 
             const auto mp = processType(node, processResult, mimeType);
