@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2017-2019 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "templateparserjobtest.h"
@@ -55,7 +42,7 @@ void TemplateParserJobTest::test_convertedHtml_data()
 
     QDir dir(QStringLiteral(MAIL_DATA_DIR));
     const auto l = dir.entryList(QStringList(QStringLiteral("plain*.mbox")), QDir::Files | QDir::Readable | QDir::NoSymLinks);
-    foreach (const QString &file, l) {
+    for (const QString &file : l) {
         QTest::newRow(file.toLatin1().constData()) << QString(dir.path() + QLatin1Char('/') +  file) << QString(dir.path() + QLatin1Char('/') + file + QLatin1String(".html"));
     }
 }
@@ -100,6 +87,9 @@ void TemplateParserJobTest::test_convertedHtml()
     QVERIFY(!convertedHtmlContent.isEmpty());
 
     QCOMPARE(convertedHtmlContent, referenceData);
+    msg.clear();
+    origMsg.clear();
+    delete parser;
 }
 
 void TemplateParserJobTest::test_replyHtml_data()
@@ -109,7 +99,7 @@ void TemplateParserJobTest::test_replyHtml_data()
 
     QDir dir(QStringLiteral(MAIL_DATA_DIR));
     const auto l = dir.entryList(QStringList(QStringLiteral("*.mbox")), QDir::Files | QDir::Readable | QDir::NoSymLinks);
-    foreach (const QString &file, l) {
+    for (const QString &file : l) {
         const QString expectedFile = dir.path() + QLatin1Char('/') + file + QStringLiteral(".html.reply");
         if (!QFile::exists(expectedFile)) {
             continue;
@@ -159,6 +149,9 @@ void TemplateParserJobTest::test_replyHtml()
     }
 
     QCOMPARE(convertedHtmlContent, referenceData);
+    msg.clear();
+    origMsg.clear();
+    delete parser;
 }
 
 void TemplateParserJobTest::test_replyPlain_data()
@@ -168,7 +161,7 @@ void TemplateParserJobTest::test_replyPlain_data()
 
     QDir dir(QStringLiteral(MAIL_DATA_DIR));
     const auto l = dir.entryList(QStringList(QStringLiteral("*.mbox")), QDir::Files | QDir::Readable | QDir::NoSymLinks);
-    foreach (const QString &file, l) {
+    for (const QString &file : l) {
         const QString expectedFile = dir.path() + QLatin1Char('/') + file + QStringLiteral(".plain.reply");
         if (!QFile::exists(expectedFile)) {
             continue;
@@ -209,6 +202,9 @@ void TemplateParserJobTest::test_replyPlain()
     const QString convertedPlainTextContent = parser->plainMessageText(false, TemplateParser::TemplateParserJob::NoSelectionAllowed);
 
     QCOMPARE(convertedPlainTextContent, referenceData);
+    msg.clear();
+    origMsg.clear();
+    delete parser;
 }
 
 void TemplateParserJobTest::test_forwardPlain_data()
@@ -218,7 +214,7 @@ void TemplateParserJobTest::test_forwardPlain_data()
 
     QDir dir(QStringLiteral(MAIL_DATA_DIR));
     const auto l = dir.entryList(QStringList(QStringLiteral("*.mbox")), QDir::Files | QDir::Readable | QDir::NoSymLinks);
-    foreach (const QString &file, l) {
+    for (const QString &file : l) {
         const QString expectedFile = dir.path() + QLatin1Char('/') + file + QStringLiteral(".plain.reply");
         if (!QFile::exists(expectedFile)) {
             continue;
@@ -259,6 +255,9 @@ void TemplateParserJobTest::test_forwardPlain()
     const QString convertedPlainTextContent = parser->plainMessageText(false, TemplateParser::TemplateParserJob::NoSelectionAllowed);
 
     QCOMPARE(convertedPlainTextContent, referenceData);
+    msg.clear();
+    origMsg.clear();
+    delete parser;
 }
 
 void TemplateParserJobTest::test_forwardHtml_data()
@@ -268,7 +267,7 @@ void TemplateParserJobTest::test_forwardHtml_data()
 
     QDir dir(QStringLiteral(MAIL_DATA_DIR));
     const auto l = dir.entryList(QStringList(QStringLiteral("*.mbox")), QDir::Files | QDir::Readable | QDir::NoSymLinks);
-    foreach (const QString &file, l) {
+    for (const QString &file : l) {
         const QString expectedFile = dir.path() + QLatin1Char('/') + file + QStringLiteral(".html.reply");
         if (!QFile::exists(expectedFile)) {
             continue;
@@ -313,6 +312,9 @@ void TemplateParserJobTest::test_forwardHtml()
     }
 
     QCOMPARE(convertedHtmlContent, referenceData);
+    msg.clear();
+    origMsg.clear();
+    delete parser;
 }
 
 void TemplateParserJobTest::test_forwardedAttachments_data()
@@ -322,7 +324,7 @@ void TemplateParserJobTest::test_forwardedAttachments_data()
 
     QDir dir(QStringLiteral(MAIL_DATA_DIR));
     const auto l = dir.entryList(QStringList(QStringLiteral("*.mbox")), QDir::Files | QDir::Readable | QDir::NoSymLinks);
-    foreach (const QString &file, l) {
+    for (const QString &file : l) {
         if (!QFile::exists(dir.path() + QLatin1Char('/') + file + QStringLiteral(".html.reply"))) {
             continue;
         }
@@ -359,7 +361,7 @@ void TemplateParserJobTest::test_forwardedAttachments()
         QFile referenceFile(referenceFileName);
         QVERIFY(referenceFile.open(QIODevice::ReadOnly));
         const QByteArray referenceRawData = KMime::CRLFtoLF(referenceFile.readAll());
-        const KMime::Message::Ptr referenceMsg(new KMime::Message);
+        KMime::Message::Ptr referenceMsg(new KMime::Message);
         referenceMsg->setContent(referenceRawData);
         referenceMsg->parse();
 
@@ -367,9 +369,13 @@ void TemplateParserJobTest::test_forwardedAttachments()
         for (int i = 1; i < msg->contents().size(); i++) {
             QCOMPARE(msg->contents()[i]->encodedContent(), referenceMsg->contents()[i]->encodedContent());
         }
+        referenceMsg.clear();
     } else {
         QCOMPARE(msg->contents().size(), 0);
     }
+    msg.clear();
+    origMsg.clear();
+    delete parser;
 }
 
 void TemplateParserJobTest::test_processWithTemplatesForBody_data()
@@ -420,6 +426,7 @@ void TemplateParserJobTest::test_processWithTemplatesForBody()
     identMan->deleteLater();
     QCOMPARE(QString::fromLatin1(msg->encodedBody()), expected);
     QCOMPARE(spy.count(), 1);
+    delete parser;
 }
 
 void TemplateParserJobTest::test_processWithTemplatesForContent_data()
@@ -473,6 +480,7 @@ void TemplateParserJobTest::test_processWithTemplatesForContent_data()
     QTest::newRow("%OHEADER=\"SSS\"") << "%HEADER=\"SSS\"" << fileName << "" << false;
     QTest::newRow("%OHEADER=\"To\"") << "%OHEADER=\"To\"" << fileName << "kde <foo@yoohoo.org>" << false;
     QTest::newRow("%HEADER( To )") << "%HEADER( To )" << fileName << "kde <foo@yoohoo.org>" << false;
+    QTest::newRow("%HEADER( To ) second test ") << "foo %HEADER( To )" << fileName << "foo kde <foo@yoohoo.org>" << false;
     //Unknown command
     QTest::newRow("unknown command") << "%GGGGG" << fileName << "%GGGGG" << false;
 
