@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "createdatabasefilejobtest.h"
@@ -79,17 +66,17 @@ void CreateDatabaseFileJobTest::shouldCreateFile()
 
     const QByteArray ba = readJsonFile(filename);
     WebEngineViewer::CreatePhishingUrlDataBaseJob job;
-    QSignalSpy spy1(&job, SIGNAL(finished(WebEngineViewer::UpdateDataBaseInfo,WebEngineViewer::CreatePhishingUrlDataBaseJob::DataBaseDownloadResult)));
+    QSignalSpy spy1(&job, &WebEngineViewer::CreatePhishingUrlDataBaseJob::finished);
     job.parseResult(ba);
     QCOMPARE(spy1.count(), 1);
     const WebEngineViewer::UpdateDataBaseInfo info = spy1.at(0).at(0).value<WebEngineViewer::UpdateDataBaseInfo>();
     WebEngineViewer::CreateDatabaseFileJob databasejob;
-    const QString createDataBaseName = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/phishingurl") + QStringLiteral("/test.db");
+    const QString createDataBaseName = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/phishingurl") + QLatin1String("/test.db");
     qDebug() << " new filename " << createDataBaseName;
     databasejob.setFileName(createDataBaseName);
     databasejob.setUpdateDataBaseInfo(info);
 
-    QSignalSpy spy2(&databasejob, SIGNAL(finished(bool,QString,QString)));
+    QSignalSpy spy2(&databasejob, &WebEngineViewer::CreateDatabaseFileJob::finished);
     databasejob.start();
     QCOMPARE(spy2.count(), 1);
     bool successCreateDataBase = spy2.at(0).at(0).toBool();
@@ -178,7 +165,7 @@ void CreateDatabaseFileJobTest::shouldRemoveElementInDataBase()
     // "x\x18\xbdn]\xa5\xa8R\xf7\xab\xcf\xc1\xa3\xa3\xc5Z,\xa6o"
 
     WebEngineViewer::CreateDatabaseFileJob databasejob;
-    const QString createDataBaseName = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/phishingurl") + QStringLiteral("/correctBinary.db");
+    const QString createDataBaseName = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/phishingurl") + QLatin1String("/correctBinary.db");
     qDebug() << " new filename " << createDataBaseName;
     databasejob.setFileName(createDataBaseName);
 
@@ -217,7 +204,7 @@ void CreateDatabaseFileJobTest::shouldRemoveElementInDataBase()
 
     databasejob.setUpdateDataBaseInfo(info);
 
-    QSignalSpy spy2(&databasejob, SIGNAL(finished(bool,QString,QString)));
+    QSignalSpy spy2(&databasejob, &WebEngineViewer::CreateDatabaseFileJob::finished);
     databasejob.start();
     QCOMPARE(spy2.count(), 1);
     bool successCreateDataBase = spy2.at(0).at(0).toBool();
@@ -301,7 +288,7 @@ void CreateDatabaseFileJobTest::shouldRemoveElementInDataBase()
 
     updateDatabasejob.setUpdateDataBaseInfo(updateinfo);
 
-    QSignalSpy spy3(&updateDatabasejob, SIGNAL(finished(bool,QString,QString)));
+    QSignalSpy spy3(&updateDatabasejob, &WebEngineViewer::CreateDatabaseFileJob::finished);
     updateDatabasejob.start();
     QCOMPARE(spy3.count(), 1);
     successCreateDataBase = spy3.at(0).at(0).toBool();
@@ -311,7 +298,7 @@ void CreateDatabaseFileJobTest::shouldRemoveElementInDataBase()
 void CreateDatabaseFileJobTest::shouldCreateCorrectBinaryFile()
 {
     WebEngineViewer::CreateDatabaseFileJob databasejob;
-    const QString createDataBaseName = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/phishingurl") + QStringLiteral("/correctBinary.db");
+    const QString createDataBaseName = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/phishingurl") + QLatin1String("/correctBinary.db");
     qDebug() << " new filename " << createDataBaseName;
     databasejob.setFileName(createDataBaseName);
 
@@ -350,7 +337,7 @@ void CreateDatabaseFileJobTest::shouldCreateCorrectBinaryFile()
 
     databasejob.setUpdateDataBaseInfo(info);
 
-    QSignalSpy spy2(&databasejob, SIGNAL(finished(bool,QString,QString)));
+    QSignalSpy spy2(&databasejob, &WebEngineViewer::CreateDatabaseFileJob::finished);
     databasejob.start();
     QCOMPARE(spy2.count(), 1);
     bool successCreateDataBase = spy2.at(0).at(0).toBool();
@@ -392,17 +379,17 @@ void CreateDatabaseFileJobTest::shouldUpdateDataBase()
     QString firstFilename = QStringLiteral("newdatabase2.json");
     const QByteArray ba = readJsonFile(firstFilename);
     WebEngineViewer::CreatePhishingUrlDataBaseJob job;
-    QSignalSpy spy1(&job, SIGNAL(finished(WebEngineViewer::UpdateDataBaseInfo,WebEngineViewer::CreatePhishingUrlDataBaseJob::DataBaseDownloadResult)));
+    QSignalSpy spy1(&job, &WebEngineViewer::CreatePhishingUrlDataBaseJob::finished);
     job.parseResult(ba);
     QCOMPARE(spy1.count(), 1);
     const WebEngineViewer::UpdateDataBaseInfo info = spy1.at(0).at(0).value<WebEngineViewer::UpdateDataBaseInfo>();
     WebEngineViewer::CreateDatabaseFileJob databasejob;
-    const QString createDataBaseName = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/phishingurl") + QStringLiteral("/update.db");
+    const QString createDataBaseName = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/phishingurl") + QLatin1String("/update.db");
     //qDebug() << " new filename " << createDataBaseName;
     databasejob.setFileName(createDataBaseName);
     databasejob.setUpdateDataBaseInfo(info);
 
-    QSignalSpy spy2(&databasejob, SIGNAL(finished(bool,QString,QString)));
+    QSignalSpy spy2(&databasejob, &WebEngineViewer::CreateDatabaseFileJob::finished);
     databasejob.start();
     QCOMPARE(spy2.count(), 1);
     bool successCreateDataBase = spy2.at(0).at(0).toBool();
@@ -419,7 +406,7 @@ void CreateDatabaseFileJobTest::shouldUpdateDataBase()
     const QByteArray baUpdate = readJsonFile(updateFilename);
 
     WebEngineViewer::CreatePhishingUrlDataBaseJob jobUpdate;
-    QSignalSpy spy3(&jobUpdate, SIGNAL(finished(WebEngineViewer::UpdateDataBaseInfo,WebEngineViewer::CreatePhishingUrlDataBaseJob::DataBaseDownloadResult)));
+    QSignalSpy spy3(&jobUpdate, &WebEngineViewer::CreatePhishingUrlDataBaseJob::finished);
     jobUpdate.parseResult(baUpdate);
     QCOMPARE(spy3.count(), 1);
 
@@ -430,7 +417,7 @@ void CreateDatabaseFileJobTest::shouldUpdateDataBase()
     databasejob2.setFileName(createDataBaseName);
     databasejob2.setUpdateDataBaseInfo(infoUpdate);
 
-    QSignalSpy spy4(&databasejob2, SIGNAL(finished(bool,QString,QString)));
+    QSignalSpy spy4(&databasejob2, &WebEngineViewer::CreateDatabaseFileJob::finished);
     databasejob2.start();
     QCOMPARE(spy4.count(), 1);
     successCreateDataBase = spy4.at(0).at(0).toBool();
