@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "createphishingurldatabasejob.h"
@@ -37,7 +24,6 @@ public:
     CreatePhishingUrlDataBaseJobPrivate()
         : mContraintsCompressionType(CreatePhishingUrlDataBaseJob::RawCompression)
         , mDataBaseDownloadNeeded(CreatePhishingUrlDataBaseJob::FullDataBase)
-        , mNetworkAccessManager(nullptr)
     {
     }
 
@@ -56,6 +42,10 @@ CreatePhishingUrlDataBaseJob::CreatePhishingUrlDataBaseJob(QObject *parent)
     , d(new CreatePhishingUrlDataBaseJobPrivate)
 {
     d->mNetworkAccessManager = new QNetworkAccessManager(this);
+    d->mNetworkAccessManager->setRedirectPolicy(QNetworkRequest::NoLessSafeRedirectPolicy);
+    d->mNetworkAccessManager->setStrictTransportSecurityEnabled(true);
+    d->mNetworkAccessManager->enableStrictTransportSecurityStore(true);
+
     connect(d->mNetworkAccessManager, &QNetworkAccessManager::finished, this, &CreatePhishingUrlDataBaseJob::slotDownloadDataBaseFinished);
     connect(d->mNetworkAccessManager, &QNetworkAccessManager::sslErrors, this, &CreatePhishingUrlDataBaseJob::slotSslErrors);
 }
@@ -90,7 +80,12 @@ void CreatePhishingUrlDataBaseJob::start()
         qCDebug(WEBENGINEVIEWER_LOG) << " postData.toJson()" << baPostData;
         //curl -H "Content-Type: application/json" -X POST -d '{"client":{"clientId":"KDE","clientVersion":"5.4.0"},"threatInfo":{"platformTypes":["WINDOWS"],"threatEntries":[{"url":"http://www.kde.org"}],"threatEntryTypes":["URL"],"threatTypes":["MALWARE"]}}' https://safebrowsing.googleapis.com/v4/threatMatches:find?key=AIzaSyBS62pXATjabbH2RM_jO2EzDg1mTMHlnyo
         QNetworkReply *reply = d->mNetworkAccessManager->post(request, baPostData);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         connect(reply, qOverload<QNetworkReply::NetworkError>(&QNetworkReply::error), this, &CreatePhishingUrlDataBaseJob::slotError);
+#else
+        connect(reply, qOverload<QNetworkReply::NetworkError>(&QNetworkReply::errorOccurred), this, &CreatePhishingUrlDataBaseJob::slotError);
+#endif
+
     }
 }
 
