@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef RICEENCODINGDECODER_H
@@ -22,6 +9,7 @@
 
 #include "webengineviewer_private_export.h"
 #include "updatedatabaseinfo.h"
+#include <QVector>
 namespace WebEngineViewer {
 //https://developers.google.com/safe-browsing/v4/compression
 class RiceDecoder
@@ -60,8 +48,8 @@ public:
     RiceEncodingDecoder();
     ~RiceEncodingDecoder();
 
-    static QList<quint32> decodeRiceIndiceDelta(const WebEngineViewer::RiceDeltaEncoding &riceDeltaEncoding);
-    static QList<quint32> decodeRiceHashesDelta(const WebEngineViewer::RiceDeltaEncoding &riceDeltaEncoding);
+    static QVector<quint32> decodeRiceIndiceDelta(const WebEngineViewer::RiceDeltaEncoding &riceDeltaEncoding);
+    static QVector<quint32> decodeRiceHashesDelta(const WebEngineViewer::RiceDeltaEncoding &riceDeltaEncoding);
 };
 }
 
