@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "searchfullhashjob.h"
@@ -50,6 +37,10 @@ SearchFullHashJob::SearchFullHashJob(QObject *parent)
     , d(new SearchFullHashJobPrivate)
 {
     d->mNetworkAccessManager = new QNetworkAccessManager(this);
+    d->mNetworkAccessManager->setRedirectPolicy(QNetworkRequest::NoLessSafeRedirectPolicy);
+    d->mNetworkAccessManager->setStrictTransportSecurityEnabled(true);
+    d->mNetworkAccessManager->enableStrictTransportSecurityStore(true);
+
     connect(d->mNetworkAccessManager, &QNetworkAccessManager::finished, this, &SearchFullHashJob::slotCheckUrlFinished);
     connect(d->mNetworkAccessManager, &QNetworkAccessManager::sslErrors, this, &SearchFullHashJob::slotSslErrors);
 }
@@ -125,6 +116,7 @@ void SearchFullHashJob::parse(const QByteArray &replyStr)
                     QList<QByteArray> hashList;
                     QMap<QString, QVariant>::const_iterator urlMapIt = urlMap.cbegin();
                     const QMap<QString, QVariant>::const_iterator urlMapItEnd = urlMap.cend();
+                    hashList.reserve(urlMap.count());
                     for (; urlMapIt != urlMapItEnd; ++urlMapIt) {
                         const QByteArray hashStr = urlMapIt.value().toByteArray();
                         hashList << hashStr;
@@ -259,7 +251,12 @@ void SearchFullHashJob::start()
         //qCDebug(WEBENGINEVIEWER_LOG) << " postData.toJson()" << baPostData;
         Q_EMIT debugJson(baPostData);
         QNetworkReply *reply = d->mNetworkAccessManager->post(request, baPostData);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         connect(reply, qOverload<QNetworkReply::NetworkError>(&QNetworkReply::error), this, &SearchFullHashJob::slotError);
+#else
+        connect(reply, qOverload<QNetworkReply::NetworkError>(&QNetworkReply::errorOccurred), this, &SearchFullHashJob::slotError);
+#endif
+
     } else {
         Q_EMIT result(WebEngineViewer::CheckPhishingUrlUtil::InvalidUrl, d->mUrl);
         deleteLater();
