@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "interceptormanager.h"
 #include "urlinterceptor/networkurlinterceptormanager.h"
@@ -45,14 +32,11 @@ InterceptorManager::InterceptorManager(QWebEngineView *webEngine, KActionCollect
 
     // Add interceptor.
     d->mNetworkUrlInterceptor = new WebEngineViewer::NetworkUrlInterceptor(this);
-    for (WebEngineViewer::NetworkPluginUrlInterceptorInterface *interface : d->mManager->interfaceList()) {
+    const auto interfaceList = d->mManager->interfaceList();
+    for (WebEngineViewer::NetworkPluginUrlInterceptorInterface *interface : interfaceList) {
         d->mNetworkUrlInterceptor->addInterceptor(interface);
     }
-#if QTWEBENGINEWIDGETS_VERSION < QT_VERSION_CHECK(5, 13, 0)
-    webEngine->page()->profile()->setRequestInterceptor(d->mNetworkUrlInterceptor);
-#else
     webEngine->page()->profile()->setUrlRequestInterceptor(d->mNetworkUrlInterceptor);
-#endif
 }
 
 InterceptorManager::~InterceptorManager()
@@ -73,7 +57,9 @@ void InterceptorManager::removeInterceptor(WebEngineViewer::NetworkPluginUrlInte
 QList<QAction *> InterceptorManager::interceptorUrlActions(const WebEngineViewer::WebHitTestResult &result) const
 {
     QList<QAction *> actions;
-    for (WebEngineViewer::NetworkPluginUrlInterceptorInterface *interface : d->mManager->interfaceList()) {
+    const auto interfaceList = d->mManager->interfaceList();
+    actions.reserve(interfaceList.count());
+    for (WebEngineViewer::NetworkPluginUrlInterceptorInterface *interface : interfaceList) {
         actions.append(interface->interceptorUrlActions(result));
     }
     return actions;
