@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "webengineview.h"
@@ -33,14 +20,8 @@ using namespace WebEngineViewer;
 class WebEngineViewer::WebEngineViewPrivate
 {
 public:
-    WebEngineViewPrivate(WebEngineView *q)
-        : mSavedRelativePosition(-1)
-        , mCurrentWidget(nullptr)
-        , mWebEngineNavigatorInterceptor(nullptr)
-        , mWebEngineNavigatorInterceptorView(nullptr)
-        , mPhishingDatabase(nullptr)
-        , mCrashCount(0)
-        , q(q)
+    explicit WebEngineViewPrivate(WebEngineView *q)
+        : q(q)
     {
     }
 
@@ -78,13 +59,13 @@ public:
         }
     }
 
-    qreal mSavedRelativePosition;
+    qreal mSavedRelativePosition = -1;
     QWidget *mCurrentWidget = nullptr;
     WebEngineManageScript *mManagerScript = nullptr;
     WebEngineNavigationRequestInterceptor *mWebEngineNavigatorInterceptor = nullptr;
     WebEngineView *mWebEngineNavigatorInterceptorView = nullptr;
     LocalDataBaseManager *mPhishingDatabase = nullptr;
-    int mCrashCount;
+    int mCrashCount = 0;
 
 private:
     WebEngineView *const q;
